@@ -16,7 +16,12 @@ var blacklist = [
     // is slow and the composer doesn't honor iteration counts:
     'remove_single_document_eval_nolock.js',
     'update_simple_eval_nolock.js',
-].map(function(file) { return dir + '/' + file; });
+
+    // This workload assumes it is running against a sharded cluster.
+    'sharded_moveChunk_drop_shard_key_index.js',
+].map(function(file) {
+    return dir + '/' + file;
+});
 
 // SERVER-16196 re-enable executing workloads
 // runCompositionOfWorkloads(ls(dir).filter(function(file) {
