@@ -28,10 +28,9 @@ function getStorageEngineName(db) {
     var status = db.serverStatus();
     assert.commandWorked(status);
 
-    assert(isMongod(db),
-           'no storage engine is reported when connected to mongos');
-    assert.neq('undefined', typeof status.storageEngine,
-               'missing storage engine info in server status');
+    assert(isMongod(db), 'no storage engine is reported when connected to mongos');
+    assert.neq(
+        'undefined', typeof status.storageEngine, 'missing storage engine info in server status');
 
     return status.storageEngine.name;
 }
