@@ -3,17 +3,23 @@
 function test() {
     function assertTooBig(obj) {
         // This used to crash rather than throwing an exception.
-        assert.throws(function(){Object.bsonsize(obj);});
+        assert.throws(function() {
+            Object.bsonsize(obj);
+        });
     }
 
     function assertNotTooBig(obj) {
-        assert.doesNotThrow(function(){Object.bsonsize(obj);});
+        assert.doesNotThrow(function() {
+            Object.bsonsize(obj);
+        });
     }
 
     function objWithDepth(depth) {
         var out = 1;
         while (depth--) {
-            out = {o: out};
+            out = {
+                o: out
+            };
         }
         return out;
     }
@@ -41,8 +47,7 @@ function test() {
     assertNotTooBig(objWithDepth(objDepthLimit - 1));
     assertTooBig(objWithDepth(objDepthLimit));
 
-
-    var arrayDepthLimit = objDepthLimit - 1; // one lower due to wrapping object
+    var arrayDepthLimit = objDepthLimit - 1;  // one lower due to wrapping object
     assertNotTooBig({array: arrayWithDepth(arrayDepthLimit - 1)});
     assertTooBig({array: arrayWithDepth(arrayDepthLimit)});
 }
@@ -53,4 +58,4 @@ test();
 // test on server
 db.depth_limit.drop();
 db.depth_limit.insert({});
-db.depth_limit.find({$where: test}).itcount(); // itcount ensures that cursor is executed on server
+db.depth_limit.find({$where: test}).itcount();  // itcount ensures that cursor is executed on server
