@@ -8,8 +8,8 @@
 
     assert.eq(null, coll.findAndModify({remove: true}));
     assert.eq(null, coll.findAndModify({update: {$inc: {i: 1}}}));
-    var upserted = coll.findAndModify(
-        {query: {_id: 0}, update: {$inc: {i: 1}}, upsert: true, new: true});
+    var upserted =
+        coll.findAndModify({query: {_id: 0}, update: {$inc: {i: 1}}, upsert: true, new: true});
     assert.eq(upserted, {_id: 0, i: 1});
 
     coll.drop();
