@@ -16,30 +16,49 @@ coll.getDB().createCollection(coll.getName());
 
 // Spec passes text-specific index validation.
 assert.commandWorked(coll.ensureIndex({a: "text"}, {name: indexName, default_language: "spanish"}));
-assert.eq( 1, coll.getIndexes().filter( function(z){ return z.name == indexName; } ).length );
+assert.eq(1,
+          coll.getIndexes().filter(function(z) {
+              return z.name == indexName;
+          }).length);
 coll.dropIndexes();
 
 // Spec fails text-specific index validation ("spanglish" unrecognized).
-assert.commandFailed(coll.ensureIndex({a: "text"}, {name: indexName, default_language: "spanglish"}));
-assert.eq( 0, coll.getIndexes().filter( function(z){ return z.name == indexName; } ).length );
+assert.commandFailed(coll.ensureIndex({a: "text"},
+                                      {name: indexName, default_language: "spanglish"}));
+assert.eq(0,
+          coll.getIndexes().filter(function(z) {
+              return z.name == indexName;
+          }).length);
 coll.dropIndexes();
 
 // Spec passes general index validation.
 assert.commandWorked(coll.ensureIndex({"$**": "text"}, {name: indexName}));
-assert.eq( 1, coll.getIndexes().filter( function(z){ return z.name == indexName; } ).length );
+assert.eq(1,
+          coll.getIndexes().filter(function(z) {
+              return z.name == indexName;
+          }).length);
 coll.dropIndexes();
 
 // Spec fails general index validation ("a.$**" invalid field name for key).
 assert.commandFailed(coll.ensureIndex({"a.$**": "text"}, {name: indexName}));
-assert.eq( 0, coll.getIndexes().filter( function(z){ return z.name == indexName; } ).length );
+assert.eq(0,
+          coll.getIndexes().filter(function(z) {
+              return z.name == indexName;
+          }).length);
 coll.dropIndexes();
 
 // SERVER-19519 Spec fails if '_fts' is specified on a non-text index.
 assert.commandFailed(coll.ensureIndex({_fts: 1}, {name: indexName}));
-assert.eq( 0, coll.getIndexes().filter( function(z){ return z.name == indexName; } ).length );
+assert.eq(0,
+          coll.getIndexes().filter(function(z) {
+              return z.name == indexName;
+          }).length);
 coll.dropIndexes();
 assert.commandFailed(coll.ensureIndex({_fts: "text"}, {name: indexName}));
-assert.eq( 0, coll.getIndexes().filter( function(z){ return z.name == indexName; } ).length );
+assert.eq(0,
+          coll.getIndexes().filter(function(z) {
+              return z.name == indexName;
+          }).length);
 coll.dropIndexes();
 
 //
@@ -60,12 +79,12 @@ coll.drop();
 // Can insert documents with valid language_override into text-indexed collection.
 assert.commandWorked(coll.ensureIndex({a: "text"}));
 coll.insert({a: ""});
-assert.writeOK( coll.insert({a: "", language: "spanish"}));
+assert.writeOK(coll.insert({a: "", language: "spanish"}));
 coll.drop();
 
 // Can't insert documents with invalid language_override into text-indexed collection.
 assert.commandWorked(coll.ensureIndex({a: "text"}));
-assert.writeError( coll.insert({a: "", language: "spanglish"}));
+assert.writeError(coll.insert({a: "", language: "spanglish"}));
 coll.drop();
 
 //
@@ -142,7 +161,7 @@ assert.commandWorked(coll.ensureIndex({a: "text"}));
 
 var longstring = "";
 var longstring2 = "";
-for(var i = 0; i < 1024 * 1024; ++i) {
+for (var i = 0; i < 1024 * 1024; ++i) {
     longstring = longstring + "a";
     longstring2 = longstring2 + "b";
 }
@@ -157,5 +176,4 @@ coll.dropIndexes();
 assert.commandFailed(coll.ensureIndex({a: 1, _fts: "text", _ftsx: 1, c: 1}, {weights: {}}));
 assert.commandFailed(coll.ensureIndex({a: 1, _fts: "text", _ftsx: 1, c: 1}));
 
-
 coll.drop();
