@@ -7,15 +7,7 @@ t.drop();
 // "Exterior shell of polygon is invalid".
 var geometry = {
     type: "Polygon",
-    coordinates: [
-        [
-            [ 0, 0 ],
-            [ 0, 1 ],
-            [ 1, 1 ],
-            [-2,-1 ],
-            [ 0, 0 ]
-        ]
-    ]
+    coordinates: [[[0, 0], [0, 1], [1, 1], [-2, -1], [0, 0]]]
 };
 
 t.insert({_id: 42, geometry: geometry});
@@ -23,8 +15,5 @@ var err = t.createIndex({geometry: '2dsphere'});
 assert.commandFailed(err);
 
 // Document's _id should be in error message.
-assert(
-    -1 != err.errmsg.indexOf('42'),
-    "Error message didn't contain document _id.\nMessage: \"" + err.errmsg
-    + '"\n'
-);
+assert(-1 != err.errmsg.indexOf('42'),
+       "Error message didn't contain document _id.\nMessage: \"" + err.errmsg + '"\n');
