@@ -2,14 +2,18 @@
 // we find them with queries.
 t = db.geo_s2nongeoarray;
 
-oldPoint = [40,5];
+oldPoint = [40, 5];
 
-var data = {geo: oldPoint, nonGeo: [123,456], otherNonGeo: [{b:[1,2]},{b:[3,4]}]};
+var data = {
+    geo: oldPoint,
+    nonGeo: [123, 456],
+    otherNonGeo: [{b: [1, 2]}, {b: [3, 4]}]
+};
 
 t.drop();
 assert.writeOK(t.insert(data));
-assert.commandWorked(t.ensureIndex({ otherNonGeo: 1 }));
-assert.eq(1, t.find({otherNonGeo: {b:[1,2]}}).itcount());
+assert.commandWorked(t.ensureIndex({otherNonGeo: 1}));
+assert.eq(1, t.find({otherNonGeo: {b: [1, 2]}}).itcount());
 assert.eq(0, t.find({otherNonGeo: 1}).itcount());
 assert.eq(1, t.find({'otherNonGeo.b': 1}).itcount());
 
