@@ -3,9 +3,15 @@
 
 var coll = db.geo_s2sparse;
 
-var point = { type: "Point", coordinates: [5, 5] };
+var point = {
+    type: "Point",
+    coordinates: [5, 5]
+};
 
-var indexSpec = { geo: "2dsphere", nonGeo: 1 };
+var indexSpec = {
+    geo: "2dsphere",
+    nonGeo: 1
+};
 
 var indexName = 'test.geo_s2sparse.$geo_2dsphere_nonGeo_1';
 
@@ -20,7 +26,7 @@ coll.ensureIndex(indexSpec);
 // Insert N documents with the geo field.
 var N = 1000;
 for (var i = 0; i < N; i++) {
-    coll.insert({ geo: point, nonGeo: "point_"+i });
+    coll.insert({geo: point, nonGeo: "point_" + i});
 }
 
 // Expect N keys.
@@ -28,7 +34,7 @@ assert.eq(N, coll.validate().keysPerIndex[indexName]);
 
 // Insert N documents without the geo field.
 for (var i = 0; i < N; i++) {
-    coll.insert({ wrongGeo: point, nonGeo: i});
+    coll.insert({wrongGeo: point, nonGeo: i});
 }
 
 // Still expect N keys as we didn't insert any geo stuff.
@@ -36,7 +42,7 @@ assert.eq(N, coll.validate().keysPerIndex[indexName]);
 
 // Insert N documents with just the geo field.
 for (var i = 0; i < N; i++) {
-    coll.insert({ geo: point});
+    coll.insert({geo: point});
 }
 
 // Expect 2N keys.
@@ -44,10 +50,10 @@ assert.eq(N + N, coll.validate().keysPerIndex[indexName]);
 
 // Add some "not geo" stuff.
 for (var i = 0; i < N; i++) {
-    coll.insert({ geo: null});
-    coll.insert({ geo: []});
-    coll.insert({ geo: undefined});
-    coll.insert({ geo: {}});
+    coll.insert({geo: null});
+    coll.insert({geo: []});
+    coll.insert({geo: undefined});
+    coll.insert({geo: {}});
 }
 
 // Still expect 2N keys.
@@ -62,7 +68,7 @@ coll.ensureIndex(indexSpec, {"2dsphereIndexVersion": 1});
 
 // Insert N documents with the geo field.
 for (var i = 0; i < N; i++) {
-    coll.insert({ geo: point, nonGeo: "point_"+i });
+    coll.insert({geo: point, nonGeo: "point_" + i});
 }
 
 // Expect N keys.
@@ -70,7 +76,7 @@ assert.eq(N, coll.validate().keysPerIndex[indexName]);
 
 // Insert N documents without the geo field.
 for (var i = 0; i < N; i++) {
-    coll.insert({ wrongGeo: point, nonGeo: i});
+    coll.insert({wrongGeo: point, nonGeo: i});
 }
 
 // Expect N keys as it's a V1 index.
@@ -89,7 +95,7 @@ indexName = 'test.geo_s2sparse.$geo_2dsphere_otherGeo_2dsphere';
 // Insert N documents with the first geo field.
 var N = 1000;
 for (var i = 0; i < N; i++) {
-    coll.insert({ geo: point});
+    coll.insert({geo: point});
 }
 
 // Expect N keys.
@@ -98,7 +104,7 @@ assert.eq(N, coll.validate().keysPerIndex[indexName]);
 // Insert N documents with the second geo field.
 var N = 1000;
 for (var i = 0; i < N; i++) {
-    coll.insert({ otherGeo: point});
+    coll.insert({otherGeo: point});
 }
 
 // They get inserted too.
@@ -106,7 +112,7 @@ assert.eq(N + N, coll.validate().keysPerIndex[indexName]);
 
 // Insert N documents with neither geo field.
 for (var i = 0; i < N; i++) {
-    coll.insert({ nonGeo: i});
+    coll.insert({nonGeo: i});
 }
 
 // Still expect 2N keys as the neither geo docs were omitted from the index.
