@@ -5,12 +5,13 @@ t.save({a: 2});
 t.save({b: 5});
 t.save({a: 1});
 
-cmd = { key: {a: 1},
-        initial: {count: 0},
-        reduce: function(obj, prev) {
-            prev.count++;
-        }
-      };
+cmd = {
+    key: {a: 1},
+    initial: {count: 0},
+    reduce: function(obj, prev) {
+        prev.count++;
+    }
+};
 
 result = t.group(cmd);
 
@@ -24,18 +25,19 @@ assert.eq(1, result[1].count, "G");
 assert.eq(1, result[2].count, "H");
 
 var keyFn = function(x) {
-    return { a: 'a' in x ? x.a : null };
+    return {
+        a: 'a' in x ? x.a : null
+    };
 };
 
 delete cmd.key;
 cmd["$keyf"] = keyFn;
-result2 = t.group( cmd );
-
-assert.eq( result , result2, "check result2" );
+result2 = t.group(cmd);
 
+assert.eq(result, result2, "check result2");
 
 delete cmd.$keyf;
 cmd["keyf"] = keyFn;
-result3 = t.group( cmd );
+result3 = t.group(cmd);
 
-assert.eq( result , result3, "check result3" );
+assert.eq(result, result3, "check result3");
