@@ -1,7 +1,7 @@
 // Basic tests for a form of stack recursion that's been shown to cause C++
 // side stack overflows in the past. See SERVER-19614.
 
-(function () {
+(function() {
     "use strict";
 
     db.recursion.drop();
@@ -14,7 +14,7 @@
 
     // Make sure db.eval doesn't blow up
     function dbEvalRecursion() {
-        db.eval(function () {
+        db.eval(function() {
             function recursion() {
                 recursion.apply();
             }
@@ -25,17 +25,17 @@
 
     // Make sure mapReduce doesn't blow up
     function mapReduceRecursion() {
-        db.recursion.mapReduce(function(){
-            (function recursion(){
-                recursion.apply();
-            })();
-        }, function(){
-        }, {
-            out: 'inline'
-        });
+        db.recursion.mapReduce(
+            function() {
+                (function recursion() {
+                    recursion.apply();
+                })();
+            },
+            function() {},
+            {out: 'inline'});
     }
 
     db.recursion.insert({});
-    assert.commandFailedWithCode(
-        assert.throws(mapReduceRecursion), ErrorCodes.JSInterpreterFailure);
+    assert.commandFailedWithCode(assert.throws(mapReduceRecursion),
+                                 ErrorCodes.JSInterpreterFailure);
 }());
