@@ -7,23 +7,26 @@
  */
 
 // 1. Drop db
-var mydb = db.getSisterDB( "repairDB" );
+var mydb = db.getSisterDB("repairDB");
 mydb.dropDatabase();
 
 var myColl = mydb.a;
 
 // 2
-var doc = {_id:1, a:"hello world"};
+var doc = {
+    _id: 1,
+    a: "hello world"
+};
 myColl.insert(doc);
-myColl.ensureIndex({a:1});
+myColl.ensureIndex({a: 1});
 mydb.repairDatabase();
 var foundDoc = myColl.findOne();
 
 assert.neq(null, foundDoc);
 assert.eq(1, foundDoc._id);
 
-assert.docEq(doc, myColl.findOne({a:doc.a}));
-assert.docEq(doc, myColl.findOne({_id:1}));
+assert.docEq(doc, myColl.findOne({a: doc.a}));
+assert.docEq(doc, myColl.findOne({_id: 1}));
 
 // 3
 var myColl2 = mydb.b;
@@ -35,5 +38,5 @@ var myColl2 = mydb.b;
 myColl.insert(doc);
 myColl2.insert(doc);
 mydb.repairDatabase();
-assert.docEq(doc, myColl.findOne({a:doc.a}));
-assert.docEq(doc, myColl2.findOne({a:doc.a}));
+assert.docEq(doc, myColl.findOne({a: doc.a}));
+assert.docEq(doc, myColl2.findOne({a: doc.a}));
