@@ -26,21 +26,25 @@ b = Timestamp(a.t, a.i);
 printjson(a);
 assert.eq(tojson(a), tojson(b), "timestamp");
 
-assert.throws(function() { Timestamp(-2, 3); }, null,
-              "Timestamp time must not accept negative time" );
-assert.throws(function() { Timestamp(0, -1); }, null,
-              "Timestamp increment must not accept negative time" );
-assert.throws(function() { Timestamp(0x10000 * 0x10000, 0); }, null,
-              "Timestamp time must not accept values larger than 2**32 - 1");
-assert.throws(function() { Timestamp(0, 0x10000 * 0x10000); }, null,
-              "Timestamp increment must not accept values larger than 2**32 - 1");
+assert.throws(function() {
+    Timestamp(-2, 3);
+}, null, "Timestamp time must not accept negative time");
+assert.throws(function() {
+    Timestamp(0, -1);
+}, null, "Timestamp increment must not accept negative time");
+assert.throws(function() {
+    Timestamp(0x10000 * 0x10000, 0);
+}, null, "Timestamp time must not accept values larger than 2**32 - 1");
+assert.throws(function() {
+    Timestamp(0, 0x10000 * 0x10000);
+}, null, "Timestamp increment must not accept values larger than 2**32 - 1");
 
 a = new Timestamp(0x80008000, 0x80008000 + 0.5);
 b = Timestamp(a.t, Math.round(a.i));
 printjson(a);
 assert.eq(tojson(a), tojson(b), "timestamp");
 
-a = new BinData(3,"VQ6EAOKbQdSnFkRmVUQAAA==");
+a = new BinData(3, "VQ6EAOKbQdSnFkRmVUQAAA==");
 b = BinData(a.type, a.base64());
 printjson(a);
 assert.eq(tojson(a), tojson(b), "bindata");
@@ -77,36 +81,38 @@ var timestampA = a.getTimestamp();
 var dateA = new Date(timestampA.getTime());
 
 // ObjectId.fromDate - invalid input types
-assert.throws(function() { ObjectId.fromDate(undefined); }, null,
-              "ObjectId.fromDate should error on undefined date" );
+assert.throws(function() {
+    ObjectId.fromDate(undefined);
+}, null, "ObjectId.fromDate should error on undefined date");
 
-assert.throws(function() { ObjectId.fromDate(12345); }, null,
-              "ObjectId.fromDate should error on numerical value" );
+assert.throws(function() {
+    ObjectId.fromDate(12345);
+}, null, "ObjectId.fromDate should error on numerical value");
 
-assert.throws(function() { ObjectId.fromDate(dateA.toISOString()); }, null,
-              "ObjectId.fromDate should error on string value" );
+assert.throws(function() {
+    ObjectId.fromDate(dateA.toISOString());
+}, null, "ObjectId.fromDate should error on string value");
 
 // SERVER-14623 dates less than or equal to 1978-07-04T21:24:15Z fail
 var checkFromDate = function(millis, expected, comment) {
     var oid = ObjectId.fromDate(new Date(millis));
     assert.eq(oid.valueOf(), expected, comment);
 };
-checkFromDate(Math.pow(2,28) * 1000, "100000000000000000000000", "1978-07-04T21:24:16Z");
-checkFromDate((Math.pow(2,28) * 1000) - 1 , "0fffffff0000000000000000", "1978-07-04T21:24:15Z");
+checkFromDate(Math.pow(2, 28) * 1000, "100000000000000000000000", "1978-07-04T21:24:16Z");
+checkFromDate((Math.pow(2, 28) * 1000) - 1, "0fffffff0000000000000000", "1978-07-04T21:24:15Z");
 checkFromDate(0, "000000000000000000000000", "start of epoch");
 
 // test date upper limit
-checkFromDate((Math.pow(2,32) * 1000) - 1, "ffffffff0000000000000000", "last valid date");
-assert.throws(function() { ObjectId.fromDate(new Date(Math.pow(2,32) * 1000)); }, null,
-              "ObjectId limited to 4 bytes for seconds" );
+checkFromDate((Math.pow(2, 32) * 1000) - 1, "ffffffff0000000000000000", "last valid date");
+assert.throws(function() {
+    ObjectId.fromDate(new Date(Math.pow(2, 32) * 1000));
+}, null, "ObjectId limited to 4 bytes for seconds");
 
 // ObjectId.fromDate - Date
 b = ObjectId.fromDate(dateA);
 printjson(a);
 assert.eq(tojson(a.getTimestamp()), tojson(b.getTimestamp()), "ObjectId.fromDate - Date");
 
-
-
 // tojsonObject
 
 // Empty object
@@ -131,4 +137,3 @@ assert.eq('{ "a" : 1, "b" : { "bb" : 2, "cc" : 3 } }',
           tojsonObject({a: 1, b: {bb: 2, cc: 3}}, '', true));
 assert.eq('{\n\t\t\t"a" : 1,\n\t\t\t"b" : {\n\t\t\t\t"bb" : 2,\n\t\t\t\t"cc" : 3\n\t\t\t}\n\t\t}',
           tojsonObject({a: 1, b: {bb: 2, cc: 3}}, '\t\t'));
-
