@@ -9,13 +9,11 @@ t.save({x: "az b x"});
 t.ensureIndex({x: "text"});
 
 // We expect to retrieve 'b'
-res = db.runCommand({stageDebug: {collection: collname,
-                                  plan: {text: {args: {search: "b"}}}}});
+res = db.runCommand({stageDebug: {collection: collname, plan: {text: {args: {search: "b"}}}}});
 assert.eq(res.ok, 1);
 assert.eq(res.results.length, 1);
 
 // I have not been indexed yet.
-res = db.runCommand({stageDebug: {collection: collname,
-                                  plan: {text: {args: {search: "hari"}}}}});
+res = db.runCommand({stageDebug: {collection: collname, plan: {text: {args: {search: "hari"}}}}});
 assert.eq(res.ok, 1);
 assert.eq(res.results.length, 0);
