@@ -4,7 +4,7 @@ var baseName = "filesize";
 // Start mongod with --smallfiles
 var m = MongoRunner.runMongod({nojournal: "", smallfiles: ""});
 
-var db = m.getDB( baseName );
+var db = m.getDB(baseName);
 
 // Skip on 32 bits, since 32-bit servers don't warn about small files
 if (db.serverBuildInfo().bits == 32) {
@@ -20,21 +20,20 @@ if (db.serverBuildInfo().bits == 32) {
         nojournal: "",
     });
 
-    db = m.getDB( baseName );
-    var log = db.adminCommand( { getLog : "global" } ).log;
+    db = m.getDB(baseName);
+    var log = db.adminCommand({getLog: "global"}).log;
 
     // Find log message like:
     // "openExisting file size 16777216 but
     // mmapv1GlobalOptions.smallfiles=false: /data/db/filesize/local.0"
     var found = false, logline = '';
-    for ( i=log.length - 1; i>= 0; i-- ) {
+    for (i = log.length - 1; i >= 0; i--) {
         logline = log[i];
-        if ( logline.indexOf( "openExisting file" ) >= 0
-            && logline.indexOf( "local.0" ) >= 0 ) {
+        if (logline.indexOf("openExisting file") >= 0 && logline.indexOf("local.0") >= 0) {
             found = true;
             break;
         }
     }
 
-    assert( found );
+    assert(found);
 }
