@@ -10,12 +10,12 @@ function get_ipaddr() {
             // Terminate path with / if defined
             path += "/";
         }
+    } catch (err) {
     }
-    catch (err) {}
 
-    var ipFile = path+"ipaddr.log";
-    var windowsCmd = "ipconfig > "+ipFile;
-    var unixCmd = "/sbin/ifconfig | grep inet | grep -v '127.0.0.1' > "+ipFile;
+    var ipFile = path + "ipaddr.log";
+    var windowsCmd = "ipconfig > " + ipFile;
+    var unixCmd = "/sbin/ifconfig | grep inet | grep -v '127.0.0.1' > " + ipFile;
     var ipAddr = null;
     var hostType = null;
 
@@ -27,11 +27,10 @@ function get_ipaddr() {
             runProgram('cmd.exe', '/c', windowsCmd);
             ipAddr = cat(ipFile).match(/IPv4.*: (.*)/)[1];
         } else {
-            runProgram('bash', '-c',  unixCmd);
+            runProgram('bash', '-c', unixCmd);
             ipAddr = cat(ipFile).replace(/addr:/g, "").match(/inet (.[^ ]*) /)[1];
         }
-    }
-    finally {
+    } finally {
         removeFile(ipFile);
     }
     return ipAddr;
