@@ -75,9 +75,15 @@ print("8: start up former master");
 clearRawMongoProgramOutput();
 replTest.restart(masterId);
 
-print("9: check former master does not roll back");
+print("9: check former master " + replTest.nodes[masterId].host + " does not select former slave " +
+      slave.host + " as sync source");
+replTest.waitForState(replTest.nodes[masterId], ReplSetTest.State.RECOVERING, 90000);
+
+// Sync source selection will log this message if it does not detect min valid in the sync
+// source candidate's oplog.
 assert.soon(function() {
-    return rawMongoProgramOutput().match("need to rollback, but in inconsistent state");
+    return rawMongoProgramOutput().match(
+        'it does not contain the necessary operations for us to reach a consistent state');
 });
 
 replTest.stopSet(15);
