@@ -13,13 +13,18 @@ if ("undefined" == typeof inner_mode) {
     // tested manually), so 127.0.0.1 is also present so the test mongo shell can connect
     // with that address.
     var mongod = MongoRunner.runMongod({ipv6: "", bind_ip: "::1,127.0.0.1"});
-    var args = ["mongo",
-                "--nodb",
-                "--ipv6",
-                "--host", "::1",
-                "--port", mongod.port,
-                "--eval", "inner_mode=true;port=" + mongod.port + ";",
-                "jstests/noPassthroughWithMongod/ipv6_connection_string_validation.js" ];
+    var args = [
+        "mongo",
+        "--nodb",
+        "--ipv6",
+        "--host",
+        "::1",
+        "--port",
+        mongod.port,
+        "--eval",
+        "inner_mode=true;port=" + mongod.port + ";",
+        "jstests/noPassthroughWithMongod/ipv6_connection_string_validation.js"
+    ];
     var exitCode = _runMongoProgram.apply(null, args);
     jsTest.log("Inner mode test finished, exit code was " + exitCode);
 
@@ -32,50 +37,49 @@ if ("undefined" == typeof inner_mode) {
 }
 
 var goodStrings = [
-        "localhost:27999/test",
-        "[::1]:27999/test",
-        "[0:0:0:0:0:0:0:1]:27999/test",
-        "[0000:0000:0000:0000:0000:0000:0000:0001]:27999/test"
+    "localhost:27999/test",
+    "[::1]:27999/test",
+    "[0:0:0:0:0:0:0:1]:27999/test",
+    "[0000:0000:0000:0000:0000:0000:0000:0001]:27999/test"
 ];
 
 var badStrings = [
-        { s: undefined,                 r: /^Missing connection string$/ },
-        { s: 7,                         r: /^Incorrect type/ },
-        { s: null,                      r: /^Incorrect type/ },
-        { s: "",                        r: /^Empty connection string$/ },
-        { s: "    ",                    r: /^Empty connection string$/ },
-        { s: ":",                       r: /^Missing host name/ },
-        { s: "/",                       r: /^Missing host name/ },
-        { s: ":/",                      r: /^Missing host name/ },
-        { s: ":/test",                  r: /^Missing host name/ },
-        { s: ":27999/",                 r: /^Missing host name/ },
-        { s: ":27999/test",             r: /^Missing host name/ },
-        { s: "/test",                   r: /^Missing host name/ },
-        { s: "localhost:/test",         r: /^Missing port number/ },
-        { s: "::1:/test",               r: /^Missing port number/ },
-        { s: "::1:cat/test",            r: /^Invalid port number/ },
-        { s: "::1:1cat/test",           r: /^Invalid port number/ },
-        { s: "::1:123456/test",         r: /^Invalid port number/ },
-        { s: "::1:65536/test",          r: /^Invalid port number/ },
-        { s: "127.0.0.1:65536/test",    r: /^Invalid port number/ },
-        { s: "::1:27999/",              r: /^Missing database name/ },
-        { s: "127.0.0.1:27999/",        r: /^Missing database name/ },
-        { s: "::1:27999/test",          r: /^More than one ':'/ },
-        { s: "0:0::0:0:1:27999/test",   r: /^More than one ':'/ },
-        { s: "0000:0000:0000:0000:0000:0000:0000:0001:27999/test", r: /^More than one ':'/ },
-        { s: "a[127.0.0.1]:27999/",     r: /^Missing database name/ },
-        { s: "a[::1:]27999/",           r: /^Invalid port number/ },
-        { s: "[::1:27999/",             r: /^Missing database name/ },
-        { s: "[::1:]27999/",            r: /^Invalid port number/ },
-        { s: "::1]:27999/",             r: /^Missing database name/ }
+    {s: undefined, r: /^Missing connection string$/},
+    {s: 7, r: /^Incorrect type/},
+    {s: null, r: /^Incorrect type/},
+    {s: "", r: /^Empty connection string$/},
+    {s: "    ", r: /^Empty connection string$/},
+    {s: ":", r: /^Missing host name/},
+    {s: "/", r: /^Missing host name/},
+    {s: ":/", r: /^Missing host name/},
+    {s: ":/test", r: /^Missing host name/},
+    {s: ":27999/", r: /^Missing host name/},
+    {s: ":27999/test", r: /^Missing host name/},
+    {s: "/test", r: /^Missing host name/},
+    {s: "localhost:/test", r: /^Missing port number/},
+    {s: "::1:/test", r: /^Missing port number/},
+    {s: "::1:cat/test", r: /^Invalid port number/},
+    {s: "::1:1cat/test", r: /^Invalid port number/},
+    {s: "::1:123456/test", r: /^Invalid port number/},
+    {s: "::1:65536/test", r: /^Invalid port number/},
+    {s: "127.0.0.1:65536/test", r: /^Invalid port number/},
+    {s: "::1:27999/", r: /^Missing database name/},
+    {s: "127.0.0.1:27999/", r: /^Missing database name/},
+    {s: "::1:27999/test", r: /^More than one ':'/},
+    {s: "0:0::0:0:1:27999/test", r: /^More than one ':'/},
+    {s: "0000:0000:0000:0000:0000:0000:0000:0001:27999/test", r: /^More than one ':'/},
+    {s: "a[127.0.0.1]:27999/", r: /^Missing database name/},
+    {s: "a[::1:]27999/", r: /^Invalid port number/},
+    {s: "[::1:27999/", r: /^Missing database name/},
+    {s: "[::1:]27999/", r: /^Invalid port number/},
+    {s: "::1]:27999/", r: /^Missing database name/}
 ];
 
 var substitutePort = function(connectionString) {
     // This will be called with non-strings as well as strings, so we need to catch exceptions
     try {
         return connectionString.replace("27999", "" + port);
-    }
-    catch (e) {
+    } catch (e) {
         return connectionString;
     }
 };
@@ -87,18 +91,17 @@ var testGood = function(i, connectionString) {
     try {
         var connectDB = connect(connectionString);
         connectDB = null;
-    }
-    catch (e) {
+    } catch (e) {
         gotException = true;
         exception = e;
     }
     if (!gotException) {
-        print("Good connection string " + i +
-              " (\"" + connectionString + "\") correctly validated");
+        print("Good connection string " + i + " (\"" + connectionString +
+              "\") correctly validated");
         return;
     }
-    var message = "FAILED to correctly validate goodString " + i +
-                  " (\"" + connectionString + "\"):  exception was \"" + tojson(exception) + "\"";
+    var message = "FAILED to correctly validate goodString " + i + " (\"" + connectionString +
+        "\"):  exception was \"" + tojson(exception) + "\"";
     doassert(message);
 };
 
@@ -110,8 +113,7 @@ var testBad = function(i, connectionString, errorRegex) {
     try {
         var connectDB = connect(connectionString);
         connectDB = null;
-    }
-    catch (e) {
+    } catch (e) {
         gotException = true;
         exception = e;
         if (errorRegex.test(e.message)) {
@@ -123,13 +125,12 @@ var testBad = function(i, connectionString, errorRegex) {
               "\") correctly rejected:\n" + tojson(exception));
         return;
     }
-    var message = "FAILED to generate correct exception for badString " + i +
-                  " (\"" + connectionString + "\"): ";
+    var message = "FAILED to generate correct exception for badString " + i + " (\"" +
+        connectionString + "\"): ";
     if (gotException) {
-        message += "exception was \"" + tojson(exception) +
-                    "\", it should have matched \"" + errorRegex.toString() + "\"";
-    }
-    else {
+        message += "exception was \"" + tojson(exception) + "\", it should have matched \"" +
+            errorRegex.toString() + "\"";
+    } else {
         message += "no exception was thrown";
     }
     doassert(message);
