@@ -1,20 +1,23 @@
 if (1) {
-
     t = db.compactspeedtest;
     t.drop();
 
-    var obj = { x: 1, y: "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", z: [1, 2] };
+    var obj = {
+        x: 1,
+        y: "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
+        z: [1, 2]
+    };
 
     var start = new Date();
     function timed() {
         db.getLastError();
         var dt = (new Date()) - start;
-        //print("time: " + dt);
+        // print("time: " + dt);
         start = new Date();
         return dt;
     }
 
-    //print("adding data");
+    // print("adding data");
     var N = 100000;
     if (db.adminCommand("buildInfo").debug)
         N = 10000;
@@ -25,27 +28,27 @@ if (1) {
     }
     var a = timed();
 
-    //print("index");
-    t.ensureIndex({ x: 1 });
-    //print("index");
-    t.ensureIndex({ y: 1 });
-    //print("index");
-    t.ensureIndex({ z: 1 });
+    // print("index");
+    t.ensureIndex({x: 1});
+    // print("index");
+    t.ensureIndex({y: 1});
+    // print("index");
+    t.ensureIndex({z: 1});
 
     a += timed();
 
-    //print("count:" + t.count());
+    // print("count:" + t.count());
 
     timed();
 
     {
-        //print("compact");
-        var res = db.runCommand({ compact: 'compactspeedtest', dev: true });
+        // print("compact");
+        var res = db.runCommand({compact: 'compactspeedtest', dev: true});
         b = timed();
-        //printjson(res);
+        // printjson(res);
         assert(res.ok);
 
-        //print("validate");
+        // print("validate");
         var v = t.validate(true);
 
         assert(v.ok);
