@@ -8,14 +8,11 @@
 // run on ephemeral storage engines.
 // @tags: [requires_persistence]
 
-(function () {
+(function() {
     "use strict";
     var keyfile = "jstests/libs/key1";
     var master;
-    var rs = new ReplSetTest({
-        nodes : { node0 : {}, node1 : {}, arbiter : {}},
-        keyFile : keyfile
-    });
+    var rs = new ReplSetTest({nodes: {node0: {}, node1: {}, arbiter: {}}, keyFile: keyfile});
     rs.startSet();
     rs.initiate();
 
@@ -27,11 +24,11 @@
     var safeInsert = function() {
         master = rs.getPrimary();
         master.getDB("admin").auth("foo", "bar");
-        assert.writeOK(master.getDB("foo").bar.insert({ x: 1 }));
+        assert.writeOK(master.getDB("foo").bar.insert({x: 1}));
     };
 
     jsTest.log("authing");
-    for (var i=0; i<2; i++) {
+    for (var i = 0; i < 2; i++) {
         assert(rs.nodes[i].getDB("admin").auth("foo", "bar"),
                "could not log into " + rs.nodes[i].host);
     }
@@ -39,7 +36,11 @@
     jsTest.log("make common point");
 
     safeInsert();
-    authutil.asCluster(rs.nodes, keyfile, function() { rs.awaitReplication(); });
+    authutil.asCluster(rs.nodes,
+                       keyfile,
+                       function() {
+                           rs.awaitReplication();
+                       });
 
     jsTest.log("write stuff to 0&2");
     rs.stop(1);
@@ -48,7 +49,7 @@
     master.getDB("admin").auth("foo", "bar");
     master.getDB("foo").bar.drop();
     jsTest.log("last op: " +
-               tojson(master.getDB("local").oplog.rs.find().sort({$natural:-1}).limit(1).next()));
+               tojson(master.getDB("local").oplog.rs.find().sort({$natural: -1}).limit(1).next()));
 
     jsTest.log("write stuff to 1&2");
     rs.stop(0);
@@ -56,12 +57,16 @@
 
     safeInsert();
     jsTest.log("last op: " +
-               tojson(master.getDB("local").oplog.rs.find().sort({$natural:-1}).limit(1).next()));
+               tojson(master.getDB("local").oplog.rs.find().sort({$natural: -1}).limit(1).next()));
 
     rs.restart(0);
 
     jsTest.log("doing rollback!");
 
-    authutil.asCluster(rs.nodes, keyfile, function () { rs.awaitSecondaryNodes(); });
+    authutil.asCluster(rs.nodes,
+                       keyfile,
+                       function() {
+                           rs.awaitSecondaryNodes();
+                       });
 
 }());
