@@ -9,7 +9,9 @@ testCleanupOrphaned({
     shardKey: {_id: 1},
     keyGen: function() {
         var ids = [];
-        for (var i = -50; i < 50; i++) { ids.push({_id: i}); }
+        for (var i = -50; i < 50; i++) {
+            ids.push({_id: i});
+        }
         return ids;
     }
 });
