@@ -12,7 +12,13 @@ assert.commandWorked(admin.runCommand({shardCollection: testNs, key: {_id: 1}}))
 
 for (var i = 0; i < 100; i += 10) {
     assert.commandWorked(st.s0.getDB('admin').runCommand({split: testNs, middle: {_id: i}}));
+    if (st.configRS) {
+        st.configRS.awaitLastOpCommitted();  // Ensure that other mongos sees the previous split
+    }
     assert.commandWorked(st.s1.getDB('admin').runCommand({split: testNs, middle: {_id: i + 5}}));
+    if (st.configRS) {
+        st.configRS.awaitLastOpCommitted();  // Ensure that other mongos sees the previous split
+    }
 }
 
-st.stop();
\ No newline at end of file
+st.stop();
