@@ -2,12 +2,10 @@
 // each role is a member of the next, creating a large chain.
 
 function runTest(conn) {
-
     var testdb = conn.getDB("rolechain");
-    testdb.runCommand({dropAllRolesFromDatabase:1});
+    testdb.runCommand({dropAllRolesFromDatabase: 1});
     var chainLen = 2000;
 
-
     jsTestLog("Generating a chain of " + chainLen + " linked roles");
 
     var roleNameBase = "chainRole";
@@ -15,15 +13,13 @@ function runTest(conn) {
         var name = roleNameBase + i;
         if (i == 0) {
             testdb.runCommand({createRole: name, privileges: [], roles: []});
-        }
-        else {
+        } else {
             jsTestLog("Creating role " + i);
             var prevRole = roleNameBase + (i - 1);
-            testdb.runCommand({createRole: name, privileges: [], roles: [ prevRole ]});
+            testdb.runCommand({createRole: name, privileges: [], roles: [prevRole]});
             var roleInfo = testdb.getRole(name);
         }
     }
-
 }
 
 // run all tests standalone
