@@ -3,20 +3,20 @@
  * mixed modes can still function
  */
 
-load("jstests/ssl/libs/ssl_helpers.js")
+load("jstests/ssl/libs/ssl_helpers.js");
 
 // Verify that disabled allows non-ssl connections
 print("=== Testing disabled cluster ===");
-replShouldSucceed(disabled, disabled);
+replShouldSucceed("disabled-disabled", disabled, disabled);
 
 // Test mixed sslMode allowSSL/preferSSL with non-ssl client
 print("=== Testing allowSSL/preferSSL cluster ===");
-replShouldSucceed(allowSSL, preferSSL);
+replShouldSucceed("allow-prefer", allowSSL, preferSSL);
 
 // Test mixed sslMode allowSSL/disabled with non-ssl client
 print("=== Testing allowSSL/disabled cluster ===");
-replShouldSucceed(allowSSL, disabled);
+replShouldSucceed("allow-disabled", allowSSL, disabled);
 
 // Test mixed sslMode disables/preferSSL - should fail with non-ssl client
 print("=== Testing disabled/preferSSL cluster - SHOULD FAIL ===");
-replShouldFail(disabled, preferSSL);
+replShouldFail("disabled-disabled", disabled, preferSSL);
