@@ -19,9 +19,13 @@ function authAllNodes() {
     }
 }
 
-opts = {sslMode:"disabled", clusterAuthMode:"keyFile", keyFile: KEYFILE};
+opts = {
+    sslMode: "disabled",
+    clusterAuthMode: "keyFile",
+    keyFile: KEYFILE
+};
 var NUM_NODES = 3;
-var rst = new ReplSetTest({ name: 'sslSet', nodes: NUM_NODES, nodeOptions : opts });
+var rst = new ReplSetTest({name: 'sslSet', nodes: NUM_NODES, nodeOptions: opts});
 rst.startSet();
 rst.initiate();
 
@@ -29,54 +33,87 @@ rst.initiate();
 var rstConn1 = rst.getPrimary();
 rstConn1.getDB("admin").createUser({user: "root", pwd: "pwd", roles: ["root"]}, {w: NUM_NODES});
 rstConn1.getDB("admin").auth("root", "pwd");
-rstConn1.getDB("test").a.insert({a:1, str:"TESTTESTTEST"});
+rstConn1.getDB("test").a.insert({a: 1, str: "TESTTESTTEST"});
 assert.eq(1, rstConn1.getDB("test").a.count(), "Error interacting with replSet");
 
 print("===== UPGRADE disabled,keyFile -> allowSSL,sendKeyfile =====");
 authAllNodes();
-rst.upgradeSet({sslMode:"allowSSL", sslPEMKeyFile: SERVER_CERT,
-                sslAllowInvalidCertificates:"",
-                clusterAuthMode:"sendKeyFile", keyFile: KEYFILE,
-                sslCAFile: CA_CERT}, "root", "pwd");
+rst.upgradeSet(
+    {
+      sslMode: "allowSSL",
+      sslPEMKeyFile: SERVER_CERT,
+      sslAllowInvalidCertificates: "",
+      clusterAuthMode: "sendKeyFile",
+      keyFile: KEYFILE,
+      sslCAFile: CA_CERT
+    },
+    "root",
+    "pwd");
 authAllNodes();
 rst.awaitReplication();
 
 var rstConn2 = rst.getPrimary();
-rstConn2.getDB("test").a.insert({a:2, str:"CHECKCHECKCHECK"});
+rstConn2.getDB("test").a.insert({a: 2, str: "CHECKCHECKCHECK"});
 assert.eq(2, rstConn2.getDB("test").a.count(), "Error interacting with replSet");
 
 print("===== UPGRADE allowSSL,sendKeyfile -> preferSSL,sendX509 =====");
-rst.upgradeSet({sslMode:"preferSSL", sslPEMKeyFile: SERVER_CERT,
-                sslAllowInvalidCertificates:"",
-                clusterAuthMode:"sendX509", keyFile: KEYFILE,
-                sslCAFile: CA_CERT}, "root", "pwd");
+rst.upgradeSet(
+    {
+      sslMode: "preferSSL",
+      sslPEMKeyFile: SERVER_CERT,
+      sslAllowInvalidCertificates: "",
+      clusterAuthMode: "sendX509",
+      keyFile: KEYFILE,
+      sslCAFile: CA_CERT
+    },
+    "root",
+    "pwd");
 authAllNodes();
 rst.awaitReplication();
 
 var rstConn3 = rst.getPrimary();
-rstConn3.getDB("test").a.insert({a:3, str:"PEASandCARROTS"});
+rstConn3.getDB("test").a.insert({a: 3, str: "PEASandCARROTS"});
 assert.eq(3, rstConn3.getDB("test").a.count(), "Error interacting with replSet");
 
-var canConnectSSL = runMongoProgram("mongo", "--port", rst.ports[0], "--ssl",
+var canConnectSSL = runMongoProgram("mongo",
+                                    "--port",
+                                    rst.ports[0],
+                                    "--ssl",
                                     "--sslAllowInvalidCertificates",
-                                    "--sslPEMKeyFile",  CLIENT_CERT, "--eval", ";");
+                                    "--sslPEMKeyFile",
+                                    CLIENT_CERT,
+                                    "--eval",
+                                    ";");
 assert.eq(0, canConnectSSL, "SSL Connection attempt failed when it should succeed");
 
 print("===== UPGRADE preferSSL,sendX509 -> preferSSL,x509 =====");
-//we cannot upgrade past preferSSL here because it will break the test client
-rst.upgradeSet({sslMode:"preferSSL", sslPEMKeyFile: SERVER_CERT,
-                sslAllowInvalidCertificates:"",
-                clusterAuthMode:"x509", keyFile: KEYFILE,
-                sslCAFile: CA_CERT}, "root", "pwd");
+// we cannot upgrade past preferSSL here because it will break the test client
+rst.upgradeSet(
+    {
+      sslMode: "preferSSL",
+      sslPEMKeyFile: SERVER_CERT,
+      sslAllowInvalidCertificates: "",
+      clusterAuthMode: "x509",
+      keyFile: KEYFILE,
+      sslCAFile: CA_CERT
+    },
+    "root",
+    "pwd");
 authAllNodes();
 rst.awaitReplication();
 var rstConn4 = rst.getPrimary();
-rstConn4.getDB("test").a.insert({a:4, str:"BEEP BOOP"});
+rstConn4.getDB("test").a.insert({a: 4, str: "BEEP BOOP"});
 rst.awaitReplication();
 assert.eq(4, rstConn4.getDB("test").a.count(), "Error interacting with replSet");
 
 // Test that an ssl connection can still be made
-var canConnectSSL = runMongoProgram("mongo", "--port", rst.ports[0], "--ssl",
+var canConnectSSL = runMongoProgram("mongo",
+                                    "--port",
+                                    rst.ports[0],
+                                    "--ssl",
                                     "--sslAllowInvalidCertificates",
-                                    "--sslPEMKeyFile",  CLIENT_CERT, "--eval", ";");
+                                    "--sslPEMKeyFile",
+                                    CLIENT_CERT,
+                                    "--eval",
+                                    ";");
 assert.eq(0, canConnectSSL, "SSL Connection attempt failed when it should succeed");
