@@ -35,6 +35,7 @@
 #include <limits>
 #include <string>
 
+#include "mongo/stdx/type_traits.h"
 #define MONGO_INCLUDE_INVARIANT_H_WHITELISTED
 #include "mongo/util/invariant.h"
 #undef MONGO_INCLUDE_INVARIANT_H_WHITELISTED
@@ -59,6 +60,9 @@ class StringData {
     StringData(const char* c, size_t len, TrustedInitTag) : _data(c), _size(len) {}
 
 public:
+    // Iterator type
+    using const_iterator = const char*;
+
     /** Constructs an empty StringData. */
     StringData() = default;
 
@@ -98,6 +102,23 @@ public:
         invariant(_data || (_size == 0));
     }
 
+    /**
+     * Constructs a StringData with begin and end iterators. begin points to the beginning of the
+     * string. end points to the position past the end of the string. In a null-terminated string,
+     * end points to the null-terminator.
+     *
+     * We template the second parameter to ensure if StringData is called with 0 in the second
+     * parameter, the (ptr,len) constructor is chosen instead.
+     */
+    template <
+        typename InputIt,
+        typename = stdx::enable_if_t<std::is_same<StringData::const_iterator, InputIt>::value>>
+    StringData(InputIt begin, InputIt end) {
+        invariant(begin && end);
+        _data = begin;
+        _size = std::distance(begin, end);
+    }
+
     /**
      * Returns -1, 0, or 1 if 'this' is less, equal, or greater than 'other' in
      * lexicographical order.
@@ -171,9 +192,6 @@ public:
     //
     // iterators
     //
-
-    typedef const char* const_iterator;
-
     const_iterator begin() const {
         return rawData();
     }
