@@ -62,6 +62,11 @@ PoolForHost::~PoolForHost() {
 }
 
 void PoolForHost::clear() {
+    if (!_parentDestroyed) {
+        logNoCache() << "Dropping all pooled connections to " << _hostName << "(with timeout of "
+                     << _socketTimeout << " seconds)";
+    }
+
     while (!_pool.empty()) {
         StoredConnection sc = _pool.top();
         delete sc.conn;
@@ -80,9 +85,19 @@ void PoolForHost::done(DBConnectionPool* pool, DBClientBase* c) {
 
     if (isFailed ||
         // Another (later) connection was reported as broken to this host
-        (c->getSockCreationMicroSec() < _minValidCreationTimeMicroSec) ||
+        (c->getSockCreationMicroSec() < _minValidCreationTimeMicroSec)) {
+        logNoCache() << "Ending connection to host " << _hostName << "(with timeout of "
+                     << _socketTimeout << " seconds)"
+                     << " due to bad connection status; " << openConnections()
+                     << " connections to that host remain open";
+        pool->onDestroy(c);
+        delete c;
+    } else if (_maxPoolSize >= 0 && static_cast<int>(_pool.size()) >= _maxPoolSize) {
         // We have a pool size that we need to enforce
-        (_maxPoolSize >= 0 && static_cast<int>(_pool.size()) >= _maxPoolSize)) {
+        logNoCache() << "Ending idle connection to host " << _hostName << "(with timeout of "
+                     << _socketTimeout << " seconds)"
+                     << " because the pool meets constraints; " << openConnections()
+                     << " connections to that host remain open";
         pool->onDestroy(c);
         delete c;
     } else {
@@ -95,9 +110,11 @@ void PoolForHost::reportBadConnectionAt(uint64_t microSec) {
     if (microSec != DBClientBase::INVALID_SOCK_CREATION_TIME &&
         microSec > _minValidCreationTimeMicroSec) {
         _minValidCreationTimeMicroSec = microSec;
-        log() << "Detected bad connection created at " << _minValidCreationTimeMicroSec
-              << " microSec, clearing pool for " << _hostName << " of " << _pool.size()
-              << " connections" << endl;
+
+        logNoCache() << "Detected bad connection created at " << _minValidCreationTimeMicroSec
+                     << " microSec, clearing pool for " << _hostName << " of " << openConnections()
+                     << " connections" << endl;
+
         clear();
     }
 }
@@ -130,6 +147,9 @@ DBClientBase* PoolForHost::get(DBConnectionPool* pool, double socketTimeout) {
 }
 
 void PoolForHost::flush() {
+    log() << "Dropping all pooled connections to " << _hostName << "(with timeout of "
+          << _socketTimeout << " seconds)";
+
     while (!_pool.empty()) {
         StoredConnection c = _pool.top();
         _pool.pop();
@@ -196,10 +216,17 @@ DBClientBase* DBConnectionPool::_get(const string& ident, double socketTimeout)
     stdx::lock_guard<stdx::mutex> L(_mutex);
     PoolForHost& p = _pools[PoolKey(ident, socketTimeout)];
     p.setMaxPoolSize(_maxPoolSize);
+    p.setSocketTimeout(socketTimeout);
     p.initializeHostName(ident);
     return p.get(this, socketTimeout);
 }
 
+int DBConnectionPool::openConnections(const string& ident, double socketTimeout) {
+    stdx::lock_guard<stdx::mutex> L(_mutex);
+    PoolForHost& p = _pools[PoolKey(ident, socketTimeout)];
+    return p.openConnections();
+}
+
 DBClientBase* DBConnectionPool::_finishCreate(const string& host,
                                               double socketTimeout,
                                               DBClientBase* conn) {
@@ -219,11 +246,17 @@ DBClientBase* DBConnectionPool::_finishCreate(const string& host,
         throw;
     }
 
+    log() << "Successfully connected to " << host << " (" << openConnections(host, socketTimeout)
+          << " connections now open to " << host << " with a " << socketTimeout
+          << " second timeout)";
+
     return conn;
 }
 
 DBClientBase* DBConnectionPool::get(const ConnectionString& url, double socketTimeout) {
-    DBClientBase* c = _get(url.toString(), socketTimeout);
+    auto host = url.toString();
+
+    DBClientBase* c = _get(host, socketTimeout);
     if (c) {
         try {
             onHandedOut(c);
@@ -236,7 +269,7 @@ DBClientBase* DBConnectionPool::get(const ConnectionString& url, double socketTi
 
     string errmsg;
     c = url.connect(errmsg, socketTimeout);
-    uassert(13328, _name + ": connect failed " + url.toString() + " : " + errmsg, c);
+    uassert(13328, _name + ": connect failed " + host + " : " + errmsg, c);
 
     return _finishCreate(url.toString(), socketTimeout, c);
 }
@@ -262,6 +295,7 @@ DBClientBase* DBConnectionPool::get(const string& host, double socketTimeout) {
                               host,
                               11002,
                               str::stream() << _name << " error: " << errmsg);
+
     return _finishCreate(host, socketTimeout, c);
 }
 
@@ -284,7 +318,13 @@ void DBConnectionPool::release(const string& host, DBClientBase* c) {
 
 
 DBConnectionPool::~DBConnectionPool() {
-    // connection closing is handled by ~PoolForHost
+    // Do not log in destruction, because global connection pools get
+    // destroyed after the logging framework.
+    stdx::lock_guard<stdx::mutex> L(_mutex);
+    for (PoolMap::iterator i = _pools.begin(); i != _pools.end(); i++) {
+        PoolForHost& p = i->second;
+        p._parentDestroyed = true;
+    }
 }
 
 void DBConnectionPool::flush() {
@@ -361,11 +401,11 @@ void DBConnectionPool::appendConnectionStats(executor::ConnectionPoolStats* stat
             invariant(uri.isOK());
             HostAndPort host = uri.getValue().getServers().front();
 
-            executor::ConnectionStatsPerHost hostStats{
-                static_cast<size_t>(i->second.numInUse()),
-                static_cast<size_t>(i->second.numAvailable()),
-                static_cast<size_t>(i->second.numCreated())};
-            stats->updateStatsForHost(host, hostStats);
+            executor::ConnectionStatsPer hostStats{static_cast<size_t>(i->second.numInUse()),
+                                                   static_cast<size_t>(i->second.numAvailable()),
+                                                   static_cast<size_t>(i->second.numCreated()),
+                                                   0};
+            stats->updateStatsForHost("global", host, hostStats);
         }
     }
 }
