@@ -678,9 +678,11 @@ bool DBClientWithCommands::eval(const string& dbname, const string& jscode) {
 
 list<string> DBClientWithCommands::getDatabaseNames() {
     BSONObj info;
-    uassert(10005,
-            "listdatabases failed",
-            runCommand("admin", BSON("listDatabases" << 1), info, QueryOption_SlaveOk));
+    uassert(
+        10005,
+        "listdatabases failed",
+        runCommand(
+            "admin", BSON("listDatabases" << 1 << "nameOnly" << true), info, QueryOption_SlaveOk));
     uassert(10006, "listDatabases.databases not array", info["databases"].type() == Array);
 
     list<string> names;
@@ -922,6 +924,12 @@ Status DBClientConnection::connect(const HostAndPort& serverAddress) {
         return swIsMasterReply.getStatus();
     }
 
+    // Ensure that the isMaster response is "ok:1".
+    auto isMasterStatus = getStatusFromCommandResult(swIsMasterReply.getValue().data);
+    if (!isMasterStatus.isOK()) {
+        return isMasterStatus;
+    }
+
     auto swProtocolSet = rpc::parseProtocolSetFromIsMasterReply(swIsMasterReply.getValue().data);
     if (!swProtocolSet.isOK()) {
         return swProtocolSet.getStatus();
@@ -1542,12 +1550,12 @@ void DBClientConnection::handleNotMasterResponse(const BSONElement& elemToCheck)
         return;
     }
 
-    MONGO_LOG_COMPONENT(1, logger::LogComponent::kReplication)
-        << "got not master from: " << _serverAddress << " of repl set: " << _parentReplSetName;
-
     ReplicaSetMonitorPtr monitor = ReplicaSetMonitor::get(_parentReplSetName);
     if (monitor) {
-        monitor->failedHost(_serverAddress);
+        monitor->failedHost(_serverAddress,
+                            {ErrorCodes::NotMaster,
+                             str::stream() << "got not master from: " << _serverAddress
+                                           << " of repl set: " << _parentReplSetName});
     }
 
     _failed = true;
