@@ -38,6 +38,7 @@
 #include "mongo/client/global_conn_pool.h"
 #include "mongo/client/replica_set_monitor_internal.h"
 #include "mongo/db/server_options.h"
+#include "mongo/db/server_parameters.h"
 #include "mongo/stdx/condition_variable.h"
 #include "mongo/stdx/mutex.h"
 #include "mongo/stdx/thread.h"
@@ -83,6 +84,8 @@ const Milliseconds kFindHostMaxBackOffTime(500);
 ReplicaSetMonitor::ConfigChangeHook asyncConfigChangeHook;
 ReplicaSetMonitor::ConfigChangeHook syncConfigChangeHook;
 
+MONGO_EXPORT_SERVER_PARAMETER(timeOutMonitoringReplicaSets, bool, false);
+
 // global background job responsible for checking every X amount of time
 class ReplicaSetMonitorWatcher : public BackgroundJob {
 public:
@@ -173,11 +176,18 @@ protected:
             m->startOrContinueRefresh().refreshAll();
 
             if (!m->isSetUsable()) {
-                log() << "Stopping periodic monitoring of set " << m->getName()
-                      << " because none of the hosts could be contacted for an extended period of "
-                         "time.";
+                if (timeOutMonitoringReplicaSets) {
+                    warning() << "Stopping periodic monitoring of set " << m->getName()
+                              << " because none of the hosts could be contacted for an extended "
+                                 "period of time.";
 
-                ReplicaSetMonitor::remove(m->getName());
+                    ReplicaSetMonitor::remove(m->getName());
+                } else {
+                    warning() << "Replica set " << m->getName()
+                              << " has been down for an extended period of time.  Monitoring of "
+                                 "this set will continue as the 'timeOutMonitoringReplicaSets' "
+                                 "server parameter is set to false";
+                }
             }
         }
     }
@@ -324,11 +334,11 @@ Refresher ReplicaSetMonitor::startOrContinueRefresh() {
     return out;
 }
 
-void ReplicaSetMonitor::failedHost(const HostAndPort& host) {
+void ReplicaSetMonitor::failedHost(const HostAndPort& host, const Status& status) {
     stdx::lock_guard<stdx::mutex> lk(_state->mutex);
     Node* node = _state->findNode(host);
     if (node)
-        node->markFailed();
+        node->markFailed(status);
     DEV _state->checkInvariants();
 }
 
@@ -484,7 +494,7 @@ Refresher::Refresher(const SetStatePtr& setState)
 
 Refresher::NextStep Refresher::getNextStep() {
     // If the set is faulty, don't try anymore
-    if (!_set->isUsable()) {
+    if (!_set->isUsable() && timeOutMonitoringReplicaSets) {
         return NextStep(NextStep::DONE);
     }
 
@@ -539,11 +549,13 @@ Refresher::NextStep Refresher::getNextStep() {
             _set->consecutiveFailedScans = 0;
         } else {
             _set->consecutiveFailedScans++;
-            log() << "All nodes for set " << _set->name << " are down. "
-                  << "This has happened for " << _set->consecutiveFailedScans
-                  << " checks in a row. Polling will stop after "
-                  << maxConsecutiveFailedChecks - _set->consecutiveFailedScans
-                  << " more failed checks";
+            if (timeOutMonitoringReplicaSets) {
+                warning() << "All nodes for set " << _set->name << " are down. "
+                          << "This has happened for " << _set->consecutiveFailedScans
+                          << " checks in a row. Polling will stop after "
+                          << maxConsecutiveFailedChecks - _set->consecutiveFailedScans
+                          << " more failed checks";
+            }
         }
 
         // Makes sure all other Refreshers in this round return DONE
@@ -568,9 +580,10 @@ void Refresher::receivedIsMaster(const HostAndPort& from,
     _scan->waitingFor.erase(from);
 
     const IsMasterReply reply(from, latencyMicros, replyObj);
+
     // Handle various failure cases
     if (!reply.ok) {
-        failedHost(from);
+        failedHost(from, {ErrorCodes::CommandFailed, "Failed to execute 'ismaster' command"});
         return;
     }
 
@@ -588,17 +601,18 @@ void Refresher::receivedIsMaster(const HostAndPort& from,
             warning() << "node: " << from << " isn't a part of set: " << _set->name
                       << " ismaster: " << replyObj;
         }
-        failedHost(from);
+
+        failedHost(from,
+                   {ErrorCodes::InconsistentReplicaSetNames,
+                    str::stream() << "Target replica set name " << reply.setName
+                                  << " does not match the monitored set name " << _set->name});
         return;
     }
 
     if (reply.isMaster) {
-        if (!receivedIsMasterFromMaster(reply)) {
-            log() << "node " << from << " believes it is primary, but its election id of "
-                  << reply.electionId << " and config version of " << reply.configVersion
-                  << " is older than the most recent election id " << _set->maxElectionId
-                  << " and config version of " << _set->configVersion;
-            failedHost(from);
+        Status status = receivedIsMasterFromMaster(from, reply);
+        if (!status.isOK()) {
+            failedHost(from, status);
             return;
         }
     }
@@ -621,7 +635,7 @@ void Refresher::receivedIsMaster(const HostAndPort& from,
     DEV _set->checkInvariants();
 }
 
-void Refresher::failedHost(const HostAndPort& host) {
+void Refresher::failedHost(const HostAndPort& host, const Status& status) {
     _scan->waitingFor.erase(host);
 
     // Failed hosts can't pass criteria, so the only way they'd effect the _refreshUntilMatches
@@ -631,7 +645,7 @@ void Refresher::failedHost(const HostAndPort& host) {
 
     Node* node = _set->findNode(host);
     if (node)
-        node->markFailed();
+        node->markFailed(status);
 }
 
 ScanStatePtr Refresher::startNewScan(const SetState* set) {
@@ -669,13 +683,17 @@ ScanStatePtr Refresher::startNewScan(const SetState* set) {
     return scan;
 }
 
-bool Refresher::receivedIsMasterFromMaster(const IsMasterReply& reply) {
+Status Refresher::receivedIsMasterFromMaster(const HostAndPort& from, const IsMasterReply& reply) {
     invariant(reply.isMaster);
 
     // Reject if config version is older. This is for backwards compatibility with nodes in pv0
     // since they don't have the same ordering with pv1 electionId.
     if (reply.configVersion < _set->configVersion) {
-        return false;
+        return {
+            ErrorCodes::NotMaster,
+            str::stream() << "Node " << from << " believes it is primary, but its config version "
+                          << reply.configVersion << " is older than the most recent config version "
+                          << _set->configVersion};
     }
 
     if (reply.electionId.isSet()) {
@@ -684,7 +702,11 @@ bool Refresher::receivedIsMasterFromMaster(const IsMasterReply& reply) {
         // because configVersion needs to be incremented whenever the protocol version is changed.
         if (reply.configVersion == _set->configVersion && _set->maxElectionId.isSet() &&
             _set->maxElectionId.compare(reply.electionId) > 0) {
-            return false;
+            return {
+                ErrorCodes::NotMaster,
+                str::stream() << "Node " << from << " believes it is primary, but its election id "
+                              << reply.electionId << " is older than the most recent election id "
+                              << _set->maxElectionId};
         }
 
         _set->maxElectionId = reply.electionId;
@@ -767,7 +789,7 @@ bool Refresher::receivedIsMasterFromMaster(const IsMasterReply& reply) {
     _scan->foundUpMaster = true;
     _set->lastSeenMaster = reply.host;
 
-    return true;
+    return Status::OK();
 }
 
 void Refresher::receivedIsMasterBeforeFoundMaster(const IsMasterReply& reply) {
@@ -812,19 +834,28 @@ HostAndPort Refresher::_refreshUntilMatches(const ReadPreferenceSetting* criteri
                 continue;
 
             case NextStep::CONTACT_HOST: {
-                BSONObj reply;  // empty on error
+                StatusWith<BSONObj> isMasterReplyStatus{ErrorCodes::InternalError,
+                                                        "Uninitialized variable"};
                 int64_t pingMicros = 0;
 
-                lk.unlock();  // relocked after attempting to call isMaster
+                // Do not do network calls while holding a mutex
+                lk.unlock();
                 try {
                     ScopedDbConnection conn(ConnectionString(ns.host), socketTimeoutSecs);
                     bool ignoredOutParam = false;
                     Timer timer;
+                    BSONObj reply;
                     conn->isMaster(ignoredOutParam, &reply);
+                    isMasterReplyStatus = reply;
                     pingMicros = timer.micros();
                     conn.done();  // return to pool on success.
-                } catch (...) {
-                    reply = BSONObj();  // should be a no-op but want to be sure
+                } catch (const DBException& ex) {
+                    // If this mongos is being used in an illegal configuration and must be
+                    // upgraded, bubble up the error.
+                    isMasterReplyStatus = ex.toStatus();
+                    if (isMasterReplyStatus == ErrorCodes::MustUpgrade) {
+                        throw;
+                    }
                 }
                 lk.lock();
 
@@ -833,10 +864,10 @@ HostAndPort Refresher::_refreshUntilMatches(const ReadPreferenceSetting* criteri
                 if (_scan != _set->currentScan)
                     return criteria ? _set->getMatchingHost(*criteria) : HostAndPort();
 
-                if (reply.isEmpty())
-                    failedHost(ns.host);
+                if (isMasterReplyStatus.isOK())
+                    receivedIsMaster(ns.host, pingMicros, isMasterReplyStatus.getValue());
                 else
-                    receivedIsMaster(ns.host, pingMicros, reply);
+                    failedHost(ns.host, isMasterReplyStatus.getStatus());
             }
         }
     }
@@ -887,10 +918,13 @@ void IsMasterReply::parse(const BSONObj& obj) {
 
 Node::Node(const HostAndPort& host) : host(host), latencyMicros(unknownLatency) {}
 
-void Node::markFailed() {
-    LOG(1) << "Marking host " << host << " as failed";
+void Node::markFailed(const Status& status) {
+    if (isUp) {
+        log() << "Marking host " << host << " as failed" << causedBy(status);
+
+        isUp = false;
+    }
 
-    isUp = false;
     isMaster = false;
 }
 
