@@ -197,16 +197,16 @@ BSONObj SyncClusterConnection::getLastErrorDetailed(
 void SyncClusterConnection::_connect(const std::string& hostStr) {
     log() << "SyncClusterConnection connecting to [" << hostStr << "]" << endl;
     const HostAndPort host(hostStr);
-    DBClientConnection* c;
+    std::unique_ptr<DBClientConnection> c;
     if (connectionHook) {
-        c = new DBClientConnection(
+        c.reset(new DBClientConnection(
             true,  // auto reconnect
             0,     // socket timeout
             [this, host](const executor::RemoteCommandResponse& isMasterReply) {
                 return connectionHook(host, isMasterReply);
-            });
+            }));
     } else {
-        c = new DBClientConnection(true);
+        c.reset(new DBClientConnection(true));
     }
 
     c->setRequestMetadataWriter(getRequestMetadataWriter());
@@ -222,7 +222,7 @@ void SyncClusterConnection::_connect(const std::string& hostStr) {
         }
     }
     _connAddresses.push_back(hostStr);
-    _conns.push_back(c);
+    _conns.push_back(c.release());
 }
 
 bool SyncClusterConnection::runCommand(const std::string& dbname,
@@ -276,9 +276,7 @@ BSONObj SyncClusterConnection::findOne(const string& ns,
                                        const BSONObj* fieldsToReturn,
                                        int queryOptions) {
     if (ns.find(".$cmd") != string::npos) {
-        string cmdName = query.obj.firstElementFieldName();
-
-        int lockType = _lockType(cmdName);
+        int lockType = _lockType(query);
 
         if (lockType > 0) {  // write $cmd
             string errmsg;
@@ -381,10 +379,10 @@ unique_ptr<DBClientCursor> SyncClusterConnection::query(const string& ns,
                                                         int batchSize) {
     _lastErrors.clear();
     if (ns.find(".$cmd") != string::npos) {
-        string cmdName = query.obj.firstElementFieldName();
-        int lockType = _lockType(cmdName);
+        int lockType = _lockType(query);
         uassert(13054,
-                (string) "write $cmd not supported in SyncClusterConnection::query for:" + cmdName,
+                str::stream() << "write $cmd not supported in SyncClusterConnection::query for: "
+                              << query.toString(),
                 lockType <= 0);
     }
 
@@ -622,7 +620,14 @@ void SyncClusterConnection::say(Message& toSend, bool isRetry, string* actualSer
     _checkLast();
 }
 
-int SyncClusterConnection::_lockType(const string& name) {
+int SyncClusterConnection::_lockType(const Query& query) {
+    string name = query.obj.firstElementFieldName();
+
+    if (name == "query") {
+        // actual command is embedded in the query object
+        name = query.obj["query"].Obj().firstElementFieldName();
+    }
+
     {
         stdx::lock_guard<stdx::mutex> lk(_mutex);
         map<string, int>::iterator i = _lockTypes.find(name);
