@@ -361,14 +361,17 @@ void addClusterMonitorPrivileges(PrivilegeVector* privileges) {
     Privilege::addPrivilegeToPrivilegeVector(
         privileges,
         Privilege(ResourcePattern::forAnyNormalResource(), clusterMonitorRoleDatabaseActions));
+    Privilege::addPrivilegeToPrivilegeVector(
+        privileges,
+        Privilege(ResourcePattern::forDatabaseName("config"), clusterMonitorRoleDatabaseActions));
+    Privilege::addPrivilegeToPrivilegeVector(
+        privileges,
+        Privilege(ResourcePattern::forDatabaseName("local"), clusterMonitorRoleDatabaseActions));
+    addReadOnlyDbPrivileges(privileges, "local");
     addReadOnlyDbPrivileges(privileges, "config");
     Privilege::addPrivilegeToPrivilegeVector(
         privileges,
-        Privilege(ResourcePattern::forExactNamespace(NamespaceString("local.system.replset")),
-                  ActionType::find));
-    Privilege::addPrivilegeToPrivilegeVector(
-        privileges,
-        Privilege(ResourcePattern::forExactNamespace(NamespaceString("local.sources")),
+        Privilege(ResourcePattern::forExactNamespace(NamespaceString("local", "system.replset")),
                   ActionType::find));
     Privilege::addPrivilegeToPrivilegeVector(
         privileges,
@@ -391,22 +394,26 @@ void addClusterManagerPrivileges(PrivilegeVector* privileges) {
     Privilege::addPrivilegeToPrivilegeVector(
         privileges,
         Privilege(ResourcePattern::forAnyNormalResource(), clusterManagerRoleDatabaseActions));
-    addReadOnlyDbPrivileges(privileges, "config");
 
-    ActionSet configSettingsActions;
-    configSettingsActions << ActionType::insert << ActionType::update << ActionType::remove;
     Privilege::addPrivilegeToPrivilegeVector(
         privileges,
-        Privilege(ResourcePattern::forExactNamespace(NamespaceString("config", "settings")),
-                  configSettingsActions));
+        Privilege(ResourcePattern::forDatabaseName("config"), clusterManagerRoleDatabaseActions));
+    Privilege::addPrivilegeToPrivilegeVector(
+        privileges,
+        Privilege(ResourcePattern::forDatabaseName("local"), clusterManagerRoleDatabaseActions));
+
     Privilege::addPrivilegeToPrivilegeVector(
         privileges,
         Privilege(ResourcePattern::forExactNamespace(NamespaceString("local", "system.replset")),
                   readRoleActions));
+    addReadOnlyDbPrivileges(privileges, "config");
+
+    ActionSet writeActions;
+    writeActions << ActionType::insert << ActionType::update << ActionType::remove;
     Privilege::addPrivilegeToPrivilegeVector(
-        privileges,
-        Privilege(ResourcePattern::forExactNamespace(NamespaceString("config", "tags")),
-                  configSettingsActions));
+        privileges, Privilege(ResourcePattern::forDatabaseName("config"), writeActions));
+    Privilege::addPrivilegeToPrivilegeVector(
+        privileges, Privilege(ResourcePattern::forDatabaseName("local"), writeActions));
 }
 
 void addClusterAdminPrivileges(PrivilegeVector* privileges) {
@@ -433,6 +440,12 @@ void addBackupPrivileges(PrivilegeVector* privileges) {
     Privilege::addPrivilegeToPrivilegeVector(
         privileges, Privilege(ResourcePattern::forClusterResource(), clusterActions));
 
+    Privilege::addPrivilegeToPrivilegeVector(
+        privileges, Privilege(ResourcePattern::forDatabaseName("config"), ActionType::find));
+
+    Privilege::addPrivilegeToPrivilegeVector(
+        privileges, Privilege(ResourcePattern::forDatabaseName("local"), ActionType::find));
+
     Privilege::addPrivilegeToPrivilegeVector(
         privileges,
         Privilege(ResourcePattern::forCollectionName("system.indexes"), ActionType::find));
@@ -503,6 +516,12 @@ void addRestorePrivileges(PrivilegeVector* privileges) {
     Privilege::addPrivilegeToPrivilegeVector(
         privileges, Privilege(ResourcePattern::forAnyResource(), ActionType::listCollections));
 
+    Privilege::addPrivilegeToPrivilegeVector(
+        privileges, Privilege(ResourcePattern::forDatabaseName("config"), actions));
+
+    Privilege::addPrivilegeToPrivilegeVector(
+        privileges, Privilege(ResourcePattern::forDatabaseName("local"), actions));
+
     // Privileges for user/role management
     Privilege::addPrivilegeToPrivilegeVector(
         privileges, Privilege(ResourcePattern::forAnyNormalResource(), userAdminRoleActions));
@@ -560,6 +579,7 @@ void addRootRolePrivileges(PrivilegeVector* privileges) {
     addUserAdminAnyDbPrivileges(privileges);
     addDbAdminAnyDbPrivileges(privileges);
     addReadWriteAnyDbPrivileges(privileges);
+    addBackupPrivileges(privileges);
     addRestorePrivileges(privileges);
     Privilege::addPrivilegeToPrivilegeVector(
         privileges, Privilege(ResourcePattern::forAnyResource(), ActionType::validate));
