@@ -218,6 +218,11 @@ public:
             return false;
         }
 
+        if (!NamespaceString(ns).isValid()) {
+            errmsg = "invalid namespace";
+            return false;
+        }
+
         BSONObj startingFromKey;
         if (!FieldParser::extract(cmdObj, startingFromKeyField, &startingFromKey, &errmsg)) {
             return false;
@@ -263,6 +268,12 @@ public:
             return false;
         }
 
+        if (shardingState->migrationSourceManager()->isActive()) {
+            errmsg = str::stream() << "Unable to cleanup orphaned documents because there is an "
+                                   << "active migration";
+            return false;
+        }
+
         ChunkVersion shardVersion;
         status = shardingState->refreshMetadataNow(txn, ns, &shardVersion);
         if (!status.isOK()) {
