@@ -232,6 +232,8 @@ public:
         PlanSummaryStats stats;
         Explain::getSummaryStats(*executor.getValue(), &stats);
         collection->infoCache()->notifyOfQuery(txn, stats.indexesUsed);
+        CurOp::get(txn)->debug().fromMultiPlanner = stats.fromMultiPlanner;
+        CurOp::get(txn)->debug().replanned = stats.replanned;
 
         verify(start == bb.buf());
 
