@@ -619,6 +619,7 @@ bool LockManager::unlock(LockRequest* request) {
     } else if (request->status == LockRequest::STATUS_CONVERTING) {
         // This cancels a pending convert request
         invariant(request->recursiveCount > 0);
+        invariant(lock->conversionsCount > 0);
 
         // Lock only goes from GRANTED to CONVERTING, so cancelling the conversion request
         // brings it back to the previous granted mode.
@@ -753,6 +754,7 @@ void LockManager::_onLockModeChanged(LockHead* lock, bool checkConflictQueue) {
 
     LockRequest* iterNext = NULL;
 
+    bool newlyCompatibleFirst = false;  // Set on enabling compatibleFirst mode.
     for (LockRequest* iter = lock->conflictList._front; (iter != NULL) && checkConflictQueue;
          iter = iterNext) {
         invariant(iter->status == LockRequest::STATUS_WAITING);
@@ -764,11 +766,11 @@ void LockManager::_onLockModeChanged(LockHead* lock, bool checkConflictQueue) {
         if (conflicts(iter->mode, lock->grantedModes)) {
             // If iter doesn't have a previous pointer, this means that it is at the front of the
             // queue. If we continue scanning the queue beyond this point, we will starve it by
-            // granting more and more requests.
-            if (!iter->prev) {
+            // granting more and more requests. However, if we newly transition to compatibleFirst
+            // mode, grant any waiting compatible requests.
+            if (!iter->prev && !newlyCompatibleFirst) {
                 break;
             }
-
             continue;
         }
 
@@ -781,13 +783,13 @@ void LockManager::_onLockModeChanged(LockHead* lock, bool checkConflictQueue) {
         lock->decConflictModeCount(iter->mode);
 
         if (iter->compatibleFirst) {
-            lock->compatibleFirstCount++;
+            newlyCompatibleFirst |= (lock->compatibleFirstCount++ == 0);
         }
 
         iter->notify->notify(lock->resourceId, LOCK_OK);
 
-        // Small optimization - nothing is compatible with MODE_X, so no point in looking
-        // further in the conflict queue.
+        // Small optimization - nothing is compatible with a newly granted MODE_X, so no point in
+        // looking further in the conflict queue. Conflicting MODE_X requests are skipped above.
         if (iter->mode == MODE_X) {
             break;
         }
