@@ -48,6 +48,7 @@
 #include "mongo/db/auth/authorization_manager.h"
 #include "mongo/db/auth/authorization_manager_global.h"
 #include "mongo/db/catalog/collection.h"
+#include "mongo/db/catalog/collection_catalog_entry.h"
 #include "mongo/db/catalog/database.h"
 #include "mongo/db/catalog/database_catalog_entry.h"
 #include "mongo/db/catalog/database_holder.h"
@@ -56,8 +57,11 @@
 #include "mongo/db/client.h"
 #include "mongo/db/clientcursor.h"
 #include "mongo/db/concurrency/d_concurrency.h"
+#include "mongo/db/concurrency/lock_state.h"
+#include "mongo/db/concurrency/write_conflict_exception.h"
 #include "mongo/db/db_raii.h"
 #include "mongo/db/dbdirectclient.h"
+#include "mongo/db/dbhelpers.h"
 #include "mongo/db/dbmessage.h"
 #include "mongo/db/dbwebserver.h"
 #include "mongo/db/ftdc/ftdc_mongod.h"
@@ -145,6 +149,11 @@ void (*snmpInit)() = NULL;
 
 extern int diagLogging;
 
+namespace {
+
+const NamespaceString startupLogCollectionName("local.startup_log");
+const NamespaceString kSystemReplSetCollection("local.system.replset");
+
 #ifdef _WIN32
 ntservice::NtServiceDefaultStrings defaultServiceStrings = {
     L"MongoDB", L"MongoDB", L"MongoDB Server"};
@@ -209,7 +218,7 @@ public:
     }
 };
 
-static void logStartup(OperationContext* txn) {
+void logStartup(OperationContext* txn) {
     BSONObjBuilder toLog;
     stringstream id;
     id << getHostNameCached() << "-" << jsTime().asInt64();
@@ -232,25 +241,24 @@ static void logStartup(OperationContext* txn) {
 
     ScopedTransaction transaction(txn, MODE_X);
     Lock::GlobalWrite lk(txn->lockState());
-    AutoGetOrCreateDb autoDb(txn, "local", mongo::MODE_X);
+    AutoGetOrCreateDb autoDb(txn, startupLogCollectionName.db(), mongo::MODE_X);
     Database* db = autoDb.getDb();
-    const std::string ns = "local.startup_log";
-    Collection* collection = db->getCollection(ns);
+    Collection* collection = db->getCollection(startupLogCollectionName);
     WriteUnitOfWork wunit(txn);
     if (!collection) {
         BSONObj options = BSON("capped" << true << "size" << 10 * 1024 * 1024);
         bool shouldReplicateWrites = txn->writesAreReplicated();
         txn->setReplicatedWrites(false);
         ON_BLOCK_EXIT(&OperationContext::setReplicatedWrites, txn, shouldReplicateWrites);
-        uassertStatusOK(userCreateNS(txn, db, ns, options));
-        collection = db->getCollection(ns);
+        uassertStatusOK(userCreateNS(txn, db, startupLogCollectionName.ns(), options));
+        collection = db->getCollection(startupLogCollectionName);
     }
     invariant(collection);
     uassertStatusOK(collection->insertDocument(txn, o, false));
     wunit.commit();
 }
 
-static void checkForIdIndexes(OperationContext* txn, Database* db) {
+void checkForIdIndexes(OperationContext* txn, Database* db) {
     if (db->name() == "local") {
         // we do not need an _id index on anything in the local database
         return;
@@ -288,18 +296,100 @@ static void checkForIdIndexes(OperationContext* txn, Database* db) {
  * @returns the number of documents in local.system.replset or 0 if this was started with
  *          --replset.
  */
-static unsigned long long checkIfReplMissingFromCommandLine(OperationContext* txn) {
-    // This is helpful for the query below to work as you can't open files when readlocked
-    ScopedTransaction transaction(txn, MODE_X);
-    Lock::GlobalWrite lk(txn->lockState());
+unsigned long long checkIfReplMissingFromCommandLine(OperationContext* txn) {
     if (!repl::getGlobalReplicationCoordinator()->getSettings().usingReplSets()) {
         DBDirectClient c(txn);
-        return c.count("local.system.replset");
+        return c.count(kSystemReplSetCollection.ns());
     }
     return 0;
 }
 
-static void repairDatabasesAndCheckVersion(OperationContext* txn) {
+/**
+ * Due to SERVER-23274, versions 3.2.0 through 3.2.4 of MongoDB incorrectly mark the final output
+ * collections of aggregations with $out stages as temporary on most replica set secondaries. Rather
+ * than risk deleting collections that the user did not intend to be temporary when newer nodes
+ * start up or get promoted to be replica set primaries, newer nodes clear the temp flags left by
+ * these versions.
+ */
+bool isSubjectToSERVER23299(OperationContext* txn) {
+    dbHolder().openDb(txn, startupLogCollectionName.db());
+    AutoGetCollectionForRead autoColl(txn, startupLogCollectionName);
+    // No startup log or an empty one means either that the user was not running an affected
+    // version, or that they manually deleted the startup collection since they last started an
+    // affected version.
+    LOG(1) << "Checking node for SERVER-23299 eligibility";
+    if (!autoColl.getCollection()) {
+        LOG(1) << "Didn't find " << startupLogCollectionName;
+        return false;
+    }
+    LOG(1) << "Checking node for SERVER-23299 applicability - reading startup log";
+    BSONObj lastStartupLogDoc;
+    if (!Helpers::getLast(txn, startupLogCollectionName.ns().c_str(), lastStartupLogDoc)) {
+        return false;
+    }
+    std::vector<int> versionComponents;
+    try {
+        for (auto elem : lastStartupLogDoc["buildinfo"]["versionArray"].Obj()) {
+            versionComponents.push_back(elem.Int());
+        }
+        uassert(40050,
+                str::stream() << "Expected three elements in buildinfo.versionArray; found "
+                              << versionComponents.size(),
+                versionComponents.size() >= 3);
+    } catch (const DBException& ex) {
+        log() << "Last entry of " << startupLogCollectionName
+              << " has no well-formed  buildinfo.versionArray field; ignoring " << causedBy(ex);
+        return false;
+    }
+    LOG(1)
+        << "Checking node for SERVER-23299 applicability - checking version 3.2.x for x in [0, 4]";
+    if (versionComponents[0] != 3)
+        return false;
+    if (versionComponents[1] != 2)
+        return false;
+    if (versionComponents[2] > 4)
+        return false;
+    LOG(1) << "Node eligible for SERVER-23299";
+    return true;
+}
+
+void handleSERVER23299ForDb(OperationContext* txn, Database* db) {
+    log() << "Scanning " << db->name() << " db for SERVER-23299 eligibility";
+    const auto dbEntry = db->getDatabaseCatalogEntry();
+    list<string> collNames;
+    dbEntry->getCollectionNamespaces(&collNames);
+    for (const auto& collName : collNames) {
+        const auto collEntry = dbEntry->getCollectionCatalogEntry(collName);
+        const auto collOptions = collEntry->getCollectionOptions(txn);
+        if (!collOptions.temp)
+            continue;
+        log() << "Marking collection " << collName << " as permanent per SERVER-23299";
+        MONGO_WRITE_CONFLICT_RETRY_LOOP_BEGIN {
+            WriteUnitOfWork wuow(txn);
+            collEntry->clearTempFlag(txn);
+            wuow.commit();
+        }
+        MONGO_WRITE_CONFLICT_RETRY_LOOP_END(txn, "repair SERVER-23299", collEntry->ns().ns());
+    }
+    log() << "Done scanning " << db->name() << " for SERVER-23299 eligibility";
+}
+
+/**
+ * Check that the oplog is capped, and abort the process if it is not.
+ * Caller must lock DB before calling this function.
+ */
+void checkForCappedOplog(OperationContext* txn, Database* db) {
+    const NamespaceString oplogNss(repl::rsOplogName);
+    invariant(txn->lockState()->isDbLockedForMode(oplogNss.db(), MODE_IS));
+    Collection* oplogCollection = db->getCollection(oplogNss);
+    if (oplogCollection && !oplogCollection->isCapped()) {
+        severe() << "The oplog collection " << oplogNss
+                 << " is not capped; a capped oplog is a requirement for replication to function.";
+        fassertFailedNoTrace(40116);
+    }
+}
+
+void repairDatabasesAndCheckVersion(OperationContext* txn) {
     LOG(1) << "enter repairDatabases (to check pdfile version #)" << endl;
 
     ScopedTransaction transaction(txn, MODE_X);
@@ -307,7 +397,7 @@ static void repairDatabasesAndCheckVersion(OperationContext* txn) {
 
     vector<string> dbNames;
 
-    StorageEngine* storageEngine = getGlobalServiceContext()->getGlobalStorageEngine();
+    StorageEngine* storageEngine = txn->getServiceContext()->getGlobalStorageEngine();
     storageEngine->listDatabases(&dbNames);
 
     // Repair all databases first, so that we do not try to open them if they are in bad shape
@@ -322,6 +412,13 @@ static void repairDatabasesAndCheckVersion(OperationContext* txn) {
 
     const repl::ReplSettings& replSettings = repl::getGlobalReplicationCoordinator()->getSettings();
 
+    // We open the "local" database before calling checkIfReplMissingFromCommandLine() to ensure the
+    // in-memory catalog entries for the 'kSystemReplSetCollection' collection have been populated
+    // if the collection exists. If the "local" database didn't exist at this point yet, then it
+    // will be created.
+    Lock::DBLock dbLock(txn->lockState(), kSystemReplSetCollection.db(), MODE_X);
+    dbHolder().openDb(txn, kSystemReplSetCollection.db());
+
     // On replica set members we only clear temp collections on DBs other than "local" during
     // promotion to primary. On pure slaves, they are only cleared when the oplog tells them
     // to. The local DB is special because it is not replicated.  See SERVER-10927 for more
@@ -330,6 +427,8 @@ static void repairDatabasesAndCheckVersion(OperationContext* txn) {
         !(checkIfReplMissingFromCommandLine(txn) || replSettings.usingReplSets() ||
           replSettings.isSlave());
 
+    const bool shouldDoCleanupForSERVER23299 = isSubjectToSERVER23299(txn);
+
     for (vector<string>::const_iterator i = dbNames.begin(); i != dbNames.end(); ++i) {
         const string dbName = *i;
         LOG(1) << "    Recovering database: " << dbName << endl;
@@ -339,10 +438,17 @@ static void repairDatabasesAndCheckVersion(OperationContext* txn) {
 
         // First thing after opening the database is to check for file compatibility,
         // otherwise we might crash if this is a deprecated format.
-        if (!db->getDatabaseCatalogEntry()->currentFilesCompatible(txn)) {
-            log() << "****";
-            log() << "cannot do this upgrade without an upgrade in the middle";
-            log() << "please do a --repair with 2.6 and then start this version";
+        auto status = db->getDatabaseCatalogEntry()->currentFilesCompatible(txn);
+        if (!status.isOK()) {
+            if (status.code() == ErrorCodes::CanRepairToDowngrade) {
+                // Convert CanRepairToDowngrade statuses to MustUpgrade statuses to avoid logging a
+                // potentially confusing and inaccurate message.
+                status = {ErrorCodes::MustUpgrade, status.reason()};
+            }
+            severe() << "Unable to start mongod due to an incompatibility with the data files and"
+                        " this version of mongod: " << status;
+            severe() << "Please consult our documentation when trying to downgrade to a previous"
+                        " major release";
             dbexit(EXIT_NEED_UPGRADE);
             return;
         }
@@ -396,6 +502,15 @@ static void repairDatabasesAndCheckVersion(OperationContext* txn) {
         if (replSettings.usingReplSets()) {
             // We only care about the _id index if we are in a replset
             checkForIdIndexes(txn, db);
+            // Ensure oplog is capped (mmap does not guarantee order of inserts on noncapped
+            // collections)
+            if (db->name() == "local") {
+                checkForCappedOplog(txn, db);
+            }
+        }
+
+        if (shouldDoCleanupForSERVER23299) {
+            handleSERVER23299ForDb(txn, db);
         }
 
         if (shouldClearNonLocalTmpCollections || dbName == "local") {
@@ -403,10 +518,19 @@ static void repairDatabasesAndCheckVersion(OperationContext* txn) {
         }
     }
 
+    // We may have features enabled on a collection or index in the data files that are recognized
+    // by this version of mongod in order to support downgrading to an earlier version of the same
+    // major release or an earlier major release. Some features may require user-intervention in
+    // order to continue starting up, but a more descriptive error message is provided to the user.
+    // Other features may be able to automatically downconvert the data files and be disabled. In
+    // either case, we only start up if we can guarantee it'd be possible to continue downgrading to
+    // earlier versions of mongod.
+    fassert(40115, storageEngine->requireDataFileCompatibilityWithPriorRelease(txn));
+
     LOG(1) << "done repairDatabases" << endl;
 }
 
-static void _initWireSpec() {
+void _initWireSpec() {
     WireSpec& spec = WireSpec::instance();
     // accept from any version
     spec.minWireVersionIncoming = RELEASE_2_4_AND_BEFORE;
@@ -416,8 +540,7 @@ static void _initWireSpec() {
     spec.maxWireVersionOutgoing = FIND_COMMAND;
 }
 
-
-static void _initAndListen(int listenPort) {
+void _initAndListen(int listenPort) {
     Client::initThread("initandlisten");
 
     _initWireSpec();
@@ -453,7 +576,8 @@ static void _initAndListen(int listenPort) {
     options.port = listenPort;
     options.ipList = serverGlobalParams.bind_ip;
 
-    MessageServer* server = createServer(options, new MyMessageHandler());
+    auto handler = std::make_shared<MyMessageHandler>();
+    MessageServer* server = createServer(options, std::move(handler));
     server->setAsTimeTracker();
 
     // This is what actually creates the sockets, but does not yet listen on them because we
@@ -581,33 +705,49 @@ static void _initAndListen(int listenPort) {
 #ifndef _WIN32
         mongo::signalForkSuccess();
 #endif
+        AuthorizationManager* globalAuthzManager = getGlobalAuthorizationManager();
+        if (globalAuthzManager->shouldValidateAuthSchemaOnStartup()) {
+            Status status = authindex::verifySystemIndexes(startupOpCtx.get());
+            if (!status.isOK()) {
+                log() << status.reason();
+                exitCleanly(EXIT_NEED_UPGRADE);
+            }
 
-        Status status = authindex::verifySystemIndexes(startupOpCtx.get());
-        if (!status.isOK()) {
-            log() << status.reason();
-            exitCleanly(EXIT_NEED_UPGRADE);
+            // SERVER-14090: Verify that auth schema version is schemaVersion26Final.
+            int foundSchemaVersion;
+            status = globalAuthzManager->getAuthorizationVersion(startupOpCtx.get(),
+                                                                 &foundSchemaVersion);
+            if (!status.isOK()) {
+                log() << "Auth schema version is incompatible: "
+                      << "User and role management commands require auth data to have "
+                      << "at least schema version " << AuthorizationManager::schemaVersion26Final
+                      << " but startup could not verify schema version: " << status.toString()
+                      << endl;
+                exitCleanly(EXIT_NEED_UPGRADE);
+            }
+            if (foundSchemaVersion < AuthorizationManager::schemaVersion26Final) {
+                log() << "Auth schema version is incompatible: "
+                      << "User and role management commands require auth data to have "
+                      << "at least schema version " << AuthorizationManager::schemaVersion26Final
+                      << " but found " << foundSchemaVersion << ". In order to upgrade "
+                      << "the auth schema, first downgrade MongoDB binaries to version "
+                      << "2.6 and then run the authSchemaUpgrade command." << endl;
+                exitCleanly(EXIT_NEED_UPGRADE);
+            }
+        } else if (globalAuthzManager->isAuthEnabled()) {
+            error() << "Auth must be disabled when starting without auth schema validation";
+            exitCleanly(EXIT_BADOPTIONS);
+        } else {
+            // If authSchemaValidation is disabled and server is running without auth,
+            // warn the user and continue startup without authSchema metadata checks.
+            log() << startupWarningsLog;
+            log() << "** WARNING: Startup auth schema validation checks are disabled for the "
+                     "database." << startupWarningsLog;
+            log() << "**          This mode should only be used to manually repair corrupted auth "
+                     "data." << startupWarningsLog;
         }
 
-        // SERVER-14090: Verify that auth schema version is schemaVersion26Final.
-        int foundSchemaVersion;
-        status = getGlobalAuthorizationManager()->getAuthorizationVersion(startupOpCtx.get(),
-                                                                          &foundSchemaVersion);
-        if (!status.isOK()) {
-            log() << "Auth schema version is incompatible: "
-                  << "User and role management commands require auth data to have "
-                  << "at least schema version " << AuthorizationManager::schemaVersion26Final
-                  << " but startup could not verify schema version: " << status.toString() << endl;
-            exitCleanly(EXIT_NEED_UPGRADE);
-        }
-        if (foundSchemaVersion < AuthorizationManager::schemaVersion26Final) {
-            log() << "Auth schema version is incompatible: "
-                  << "User and role management commands require auth data to have "
-                  << "at least schema version " << AuthorizationManager::schemaVersion26Final
-                  << " but found " << foundSchemaVersion << ". In order to upgrade "
-                  << "the auth schema, first downgrade MongoDB binaries to version "
-                  << "2.6 and then run the authSchemaUpgrade command." << endl;
-            exitCleanly(EXIT_NEED_UPGRADE);
-        }
+        logStartup(startupOpCtx.get());
 
         getDeleter()->startWorkers();
 
@@ -645,8 +785,6 @@ static void _initAndListen(int listenPort) {
         uassertStatusOK(ShardingStateRecovery::recover(startupOpCtx.get()));
     }
 
-    logStartup(startupOpCtx.get());
-
     // MessageServer::run will return when exit code closes its socket and we don't need the
     // operation context anymore
     startupOpCtx.reset();
@@ -673,6 +811,8 @@ ExitCode initAndListen(int listenPort) {
     }
 }
 
+}  // namespace
+
 #if defined(_WIN32)
 ExitCode initService() {
     ntservice::reportStatus(SERVICE_RUNNING);
