@@ -343,7 +343,7 @@ long long Helpers::removeRange(OperationContext* txn,
     while (1) {
         // Scoping for write lock.
         {
-            OldClientWriteContext ctx(txn, ns);
+            AutoGetCollection ctx(txn, NamespaceString(ns), MODE_IX);
             Collection* collection = ctx.getCollection();
             if (!collection)
                 break;
@@ -351,6 +351,12 @@ long long Helpers::removeRange(OperationContext* txn,
             IndexDescriptor* desc =
                 collection->getIndexCatalog()->findIndexByKeyPattern(txn, indexKeyPattern.toBSON());
 
+            if (!desc) {
+                warning(LogComponent::kSharding) << "shard key index " << indexKeyPattern.toBSON()
+                                                 << " on '" << ns << "' was dropped";
+                return -1;
+            }
+
             unique_ptr<PlanExecutor> exec(
                 InternalPlanner::indexScan(txn,
                                            collection,
