@@ -669,8 +669,8 @@ void receivedUpdate(OperationContext* txn, const NamespaceString& nsString, Mess
         op.setQuery_inlock(query);
     }
 
-    Status status =
-        AuthorizationSession::get(client)->checkAuthForUpdate(nsString, query, toupdate, upsert);
+    Status status = AuthorizationSession::get(client)
+                        ->checkAuthForUpdate(txn, nsString, query, toupdate, upsert);
     audit::logUpdateAuthzCheck(client, nsString, query, toupdate, upsert, multi, status.code());
     uassertStatusOK(status);
 
@@ -818,7 +818,7 @@ void receivedDelete(OperationContext* txn, const NamespaceString& nsString, Mess
         op.setNS_inlock(nsString.ns());
     }
 
-    Status status = AuthorizationSession::get(client)->checkAuthForDelete(nsString, pattern);
+    Status status = AuthorizationSession::get(client)->checkAuthForDelete(txn, nsString, pattern);
     audit::logDeleteAuthzCheck(client, nsString, pattern, status.code());
     uassertStatusOK(status);
 
@@ -858,6 +858,8 @@ void receivedDelete(OperationContext* txn, const NamespaceString& nsString, Mess
             PlanSummaryStats summary;
             Explain::getSummaryStats(*exec, &summary);
             collection->infoCache()->notifyOfQuery(txn, summary.indexesUsed);
+            op.debug().fromMultiPlanner = summary.fromMultiPlanner;
+            op.debug().replanned = summary.replanned;
 
             if (repl::ReplClientInfo::forClient(client).getLastOp() != lastOpAtOperationStart) {
                 // If this operation has already generated a new lastOp, don't bother setting it
@@ -884,7 +886,7 @@ bool receivedGetMore(OperationContext* txn, DbResponse& dbresponse, Message& m,
     curop.debug().cursorid = cursorid;
 
     {
-        stdx::lock_guard<Client>(*txn->getClient());
+        stdx::lock_guard<Client> lk(*txn->getClient());
         CurOp::get(txn)->setNS_inlock(ns);
     }
 
@@ -1156,7 +1158,7 @@ void receivedInsert(OperationContext* txn, const NamespaceString& nsString, Mess
     DbMessage d(m);
     const char* ns = d.getns();
     {
-        stdx::lock_guard<Client>(*txn->getClient());
+        stdx::lock_guard<Client> lk(*txn->getClient());
         CurOp::get(txn)->setNS_inlock(nsString.ns());
     }
 
@@ -1179,7 +1181,7 @@ void receivedInsert(OperationContext* txn, const NamespaceString& nsString, Mess
         // Check auth for insert (also handles checking if this is an index build and checks
         // for the proper privileges in that case).
         Status status =
-            AuthorizationSession::get(txn->getClient())->checkAuthForInsert(nsString, obj);
+            AuthorizationSession::get(txn->getClient())->checkAuthForInsert(txn, nsString, obj);
         audit::logInsertAuthzCheck(txn->getClient(), nsString, obj, status.code());
         uassertStatusOK(status);
     }
@@ -1243,13 +1245,18 @@ static void shutdownServer() {
 stdx::mutex shutdownLock;
 
 void signalShutdown() {
-    // Notify all threads shutdown has started
+    // This call chain uses its own locker directly because it isn't always called in a context that
+    // already has one, and is illegal to call while holding any locks.
+    DefaultLockerImpl locker;
+
+    // Notify all threads shutdown has started. This is done while holding the PBWM lock to
+    // ensure that replication isn't mid-batch to avoid SERVER-24933.
+    Lock::ResourceLock pbwm(&locker, resourceIdParallelBatchWriterMode, MODE_IS);
     shutdownInProgress.fetchAndAdd(1);
 }
 
 void exitCleanly(ExitCode code) {
-    // Notify all threads shutdown has started
-    shutdownInProgress.fetchAndAdd(1);
+    signalShutdown();
 
     // Grab the shutdown lock to prevent concurrent callers
     stdx::lock_guard<stdx::mutex> lockguard(shutdownLock);
@@ -1266,8 +1273,6 @@ void exitCleanly(ExitCode code) {
 
     getGlobalServiceContext()->setKillAllOperations();
 
-    repl::getGlobalReplicationCoordinator()->shutdown();
-
     Client& client = cc();
     ServiceContext::UniqueOperationContext uniqueTxn;
     OperationContext* txn = client.getOperationContext();
@@ -1276,6 +1281,8 @@ void exitCleanly(ExitCode code) {
         txn = uniqueTxn.get();
     }
 
+
+    repl::getGlobalReplicationCoordinator()->shutdown(txn);
     ShardingState::get(txn)->shutDown(txn);
 
     // We should always be able to acquire the global lock at shutdown.
