@@ -119,6 +119,33 @@ TEST(SimpleMod, PrepareNoOp) {
     ASSERT_TRUE(execInfo.noOp);
 }
 
+TEST(SimpleMod, PrepareNotNoOp) {
+    Document doc(fromjson("{a: NumberInt(2)}"));
+    Mod setMod(fromjson("{$set: {a: NumberLong(2)}}"));
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(setMod.prepare(doc.root(), "", &execInfo));
+
+    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a");
+    ASSERT_FALSE(execInfo.noOp);
+}
+
+TEST(SimpleMod, PrepareIdentityOpOnDeserializedIsNotANoOp) {
+    Document doc(fromjson("{a: { b: NumberInt(0)}}"));
+
+    // Apply a mutation to the document that will make it non-serialized.
+    doc.root()["a"]["b"].setValueInt(2);
+
+    // Apply an op that would be a no-op.
+    Mod setMod(fromjson("{$set: {a: {b : NumberInt(2)}}}"));
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(setMod.prepare(doc.root(), "", &execInfo));
+
+    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a");
+    ASSERT_FALSE(execInfo.noOp);
+}
+
 TEST(SimpleMod, PrepareSetOnInsert) {
     Document doc(fromjson("{a: 1}"));
     Mod setMod(fromjson("{$setOnInsert: {a: 2}}"));
@@ -236,6 +263,17 @@ TEST(DottedMod, PrepareNoOp) {
     ASSERT_TRUE(execInfo.noOp);
 }
 
+TEST(DottedMod, PrepareNotNoOp) {
+    Document doc(fromjson("{a: {b: NumberLong(2)}}"));
+    Mod setMod(fromjson("{$set: {'a.b': NumberInt(2)}}"));
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(setMod.prepare(doc.root(), "", &execInfo));
+
+    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a.b");
+    ASSERT_FALSE(execInfo.noOp);
+}
+
 TEST(DottedMod, PreparePathNotViable) {
     Document doc(fromjson("{a:1}"));
     Mod setMod(fromjson("{$set: {'a.b': 2}}"));
@@ -372,6 +410,17 @@ TEST(IndexedMod, PrepareNoOp) {
     ASSERT_TRUE(execInfo.noOp);
 }
 
+TEST(IndexedMod, PrepareNotNoOp) {
+    Document doc(fromjson("{a: [{b: 0},{b: 1},{b: 2.0}]}"));
+    Mod setMod(fromjson("{$set: {'a.2.b': NumberInt(2)}}"));
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(setMod.prepare(doc.root(), "", &execInfo));
+
+    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a.2.b");
+    ASSERT_FALSE(execInfo.noOp);
+}
+
 TEST(IndexedMod, PrepareNonViablePath) {
     Document doc(fromjson("{a: 0}"));
     Mod setMod(fromjson("{$set: {'a.2.b': 2}}"));
