@@ -42,7 +42,6 @@
 #include "mongo/db/db_raii.h"
 #include "mongo/db/exec/filter.h"
 #include "mongo/db/exec/working_set_common.h"
-#include "mongo/db/service_context.h"
 #include "mongo/db/keypattern.h"
 #include "mongo/db/matcher/extensions_callback_real.h"
 #include "mongo/db/query/explain.h"
@@ -54,6 +53,7 @@
 #include "mongo/db/s/sharding_state.h"
 #include "mongo/db/server_options.h"
 #include "mongo/db/server_parameters.h"
+#include "mongo/db/service_context.h"
 #include "mongo/db/storage/storage_options.h"
 #include "mongo/s/chunk_version.h"
 #include "mongo/s/stale_exception.h"
@@ -157,6 +157,8 @@ void endQueryOp(OperationContext* txn,
     curop->debug().keysExamined = summaryStats.totalKeysExamined;
     curop->debug().docsExamined = summaryStats.totalDocsExamined;
     curop->debug().idhack = summaryStats.isIdhack;
+    curop->debug().fromMultiPlanner = summaryStats.fromMultiPlanner;
+    curop->debug().replanned = summaryStats.replanned;
 
     if (collection) {
         collection->infoCache()->notifyOfQuery(txn, summaryStats.indexesUsed);
@@ -169,7 +171,7 @@ void endQueryOp(OperationContext* txn,
     if (dbProfilingLevel > 0 || curop->elapsedMillis() > serverGlobalParams.slowMS ||
         logger::globalLogDomain()->shouldLog(commandLogComponent, logLevelOne)) {
         // Generate plan summary string.
-        stdx::lock_guard<Client>(*txn->getClient());
+        stdx::lock_guard<Client> lk(*txn->getClient());
         curop->setPlanSummary_inlock(Explain::getPlanSummary(&exec));
     }
 
@@ -384,6 +386,19 @@ QueryResult::View getMore(OperationContext* txn,
         PlanExecutor* exec = cc->getExecutor();
         exec->reattachToOperationContext(txn);
         exec->restoreState();
+
+        auto planSummary = Explain::getPlanSummary(exec);
+        {
+            stdx::lock_guard<Client> lk(*txn->getClient());
+            curop.setPlanSummary_inlock(planSummary);
+        }
+
+        // We report keysExamined and docsExamined to OpDebug for a given getMore operation. To
+        // obtain these values we need to take a diff of the pre-execution and post-execution
+        // metrics, as they accumulate over the course of a cursor's lifetime.
+        PlanSummaryStats preExecutionStats;
+        Explain::getSummaryStats(*exec, &preExecutionStats);
+
         PlanExecutor::ExecState state;
 
         generateBatch(ntoreturn, cc, &bb, &numResults, &slaveReadTill, &state);
@@ -413,6 +428,13 @@ QueryResult::View getMore(OperationContext* txn,
             generateBatch(ntoreturn, cc, &bb, &numResults, &slaveReadTill, &state);
         }
 
+        PlanSummaryStats postExecutionStats;
+        Explain::getSummaryStats(*exec, &postExecutionStats);
+        curop.debug().keysExamined =
+            postExecutionStats.totalKeysExamined - preExecutionStats.totalKeysExamined;
+        curop.debug().docsExamined =
+            postExecutionStats.totalDocsExamined - preExecutionStats.totalDocsExamined;
+
         // We have to do this before re-acquiring locks in the agg case because
         // shouldSaveCursorGetMore() can make a network call for agg cursors.
         //
@@ -503,13 +525,38 @@ std::string runQuery(OperationContext* txn,
     LOG(5) << "Running query:\n" << cq->toString();
     LOG(2) << "Running query: " << cq->toStringShort();
 
+    ShardingState* const shardingState = ShardingState::get(txn);
+
     // Parse, canonicalize, plan, transcribe, and get a plan executor.
-    AutoGetCollectionForRead ctx(txn, nss);
+    boost::optional<AutoGetCollectionForRead> optionalCtx;
+    try {
+        optionalCtx.emplace(txn, nss);
+    } catch (const StaleConfigException& sce) {
+        // Wait for migration completion to get the correct chunk version
+        const int maxTimeoutSec = 30;
+        int timeoutSec = cq->getParsed().getMaxTimeMS() / 1000;
+        if (!timeoutSec || timeoutSec > maxTimeoutSec) {
+            timeoutSec = maxTimeoutSec;
+        }
+
+        if (shardingState->waitTillNotInCriticalSection(maxTimeoutSec)) {
+            ChunkVersion unused;
+            shardingState->refreshMetadataIfNeeded(
+                txn, nss.ns(), sce.getVersionReceived(), &unused);
+        }
+        throw;
+    }
+
+    const auto& ctx = *optionalCtx;
     Collection* collection = ctx.getCollection();
 
     const int dbProfilingLevel =
         ctx.getDb() ? ctx.getDb()->getProfilingLevel() : serverGlobalParams.defaultProfile;
 
+    // It is possible that the sharding version will change during yield while we are retrieving a
+    // plan executor. If this happens we will throw an error and mongos will retry.
+    const ChunkVersion shardingVersionAtStart = shardingState->getVersion(nss.ns());
+
     // We have a parsed query. Time to get the execution plan for it.
     std::unique_ptr<PlanExecutor> exec = uassertStatusOK(
         getExecutorFind(txn, collection, nss, std::move(cq), PlanExecutor::YIELD_AUTO));
@@ -546,11 +593,6 @@ std::string runQuery(OperationContext* txn,
         return "";
     }
 
-    ShardingState* const shardingState = ShardingState::get(txn);
-
-    // We freak out later if this changes before we're done with the query.
-    const ChunkVersion shardingVersionAtStart = shardingState->getVersion(nss.ns());
-
     // Handle query option $maxTimeMS (not used with commands).
     curop.setMaxTimeMicros(static_cast<unsigned long long>(pq.getMaxTimeMS()) * 1000);
     txn->checkForInterrupt();  // May trigger maxTimeAlwaysTimeOut fail point.
