@@ -375,7 +375,7 @@ StatusWith<unique_ptr<LiteParsedQuery>> LiteParsedQuery::makeFromFindCommand(Nam
 
     pq->addMetaProjection();
 
-    Status validateStatus = pq->validateFindCmd();
+    Status validateStatus = pq->validate();
     if (!validateStatus.isOK()) {
         return validateStatus;
     }
@@ -662,6 +662,11 @@ Status LiteParsedQuery::validate() const {
         }
     }
 
+    // AwaitData is only valid with a tailable cursor.
+    if (_awaitData && !_tailable) {
+        return Status(ErrorCodes::BadValue, "Cannot set awaitData without tailable");
+    }
+
     return Status::OK();
 }
 
@@ -975,14 +980,6 @@ void LiteParsedQuery::addMetaProjection() {
     }
 }
 
-Status LiteParsedQuery::validateFindCmd() {
-    if (isAwaitData() && !isTailable()) {
-        return Status(ErrorCodes::BadValue, "Cannot set awaitData without tailable");
-    }
-
-    return validate();
-}
-
 boost::optional<long long> LiteParsedQuery::getEffectiveBatchSize() const {
     return _batchSize ? _batchSize : _ntoreturn;
 }
