@@ -54,7 +54,6 @@
 #include "mongo/db/operation_context_impl.h"
 #include "mongo/db/prefetch.h"
 #include "mongo/db/repl/bgsync.h"
-#include "mongo/db/repl/minvalid.h"
 #include "mongo/db/repl/oplog.h"
 #include "mongo/db/repl/oplogreader.h"
 #include "mongo/db/repl/repl_client_info.h"
@@ -109,6 +108,11 @@ static Counter64 opsAppliedStats;
 // The oplog entries applied
 static ServerStatusMetricField<Counter64> displayOpsApplied("repl.apply.ops", &opsAppliedStats);
 
+// Number of times we tried to go live as a secondary.
+static Counter64 attemptsToBecomeSecondary;
+static ServerStatusMetricField<Counter64> displayAttemptsToBecomeSecondary(
+    "repl.apply.attemptsToBecomeSecondary", &attemptsToBecomeSecondary);
+
 MONGO_FP_DECLARE(rsSyncApplyStop);
 
 // Number and time of each ApplyOps worker pool round
@@ -131,39 +135,6 @@ bool isCrudOpType(const char* field) {
     }
     return false;
 }
-
-void handleSlaveDelay(const Timestamp& ts) {
-    ReplicationCoordinator* replCoord = getGlobalReplicationCoordinator();
-    int slaveDelaySecs = durationCount<Seconds>(replCoord->getSlaveDelaySecs());
-
-    // ignore slaveDelay if the box is still initializing. once
-    // it becomes secondary we can worry about it.
-    if (slaveDelaySecs > 0 && replCoord->getMemberState().secondary()) {
-        long long a = ts.getSecs();
-        long long b = time(0);
-        long long lag = b - a;
-        long long sleeptime = slaveDelaySecs - lag;
-        if (sleeptime > 0) {
-            uassert(12000,
-                    "rs slaveDelay differential too big check clocks and systems",
-                    sleeptime < 0x40000000);
-            if (sleeptime < 60) {
-                sleepsecs((int)sleeptime);
-            } else {
-                warning() << "slavedelay causing a long sleep of " << sleeptime << " seconds";
-                // sleep(hours) would prevent reconfigs from taking effect & such!
-                long long waitUntil = b + sleeptime;
-                while (time(0) < waitUntil) {
-                    sleepsecs(6);
-
-                    // Handle reconfigs that changed the slave delay
-                    if (durationCount<Seconds>(replCoord->getSlaveDelaySecs()) != slaveDelaySecs)
-                        break;
-                }
-            }
-        }
-    }  // endif slaveDelay
-}
 }
 
 namespace {
@@ -284,7 +255,7 @@ bool SyncTail::peek(BSONObj* op) {
 // static
 Status SyncTail::syncApply(OperationContext* txn,
                            const BSONObj& op,
-                           bool convertUpdateToUpsert,
+                           bool inSteadyStateReplication,
                            ApplyOperationInLockFn applyOperationInLock,
                            ApplyCommandInLockFn applyCommandInLock,
                            IncrementOpsAppliedStatsFn incrementOpsAppliedStats) {
@@ -320,7 +291,7 @@ Status SyncTail::syncApply(OperationContext* txn,
             Lock::GlobalWrite globalWriteLock(txn->lockState());
 
             // special case apply for commands to avoid implicit database creation
-            Status status = applyCommandInLock(txn, op);
+            Status status = applyCommandInLock(txn, op, inSteadyStateReplication);
             incrementOpsAppliedStats();
             return status;
         }
@@ -333,7 +304,7 @@ Status SyncTail::syncApply(OperationContext* txn,
         txn->setReplicatedWrites(false);
         DisableDocumentValidation validationDisabler(txn);
 
-        Status status = applyOperationInLock(txn, db, op, convertUpdateToUpsert);
+        Status status = applyOperationInLock(txn, db, op, inSteadyStateReplication);
         if (!status.isOK() && status.code() == ErrorCodes::WriteConflict) {
             throw WriteConflictException();
         }
@@ -362,20 +333,24 @@ Status SyncTail::syncApply(OperationContext* txn,
 
             auto resetLocks = [&](LockMode mode) {
                 collectionLock.reset();
+                // Warning: We must reset the pointer to nullptr first, in order to ensure that we
+                // drop the DB lock before acquiring
+                // the upgraded one.
+                dbLock.reset();
                 dbLock.reset(new Lock::DBLock(txn->lockState(), dbName, mode));
                 collectionLock.reset(new Lock::CollectionLock(txn->lockState(), ns, mode));
             };
 
             resetLocks(MODE_IX);
             if (!dbHolder().get(txn, dbName)) {
-                // need to create database, try again
+                // Need to create database, so reset lock to stronger mode.
                 resetLocks(MODE_X);
                 ctx.reset(new OldClientContext(txn, ns));
             } else {
                 ctx.reset(new OldClientContext(txn, ns));
                 if (!ctx->db()->getCollection(ns)) {
-                    // uh, oh, we need to create collection
-                    // try again
+                    // Need to implicitly create collection.  This occurs for 'u' opTypes,
+                    // but not for 'i' nor 'd'.
                     ctx.reset();
                     resetLocks(MODE_X);
                     ctx.reset(new OldClientContext(txn, ns));
@@ -394,10 +369,12 @@ Status SyncTail::syncApply(OperationContext* txn,
     return Status(ErrorCodes::BadValue, ss);
 }
 
-Status SyncTail::syncApply(OperationContext* txn, const BSONObj& op, bool convertUpdateToUpsert) {
+Status SyncTail::syncApply(OperationContext* txn,
+                           const BSONObj& op,
+                           bool inSteadyStateReplication) {
     return syncApply(txn,
                      op,
-                     convertUpdateToUpsert,
+                     inSteadyStateReplication,
                      applyOperation_inlock,
                      applyCommand_inlock,
                      stdx::bind(&Counter64::increment, &opsAppliedStats, 1ULL));
@@ -549,14 +526,19 @@ OpTime SyncTail::multiApply(OperationContext* txn, const OpQueue& ops) {
     // stop all readers until we're done
     Lock::ParallelBatchWriterMode pbwm(txn->lockState());
 
+    if (inShutdownStrict()) {
+        log() << "Cannot apply operations due to shutdown in progress";
+        return OpTime();
+    }
+
     ReplicationCoordinator* replCoord = getGlobalReplicationCoordinator();
     if (replCoord->getMemberState().primary() && !replCoord->isWaitingForApplierToDrain()) {
         severe() << "attempting to replicate ops while primary";
         fassertFailed(28527);
     }
 
-    applyOps(writerVectors, &_writerPool, _applyFunc, this);
-
+    // Since we write the oplog from a single thread in-order, we don't need to use the
+    // oplogDeleteFromPoint.
     OpTime lastOpTime;
     {
         ON_BLOCK_EXIT([&] { _writerPool.join(); });
@@ -568,23 +550,28 @@ OpTime SyncTail::multiApply(OperationContext* txn, const OpQueue& ops) {
         lastOpTime = writeOpsToOplog(txn, raws);
     }
 
-    if (inShutdownStrict()) {
-        log() << "Cannot apply operations due to shutdown in progress";
-        return OpTime();
-    }
-    // We have now written all database writes and updated the oplog to match.
+    setMinValidToAtLeast(txn, lastOpTime);  // Mark us as in the middle of a batch.
+
+    applyOps(writerVectors, &_writerPool, _applyFunc, this);
+    _writerPool.join();
+
+    // Due to SERVER-24933 we can't enter inShutdown while holding the PBWM lock.
+    invariant(!inShutdownStrict());
+
+    setAppliedThrough(txn, lastOpTime);  // Mark batch as complete.
+
     return lastOpTime;
 }
 
 namespace {
-void tryToGoLiveAsASecondary(OperationContext* txn,
-                             ReplicationCoordinator* replCoord,
-                             const BatchBoundaries& minValidBoundaries,
-                             const OpTime& lastWriteOpTime) {
+void tryToGoLiveAsASecondary(OperationContext* txn, ReplicationCoordinator* replCoord) {
     if (replCoord->isInPrimaryOrSecondaryState()) {
         return;
     }
 
+    // This needs to happen after the attempt so readers can be sure we've already tried.
+    ON_BLOCK_EXIT([] { attemptsToBecomeSecondary.increment(); });
+
     ScopedTransaction transaction(txn, MODE_S);
     Lock::GlobalRead readLock(txn->lockState());
 
@@ -599,15 +586,8 @@ void tryToGoLiveAsASecondary(OperationContext* txn,
         return;
     }
 
-    // If an apply batch is active then we cannot transition.
-    if (!minValidBoundaries.start.isNull()) {
-        return;
-    }
-
-    // Must have applied/written to minvalid, so return if not.
-    // -- If 'lastWriteOpTime' is null/uninitialized then we can't transition.
-    // -- If 'lastWriteOpTime' is less than the end of the last batch then we can't transition.
-    if (lastWriteOpTime.isNull() || minValidBoundaries.end > lastWriteOpTime) {
+    // We can't go to SECONDARY until we reach minvalid.
+    if (replCoord->getMyLastAppliedOpTime() < getMinValid(txn)) {
         return;
     }
 
@@ -623,7 +603,8 @@ class SyncTail::OpQueueBatcher {
     MONGO_DISALLOW_COPYING(OpQueueBatcher);
 
 public:
-    explicit OpQueueBatcher(SyncTail* syncTail) : _syncTail(syncTail), _thread([&] { run(); }) {}
+    explicit OpQueueBatcher(SyncTail* syncTail, StorageInterface* storageInterface)
+        : _syncTail(syncTail), _storageInterface(storageInterface), _thread([&] { run(); }) {}
     ~OpQueueBatcher() {
         _inShutdown.store(true);
         _cv.notify_all();
@@ -651,42 +632,23 @@ private:
         OperationContextImpl txn;
         auto replCoord = ReplicationCoordinator::get(&txn);
 
+        const auto oplogMaxSize = fassertStatusOK(
+            40301, _storageInterface->getOplogMaxSize(&txn, NamespaceString(rsOplogName)));
+
+        // Batches are limited to 10% of the oplog.
+        BatchLimits batchLimits;
+        batchLimits.ops = replBatchLimitOperations;
+        batchLimits.bytes = std::min(oplogMaxSize / 10, size_t(replBatchLimitBytes));
         while (!_inShutdown.load()) {
-            Timer batchTimer;
+            const auto slaveDelay = replCoord->getSlaveDelaySecs();
+            batchLimits.slaveDelayLatestTimestamp = (slaveDelay > Seconds(0))
+                ? (Date_t::now() - slaveDelay)
+                : boost::optional<Date_t>();
 
             OpQueue ops;
-            // tryPopAndWaitForMore returns true when we need to end a batch early
-            while (!_syncTail->tryPopAndWaitForMore(&txn, &ops) &&
-                   (ops.getSize() < replBatchLimitBytes) && !_inShutdown.load()) {
-                int now = batchTimer.seconds();
-
-                // apply replication batch limits
-                if (!ops.empty()) {
-                    if (now > replBatchLimitSeconds)
-                        break;
-                    if (ops.getDeque().size() > replBatchLimitOperations)
-                        break;
-                }
-
-                const int slaveDelaySecs = durationCount<Seconds>(replCoord->getSlaveDelaySecs());
-                if (!ops.empty() && slaveDelaySecs > 0) {
-                    const BSONObj lastOp = ops.back().raw;
-                    const unsigned int opTimestampSecs = lastOp["ts"].timestamp().getSecs();
-
-                    // Stop the batch as the lastOp is too new to be applied. If we continue
-                    // on, we can get ops that are way ahead of the delay and this will
-                    // make this thread sleep longer when handleSlaveDelay is called
-                    // and apply ops much sooner than we like.
-                    if (opTimestampSecs > static_cast<unsigned int>(time(0) - slaveDelaySecs)) {
-                        break;
-                    }
-                }
-
-                if (MONGO_FAIL_POINT(rsSyncApplyStop)) {
-                    break;
-                }
-
-                // keep fetching more ops as long as we haven't filled up a full batch yet
+            // tryPopAndWaitForMore adds to ops and returns true when we need to end a batch early.
+            while (!_inShutdown.load() &&
+                   !_syncTail->tryPopAndWaitForMore(&txn, &ops, batchLimits)) {
             }
 
             // For pausing replication in tests
@@ -694,6 +656,10 @@ private:
                 sleepmillis(0);
             }
 
+            if (ops.empty()) {
+                continue;  // Don't emit empty batches.
+            }
+
             stdx::unique_lock<stdx::mutex> lk(_mutex);
             while (!_ops.empty()) {
                 // Block until the previous batch has been taken.
@@ -708,6 +674,7 @@ private:
 
     AtomicWord<bool> _inShutdown;
     SyncTail* const _syncTail;
+    StorageInterface* const _storageInterface;
 
     stdx::mutex _mutex;  // Guards _ops.
     stdx::condition_variable _cv;
@@ -717,8 +684,8 @@ private:
 };
 
 /* tail an oplog.  ok to return, will be re-called. */
-void SyncTail::oplogApplication() {
-    OpQueueBatcher batcher(this);
+void SyncTail::oplogApplication(StorageInterface* storageInterface) {
+    OpQueueBatcher batcher(this, storageInterface);
 
     OperationContextImpl txn;
     auto replCoord = ReplicationCoordinator::get(&txn);
@@ -727,9 +694,6 @@ void SyncTail::oplogApplication() {
             ? new ApplyBatchFinalizerForJournal(replCoord)
             : new ApplyBatchFinalizer(replCoord)};
 
-    auto minValidBoundaries = getMinValid(&txn);
-    OpTime originalEndOpTime(minValidBoundaries.end);
-    OpTime lastWriteOpTime{replCoord->getMyLastAppliedOpTime()};
     while (!inShutdown()) {
         OpQueue ops;
 
@@ -739,7 +703,7 @@ void SyncTail::oplogApplication() {
                 return;
             }
 
-            tryToGoLiveAsASecondary(&txn, replCoord, minValidBoundaries, lastWriteOpTime);
+            tryToGoLiveAsASecondary(&txn, replCoord);
 
             // Blocks up to a second waiting for a batch to be ready to apply. If one doesn't become
             // ready in time, we'll loop again so we can do the above checks periodically.
@@ -751,9 +715,7 @@ void SyncTail::oplogApplication() {
 
         invariant(!ops.empty());
 
-        const BSONObj lastOp = ops.back().raw;
-
-        if (lastOp.isEmpty()) {
+        if (ops.front().raw.isEmpty()) {
             // This means that the network thread has coalesced and we have processed all of its
             // data.
             invariant(ops.getDeque().size() == 1);
@@ -761,66 +723,40 @@ void SyncTail::oplogApplication() {
                 replCoord->signalDrainComplete(&txn);
             }
 
-            // Reset when triggered in case it was from a rollback, safe to do at any time.
-            lastWriteOpTime = replCoord->getMyLastAppliedOpTime();
-
             continue;  // This wasn't a real op. Don't try to apply it.
         }
 
-        const auto lastOpTime = fassertStatusOK(28773, OpTime::parseFromOplogEntry(lastOp));
-        // TODO: Make ">=" once SERVER-21988 is fixed.
-        if (lastWriteOpTime > lastOpTime) {
-            // Error for the oplog to go back in time.
+        // Extract some info from ops that we'll need after releasing the batch below.
+        const auto firstOpTimeInBatch =
+            fassertStatusOK(40299, OpTime::parseFromOplogEntry(ops.front().raw));
+        const auto lastOpTimeInBatch =
+            fassertStatusOK(28773, OpTime::parseFromOplogEntry(ops.back().raw));
+
+        // Make sure the oplog doesn't go back in time or repeat an entry.
+        if (firstOpTimeInBatch <= replCoord->getMyLastAppliedOpTime()) {
             fassert(34361,
                     Status(ErrorCodes::OplogOutOfOrder,
-                           str::stream() << "Attempted to apply an earlier oplog entry (ts: "
-                                         << lastOpTime.getTimestamp().toStringPretty()
-                                         << ") when our lastWrittenOptime was "
-                                         << lastWriteOpTime.toString()));
+                           str::stream() << "Attempted to apply an oplog entry ("
+                                         << firstOpTimeInBatch.toString()
+                                         << ") which is not greater than our last applied OpTime ("
+                                         << replCoord->getMyLastAppliedOpTime().toString()
+                                         << ")."));
         }
 
-        handleSlaveDelay(lastOpTime.getTimestamp());
-
-        // Set minValid to the last OpTime that needs to be applied, in this batch or from the
-        // (last) failed batch, whichever is larger.
-        // This will cause this node to go into RECOVERING state
-        // if we should crash and restart before updating finishing.
-        const OpTime start(getLastSetTimestamp(), OpTime::kUninitializedTerm);
-
-
-        // Take the max of the first endOptime (if we recovered) and the end of our batch.
-
-        // Setting end to the max of originalEndOpTime and lastOpTime (the end of the batch)
-        // ensures that we keep pushing out the point where we can become consistent
-        // and allow reads. If we recover and end up doing smaller batches we must pass the
-        // originalEndOpTime before we are good.
-        //
-        // For example:
-        // batch apply, 20-40, end = 40
-        // batch failure,
-        // restart
-        // batch apply, 20-25, end = max(25, 40) = 40
-        // batch apply, 25-45, end = 45
-        const OpTime end(std::max(originalEndOpTime, lastOpTime));
-
-        // This write will not journal/checkpoint.
-        setMinValid(&txn, {start, end});
-
-        lastWriteOpTime = multiApply(&txn, ops);
-        if (lastWriteOpTime.isNull()) {
+        const bool fail = multiApply(&txn, ops).isNull();
+        if (fail) {
             // fassert if oplog application failed for any reasons other than shutdown.
             error() << "Failed to apply " << ops.getDeque().size()
-                    << " operations - batch start:" << start << " end:" << end;
+                    << " operations - batch start:" << firstOpTimeInBatch
+                    << " end:" << lastOpTimeInBatch;
             fassert(34360, inShutdownStrict());
             // Return without setting minvalid in the case of shutdown.
             return;
         }
 
-        setNewTimestamp(lastWriteOpTime.getTimestamp());
-        setMinValid(&txn, end, DurableRequirement::None);
-        minValidBoundaries.start = {};
-        minValidBoundaries.end = end;
-        finalizer->record(lastWriteOpTime);
+        // Update various things that care about our last applied optime.
+        setNewTimestamp(lastOpTimeInBatch.getTimestamp());
+        finalizer->record(lastOpTimeInBatch);
     }
 }
 
@@ -837,6 +773,8 @@ SyncTail::OplogEntry::OplogEntry(const BSONObj& rawInput) : raw(rawInput.getOwne
             version = elem;
         } else if (name == "o") {
             o = elem;
+        } else if (name == "ts") {
+            ts = elem;
         }
     }
 }
@@ -846,27 +784,62 @@ SyncTail::OplogEntry::OplogEntry(const BSONObj& rawInput) : raw(rawInput.getOwne
 // Batch should end early if we encounter a command, or if
 // there are no further ops in the bgsync queue to read.
 // This function also blocks 1 second waiting for new ops to appear in the bgsync
-// queue.  We can't block forever because there are maintenance things we need
-// to periodically check in the loop.
-bool SyncTail::tryPopAndWaitForMore(OperationContext* txn, SyncTail::OpQueue* ops) {
+// queue.  We don't block forever so that we can periodically check for things like shutdown or
+// reconfigs.
+bool SyncTail::tryPopAndWaitForMore(OperationContext* txn,
+                                    SyncTail::OpQueue* ops,
+                                    const BatchLimits& limits) {
     BSONObj op;
     // Check to see if there are ops waiting in the bgsync queue
     bool peek_success = peek(&op);
 
     if (!peek_success) {
-        // if we don't have anything in the queue, wait a bit for something to appear
+        // If we don't have anything in the queue, wait a bit for something to appear.
         if (ops->empty()) {
-            // block up to 1 second
+            // Block up to 1 second. We still return true in this case because we want this
+            // op to be the first in a new batch with a new start time.
             _networkQueue->waitForMore();
-            return false;
         }
 
-        // otherwise, apply what we have
         return true;
     }
 
+    // If this op would put us over the byte limit don't include it unless the batch is empty.
+    // We allow single-op batches to exceed the byte limit so that large ops are able to be
+    // processed.
+    if (!ops->empty() && (ops->getSize() + size_t(op.objsize())) > limits.bytes) {
+        return true;  // Return before wasting time parsing the op.
+    }
+
     auto entry = OplogEntry(op);
 
+    if (!entry.raw.isEmpty()) {
+        // check for oplog version change
+        int curVersion = 0;
+        if (entry.version.eoo()) {
+            // missing version means version 1
+            curVersion = 1;
+        } else {
+            curVersion = entry.version.Int();
+        }
+
+        if (curVersion != OPLOG_VERSION) {
+            severe() << "expected oplog version " << OPLOG_VERSION << " but found version "
+                     << curVersion << " in oplog entry: " << op;
+            fassertFailedNoTrace(18820);
+        }
+    }
+
+    if (limits.slaveDelayLatestTimestamp &&
+        entry.ts.timestampTime() > *limits.slaveDelayLatestTimestamp) {
+        if (ops->empty()) {
+            // Sleep if we've got nothing to do. Only sleep for 1 second at a time to allow
+            // reconfigs and shutdown to occur.
+            sleepsecs(1);
+        }
+        return true;
+    }
+
     // Check for ops that must be processed one at a time.
     if (entry.raw.isEmpty() ||       // sentinel that network queue is drained.
         (entry.opType[0] == 'c') ||  // commands.
@@ -883,26 +856,12 @@ bool SyncTail::tryPopAndWaitForMore(OperationContext* txn, SyncTail::OpQueue* op
         return true;
     }
 
-    // check for oplog version change
-    int curVersion = 0;
-    if (entry.version.eoo())
-        // missing version means version 1
-        curVersion = 1;
-    else
-        curVersion = entry.version.Int();
-
-    if (curVersion != OPLOG_VERSION) {
-        severe() << "expected oplog version " << OPLOG_VERSION << " but found version "
-                 << curVersion << " in oplog entry: " << op;
-        fassertFailedNoTrace(18820);
-    }
-
     // Copy the op to the deque and remove it from the bgsync queue.
     ops->push_back(std::move(entry));
     _networkQueue->consume();
 
-    // Go back for more ops
-    return false;
+    // Go back for more ops, unless we've hit the limit.
+    return ops->getDeque().size() >= limits.ops;
 }
 
 void SyncTail::setHostname(const std::string& hostname) {
@@ -1032,11 +991,12 @@ void multiSyncApply(const std::vector<BSONObj>& ops, SyncTail* st) {
     // allow us to get through the magic barrier
     txn.lockState()->setIsBatchWriter(true);
 
-    bool convertUpdatesToUpserts = true;
+    // This function is only called in steady state replication.
+    bool inSteadyStateReplication = true;
 
     for (std::vector<BSONObj>::const_iterator it = ops.begin(); it != ops.end(); ++it) {
         try {
-            const Status s = SyncTail::syncApply(&txn, *it, convertUpdatesToUpserts);
+            const Status s = SyncTail::syncApply(&txn, *it, inSteadyStateReplication);
             if (!s.isOK()) {
                 severe() << "Error applying operation (" << it->toString() << "): " << s;
                 fassertFailedNoTrace(16359);
@@ -1059,23 +1019,39 @@ void multiInitialSyncApply(const std::vector<BSONObj>& ops, SyncTail* st) {
     initializeWriterThread();
 
     OperationContextImpl txn;
-    txn.setReplicatedWrites(false);
-    DisableDocumentValidation validationDisabler(&txn);
+    Status status = multiInitialSyncApply_noAbort(&txn, ops, st);
+    fassertNoTrace(15915, status);
+}
+
+Status multiInitialSyncApply_noAbort(OperationContext* txn,
+                                     const std::vector<BSONObj>& ops,
+                                     SyncTail* st) {
+    txn->setReplicatedWrites(false);
+    DisableDocumentValidation validationDisabler(txn);
 
     // allow us to get through the magic barrier
-    txn.lockState()->setIsBatchWriter(true);
+    txn->lockState()->setIsBatchWriter(true);
 
-    bool convertUpdatesToUpserts = false;
+    // This function is only called in initial sync, as its name suggests.
+    bool inSteadyStateReplication = false;
 
     for (std::vector<BSONObj>::const_iterator it = ops.begin(); it != ops.end(); ++it) {
         try {
-            const Status s = SyncTail::syncApply(&txn, *it, convertUpdatesToUpserts);
+            const Status s = SyncTail::syncApply(txn, *it, inSteadyStateReplication);
             if (!s.isOK()) {
-                if (st->shouldRetry(&txn, *it)) {
-                    const Status s2 = SyncTail::syncApply(&txn, *it, convertUpdatesToUpserts);
+                // Don't retry on commands.
+                SyncTail::OplogEntry entry(*it);
+                if (entry.opType[0] == 'c') {
+                    error() << "Error applying command (" << it->toString() << "): " << s;
+                    return s;
+                }
+
+                // We might need to fetch the missing docs from the sync source.
+                if (st->shouldRetry(txn, *it)) {
+                    const Status s2 = SyncTail::syncApply(txn, *it, inSteadyStateReplication);
                     if (!s2.isOK()) {
                         severe() << "Error applying operation (" << it->toString() << "): " << s2;
-                        fassertFailedNoTrace(15915);
+                        return s2;
                     }
                 }
 
@@ -1084,16 +1060,24 @@ void multiInitialSyncApply(const std::vector<BSONObj>& ops, SyncTail* st) {
                 // subsequently got deleted and no longer exists on the Sync Target at all
             }
         } catch (const DBException& e) {
+            // SERVER-24927 If we have a NamespaceNotFound exception, then this document will be
+            // dropped before initial sync ends anyways and we should ignore it.
+            SyncTail::OplogEntry entry(*it);
+            if (e.getCode() == ErrorCodes::NamespaceNotFound &&
+                isCrudOpType(entry.opType.rawData())) {
+                continue;
+            }
+
             severe() << "writer worker caught exception: " << causedBy(e)
                      << " on: " << it->toString();
 
             if (inShutdown()) {
-                return;
+                return Status::OK();
             }
-
-            fassertFailedNoTrace(16361);
+            return e.toStatus();
         }
     }
+    return Status::OK();
 }
 
 }  // namespace repl
