@@ -61,6 +61,7 @@ namespace mongo {
 
 using std::shared_ptr;
 using std::string;
+using std::unique_ptr;
 using std::vector;
 
 namespace {
@@ -376,52 +377,6 @@ bool ShardingState::forgetPending(OperationContext* txn,
     return true;
 }
 
-void ShardingState::splitChunk(OperationContext* txn,
-                               const string& ns,
-                               const BSONObj& min,
-                               const BSONObj& max,
-                               const vector<BSONObj>& splitKeys,
-                               ChunkVersion version) {
-    invariant(txn->lockState()->isCollectionLockedForMode(ns, MODE_X));
-    stdx::lock_guard<stdx::mutex> lk(_mutex);
-
-    CollectionMetadataMap::const_iterator it = _collMetadata.find(ns);
-    verify(it != _collMetadata.end());
-
-    ChunkType chunk;
-    chunk.setMin(min);
-    chunk.setMax(max);
-    string errMsg;
-
-    shared_ptr<CollectionMetadata> cloned(
-        it->second->cloneSplit(chunk, splitKeys, version, &errMsg));
-    // uassert to match old behavior, TODO: report errors w/o throwing
-    uassert(16857, errMsg, NULL != cloned.get());
-
-    _collMetadata[ns] = cloned;
-}
-
-void ShardingState::mergeChunks(OperationContext* txn,
-                                const string& ns,
-                                const BSONObj& minKey,
-                                const BSONObj& maxKey,
-                                ChunkVersion mergedVersion) {
-    invariant(txn->lockState()->isCollectionLockedForMode(ns, MODE_X));
-    stdx::lock_guard<stdx::mutex> lk(_mutex);
-
-    CollectionMetadataMap::const_iterator it = _collMetadata.find(ns);
-    verify(it != _collMetadata.end());
-
-    string errMsg;
-
-    shared_ptr<CollectionMetadata> cloned(
-        it->second->cloneMerge(minKey, maxKey, mergedVersion, &errMsg));
-    // uassert to match old behavior, TODO: report errors w/o throwing
-    uassert(17004, errMsg, NULL != cloned.get());
-
-    _collMetadata[ns] = cloned;
-}
-
 bool ShardingState::inCriticalMigrateSection() {
     return _migrationSourceManager.getInCriticalSection();
 }
@@ -689,7 +644,6 @@ Status ShardingState::_refreshMetadata(OperationContext* txn,
     shared_ptr<CollectionMetadata> remoteMetadata(std::make_shared<CollectionMetadata>());
 
     Timer refreshTimer;
-    long long refreshMillis;
 
     {
         Status status = mdLoader.makeCollectionMetadata(txn,
@@ -698,7 +652,6 @@ Status ShardingState::_refreshMetadata(OperationContext* txn,
                                                         getShardName(),
                                                         fullReload ? NULL : beforeMetadata.get(),
                                                         remoteMetadata.get());
-        refreshMillis = refreshTimer.millis();
 
         if (status.code() == ErrorCodes::NamespaceNotFound) {
             remoteMetadata.reset();
@@ -839,8 +792,8 @@ Status ShardingState::_refreshMetadata(OperationContext* txn,
             << "need to retry loading metadata for " << ns
             << ", collection may have been dropped or recreated during load"
             << " (loaded shard version : " << remoteShardVersion.toString()
-            << ", stored shard versions : " << localShardVersionMsg << ", took " << refreshMillis
-            << "ms)";
+            << ", stored shard versions : " << localShardVersionMsg << ", took "
+            << refreshTimer.millis() << " ms)";
 
         warning() << errMsg;
         return Status(ErrorCodes::RemoteChangeDetected, errMsg);
@@ -849,7 +802,7 @@ Status ShardingState::_refreshMetadata(OperationContext* txn,
     if (choice == VersionChoice::Local) {
         LOG(0) << "metadata of collection " << ns
                << " already up to date (shard version : " << afterShardVersion.toString()
-               << ", took " << refreshMillis << "ms)";
+               << ", took " << refreshTimer.millis() << " ms)";
         return Status::OK();
     }
 
@@ -858,20 +811,22 @@ Status ShardingState::_refreshMetadata(OperationContext* txn,
     switch (installType) {
         case InstallType_New:
             LOG(0) << "collection " << ns << " was previously unsharded"
-                   << ", new metadata loaded with shard version " << remoteShardVersion;
+                   << ", new metadata loaded with shard version " << remoteShardVersion << ", took "
+                   << refreshTimer.millis() << " ms";
             break;
         case InstallType_Update:
             LOG(0) << "updating metadata for " << ns << " from shard version "
-                   << localShardVersionMsg << " to shard version " << remoteShardVersion;
+                   << localShardVersionMsg << " to shard version " << remoteShardVersion
+                   << ", took " << refreshTimer.millis() << " ms";
             break;
         case InstallType_Replace:
             LOG(0) << "replacing metadata for " << ns << " at shard version "
                    << localShardVersionMsg << " with a new epoch (shard version "
-                   << remoteShardVersion << ")";
+                   << remoteShardVersion << "), took " << refreshTimer.millis() << " ms";
             break;
         case InstallType_Drop:
             LOG(0) << "dropping metadata for " << ns << " at shard version " << localShardVersionMsg
-                   << ", took " << refreshMillis << "ms";
+                   << ", took " << refreshTimer.millis() << " ms";
             break;
         default:
             verify(false);
@@ -880,7 +835,7 @@ Status ShardingState::_refreshMetadata(OperationContext* txn,
 
     if (installType != InstallType_Drop) {
         LOG(0) << "collection version was loaded at version " << remoteCollVersion << ", took "
-               << refreshMillis << "ms";
+               << refreshTimer.millis() << " ms";
     }
 
     return Status::OK();
@@ -934,6 +889,19 @@ shared_ptr<CollectionMetadata> ShardingState::getCollectionMetadata(const string
     }
 }
 
+void ShardingState::exchangeCollectionMetadata(OperationContext* txn,
+                                               const NamespaceString& nss,
+                                               unique_ptr<CollectionMetadata> newMetadata) {
+    invariant(txn->lockState()->isCollectionLockedForMode(nss.ns(), MODE_X));
+
+    stdx::lock_guard<stdx::mutex> lk(_mutex);
+
+    CollectionMetadataMap::iterator it = _collMetadata.find(nss.ns());
+    invariant(it != _collMetadata.end());
+
+    it->second = std::move(newMetadata);
+}
+
 /**
  * Global free function.
  */
