@@ -271,6 +271,12 @@ Status addGeneralServerOptions(moe::OptionSection* options) {
                                moe::String,
                                "private key for cluster authentication").incompatibleWith("noauth");
 
+    options->addOptionChaining("noauth", "noauth", moe::Switch, "run without security")
+        .setSources(moe::SourceAllLegacy)
+        .incompatibleWith("auth")
+        .incompatibleWith("keyFile")
+        .incompatibleWith("clusterAuthMode");
+
     options->addOptionChaining(
                  "setParameter", "setParameter", moe::StringMap, "Set a configurable parameter")
         .composing();
@@ -535,6 +541,18 @@ Status validateServerOptions(const moe::Environment& params) {
         if (authMechParameter != parameters.end() && authMechParameter->second.empty()) {
             haveAuthenticationMechanisms = false;
         }
+
+        // Make sure 'internalLookupStageBatchSize' can only be set if test commands are enabled.
+        auto lookupBatchSizeParameter = parameters.find("internalLookupStageBatchSize");
+        auto enableTestCommandsParameter = parameters.find("enableTestCommands");
+        if (lookupBatchSizeParameter != parameters.end()) {
+            if (enableTestCommandsParameter == parameters.end() ||
+                enableTestCommandsParameter->second != "1") {
+                return Status(
+                    ErrorCodes::BadValue,
+                    "internalLookupStageBatchSize can only be set if test commands are enabled.");
+            }
+        }
     }
     if ((params.count("security.authorization") &&
          params["security.authorization"].as<std::string>() == "enabled") ||
@@ -688,6 +706,19 @@ Status canonicalizeServerOptions(moe::Environment* params) {
         }
     }
 
+    if (params->count("noauth")) {
+        Status ret =
+            params->set("security.authorization",
+                        (*params)["noauth"].as<bool>() ? moe::Value(std::string("disabled"))
+                                                       : moe::Value(std::string("enabled")));
+        if (!ret.isOK()) {
+            return ret;
+        }
+        ret = params->remove("noauth");
+        if (!ret.isOK()) {
+            return ret;
+        }
+    }
     return Status::OK();
 }
 
@@ -783,6 +814,7 @@ Status storeServerOptions(const moe::Environment& params, const std::vector<std:
             return Status(ErrorCodes::BadValue,
                           "unsupported value for clusterAuthMode " + clusterAuthMode);
         }
+        serverGlobalParams.authState = ServerGlobalParams::AuthState::kEnabled;
     } else {
         serverGlobalParams.clusterAuthMode.store(ServerGlobalParams::ClusterAuthMode_undefined);
     }
@@ -808,10 +840,8 @@ Status storeServerOptions(const moe::Environment& params, const std::vector<std:
     }
 
     if (params.count("net.bindIp")) {
-        // passing in wildcard is the same as default behavior; remove and warn
+        // passing in wildcard is the same as default behavior; remove for SERVER-3350
         if (serverGlobalParams.bind_ip == "0.0.0.0") {
-            std::cout << "warning: bind_ip of 0.0.0.0 is unnecessary; "
-                      << "listens on all ips by default" << endl;
             serverGlobalParams.bind_ip = "";
         }
     }
@@ -938,6 +968,15 @@ Status storeServerOptions(const moe::Environment& params, const std::vector<std:
     if (params.count("security.keyFile")) {
         serverGlobalParams.keyFile =
             boost::filesystem::absolute(params["security.keyFile"].as<string>()).generic_string();
+        serverGlobalParams.authState = ServerGlobalParams::AuthState::kEnabled;
+    }
+
+    if (params.count("security.authorization") &&
+        params["security.authorization"].as<std::string>() == "disabled") {
+        serverGlobalParams.authState = ServerGlobalParams::AuthState::kDisabled;
+    } else if (params.count("security.authorization") &&
+               params["security.authorization"].as<std::string>() == "enabled") {
+        serverGlobalParams.authState = ServerGlobalParams::AuthState::kEnabled;
     }
 
     if (params.count("processManagement.pidFilePath")) {
