@@ -31,7 +31,7 @@
 
 #pragma once
 
-#include <queue>
+#include <list>
 #include <string>
 
 #include <wiredtiger.h>
@@ -133,6 +133,8 @@ public:
         return _conn;
     }
     void dropSomeQueuedIdents();
+    std::list<WiredTigerCachedCursor> filterCursorsWithQueuedDrops(
+        std::list<WiredTigerCachedCursor>* cache);
     bool haveDropsQueued() const;
 
     void syncSizeInfo(bool sync) const;
@@ -177,7 +179,7 @@ private:
 
     mutable stdx::mutex _dropAllQueuesMutex;
     mutable stdx::mutex _identToDropMutex;
-    std::queue<std::string> _identToDrop;
+    std::list<std::string> _identToDrop;
 
     mutable Date_t _previousCheckedDropsQueued;
 
