@@ -70,6 +70,8 @@ Status wtRCToStatus_slow(int retCode, const char* prefix) {
         return Status(ErrorCodes::BadValue, s);
     }
 
+    uassert(ErrorCodes::ExceededMemoryLimit, s, retCode != WT_CACHE_FULL);
+
     // TODO convert specific codes rather than just using UNKNOWN_ERROR for everything.
     return Status(ErrorCodes::UnknownError, s);
 }
@@ -200,6 +202,13 @@ Status WiredTigerUtil::checkApplicationMetadataFormatVersion(OperationContext* o
         return Status(ErrorCodes::UnsupportedFormat,
                       str::stream() << "application metadata for " << uri << " is missing ");
 
+    if (metadata.type != WT_CONFIG_ITEM::WT_CONFIG_ITEM_STRUCT) {
+        return Status(ErrorCodes::FailedToParse,
+                      str::stream()
+                          << "application metadata must be enclosed in parentheses. Actual value: "
+                          << StringData(metadata.str, metadata.len));
+    }
+
     WiredTigerConfigParser parser(metadata);
 
     int64_t version = 0;
@@ -220,7 +229,7 @@ Status WiredTigerUtil::checkApplicationMetadataFormatVersion(OperationContext* o
     if (version < minimumVersion || version > maximumVersion) {
         return Status(ErrorCodes::UnsupportedFormat,
                       str::stream() << "Application metadata for " << uri
-                                    << " has unsupported format version " << version);
+                                    << " has unsupported format version: " << version << ".");
     }
 
     LOG(2) << "WiredTigerUtil::checkApplicationMetadataFormatVersion "
@@ -242,6 +251,11 @@ Status WiredTigerUtil::checkTableCreationOptions(const BSONElement& configElem)
     ErrorAccumulator eventHandler(&errors);
 
     StringData config = configElem.valueStringData();
+    // Do NOT allow embedded null characters
+    if (config.size() != strlen(config.rawData())) {
+        return {ErrorCodes::FailedToParse, "malformed 'configString' value."};
+    }
+
     Status status = wtRCToStatus(
         wiredtiger_config_validate(nullptr, &eventHandler, "WT_SESSION.create", config.rawData()));
     if (!status.isOK()) {
@@ -382,9 +396,9 @@ int WiredTigerUtil::verifyTable(OperationContext* txn,
     ErrorAccumulator eventHandler(errors);
 
     // Try to close as much as possible to avoid EBUSY errors.
-    WiredTigerRecoveryUnit::get(txn)->getSession(txn)->closeAllCursors();
+    WiredTigerRecoveryUnit::get(txn)->getSession(txn)->closeAllCursors(uri);
     WiredTigerSessionCache* sessionCache = WiredTigerRecoveryUnit::get(txn)->getSessionCache();
-    sessionCache->closeAll();
+    sessionCache->closeAllCursors(uri);
 
     // Open a new session with custom error handlers.
     WT_CONNECTION* conn = WiredTigerRecoveryUnit::get(txn)->getSessionCache()->conn();
