@@ -1,4 +1,5 @@
-/** *    Copyright (C) 2015 MongoDB Inc.
+/**
+ *    Copyright (C) 2015 MongoDB Inc.
  *
  *    This program is free software: you can redistribute it and/or  modify
  *    it under the terms of the GNU Affero General Public License, version 3,
@@ -93,11 +94,23 @@ public:
      */
     size_t availableConnections(const stdx::unique_lock<stdx::mutex>& lk);
 
+    /**
+     * Returns the number of in progress connections in the pool.
+     */
+    size_t refreshingConnections(const stdx::unique_lock<stdx::mutex>& lk);
+
     /**
      * Returns the total number of connections ever created in this pool.
      */
     size_t createdConnections(const stdx::unique_lock<stdx::mutex>& lk);
 
+    /**
+     * Returns the total number of connections currently open that belong to
+     * this pool. This is the sum of refreshingConnections, availableConnections,
+     * and inUseConnections.
+     */
+    size_t openConnections(const stdx::unique_lock<stdx::mutex>& lk);
+
 private:
     using OwnedConnection = std::unique_ptr<ConnectionInterface>;
     using OwnershipPool = std::unordered_map<ConnectionInterface*, OwnedConnection>;
@@ -172,12 +185,15 @@ size_t const ConnectionPool::kDefaultMaxConns = std::numeric_limits<size_t>::max
 size_t const ConnectionPool::kDefaultMinConns = 1;
 const Milliseconds ConnectionPool::kDefaultRefreshRequirement = Minutes(1);
 const Milliseconds ConnectionPool::kDefaultRefreshTimeout = Seconds(20);
+size_t const ConnectionPool::kDefaultMaxConnecting = std::numeric_limits<size_t>::max();
 
 const Status ConnectionPool::kConnectionStateUnknown =
     Status(ErrorCodes::InternalError, "Connection is in an unknown state");
 
-ConnectionPool::ConnectionPool(std::unique_ptr<DependentTypeFactoryInterface> impl, Options options)
-    : _options(std::move(options)), _factory(std::move(impl)) {}
+ConnectionPool::ConnectionPool(std::unique_ptr<DependentTypeFactoryInterface> impl,
+                               std::string name,
+                               Options options)
+    : _name(std::move(name)), _options(std::move(options)), _factory(std::move(impl)) {}
 
 ConnectionPool::~ConnectionPool() = default;
 
@@ -222,13 +238,24 @@ void ConnectionPool::appendConnectionStats(ConnectionPoolStats* stats) const {
         HostAndPort host = kv.first;
 
         auto& pool = kv.second;
-        ConnectionStatsPerHost hostStats{pool->inUseConnections(lk),
-                                         pool->availableConnections(lk),
-                                         pool->createdConnections(lk)};
-        stats->updateStatsForHost(host, hostStats);
+        ConnectionStatsPer hostStats{pool->inUseConnections(lk),
+                                     pool->availableConnections(lk),
+                                     pool->createdConnections(lk),
+                                     pool->refreshingConnections(lk)};
+        stats->updateStatsForHost(_name, host, hostStats);
     }
 }
 
+size_t ConnectionPool::getNumConnectionsPerHost(const HostAndPort& hostAndPort) const {
+    stdx::unique_lock<stdx::mutex> lk(_mutex);
+    auto iter = _pools.find(hostAndPort);
+    if (iter != _pools.end()) {
+        return iter->second->openConnections(lk);
+    }
+
+    return 0;
+}
+
 void ConnectionPool::returnConnection(ConnectionInterface* conn) {
     stdx::unique_lock<stdx::mutex> lk(_mutex);
 
@@ -262,10 +289,19 @@ size_t ConnectionPool::SpecificPool::availableConnections(
     return _readyPool.size();
 }
 
+size_t ConnectionPool::SpecificPool::refreshingConnections(
+    const stdx::unique_lock<stdx::mutex>& lk) {
+    return _processingPool.size();
+}
+
 size_t ConnectionPool::SpecificPool::createdConnections(const stdx::unique_lock<stdx::mutex>& lk) {
     return _created;
 }
 
+size_t ConnectionPool::SpecificPool::openConnections(const stdx::unique_lock<stdx::mutex>& lk) {
+    return _checkedOutPool.size() + _readyPool.size() + _processingPool.size();
+}
+
 void ConnectionPool::SpecificPool::getConnection(const HostAndPort& hostAndPort,
                                                  Milliseconds timeout,
                                                  stdx::unique_lock<stdx::mutex> lk,
@@ -303,6 +339,8 @@ void ConnectionPool::SpecificPool::returnConnection(ConnectionInterface* connPtr
 
     if (!conn->getStatus().isOK()) {
         // TODO: alert via some callback if the host is bad
+        log() << "Ending connection to host " << _hostAndPort << " due to bad connection status; "
+              << openConnections(lk) << " connections to that host remain open";
         return;
     }
 
@@ -313,6 +351,9 @@ void ConnectionPool::SpecificPool::returnConnection(ConnectionInterface* connPtr
         if (_readyPool.size() + _processingPool.size() + _checkedOutPool.size() >=
             _parent->_options.minConnections) {
             // If we already have minConnections, just let the connection lapse
+            log() << "Ending idle connection to host " << _hostAndPort
+                  << " because the pool meets constraints; " << openConnections(lk)
+                  << " connections to that host remain open";
             return;
         }
 
@@ -329,8 +370,10 @@ void ConnectionPool::SpecificPool::returnConnection(ConnectionInterface* connPtr
                              auto conn = takeFromProcessingPool(connPtr);
 
                              // If the host and port were dropped, let this lapse
-                             if (conn->getGeneration() != _generation)
+                             if (conn->getGeneration() != _generation) {
+                                 spawnConnections(lk);
                                  return;
+                             }
 
                              // If we're in shutdown, we don't need refreshed connections
                              if (_state == State::kInShutdown)
@@ -340,6 +383,7 @@ void ConnectionPool::SpecificPool::returnConnection(ConnectionInterface* connPtr
                              // pool
                              if (status.isOK()) {
                                  addToReady(lk, std::move(conn));
+                                 spawnConnections(lk);
                                  return;
                              }
 
@@ -347,6 +391,10 @@ void ConnectionPool::SpecificPool::returnConnection(ConnectionInterface* connPtr
                              // failing all operations.  We do this because the various callers have
                              // their own time limit which is unrelated to our internal one.
                              if (status.code() == ErrorCodes::ExceededTimeLimit) {
+                                 log() << "Pending connection to host " << _hostAndPort
+                                       << " did not complete within the connection timeout,"
+                                       << " retrying with a new connection;" << openConnections(lk)
+                                       << " connections to that host remain open";
                                  spawnConnections(lk);
                                  return;
                              }
@@ -411,6 +459,10 @@ void ConnectionPool::SpecificPool::processFailure(const Status& status,
     // Drop ready connections
     _readyPool.clear();
 
+    // Log something helpful
+    log() << "Dropping all pooled connections to " << _hostAndPort
+          << " due to failed operation on a connection";
+
     // Migrate processing connections to the dropped pool
     for (auto&& x : _processingPool) {
         _droppedProcessingPool[x.first] = std::move(x.second);
@@ -512,7 +564,8 @@ void ConnectionPool::SpecificPool::spawnConnections(stdx::unique_lock<stdx::mute
     };
 
     // While all of our inflight connections are less than our target
-    while (_readyPool.size() + _processingPool.size() + _checkedOutPool.size() < target()) {
+    while ((_readyPool.size() + _processingPool.size() + _checkedOutPool.size() < target()) &&
+           (_processingPool.size() < _parent->_options.maxConnecting)) {
         std::unique_ptr<ConnectionPool::ConnectionInterface> handle;
         try {
             // make a new connection and put it in processing
@@ -540,8 +593,10 @@ void ConnectionPool::SpecificPool::spawnConnections(stdx::unique_lock<stdx::mute
                            if (conn->getGeneration() != _generation) {
                                // If the host and port was dropped, let the
                                // connection lapse
+                               spawnConnections(lk);
                            } else if (status.isOK()) {
                                addToReady(lk, std::move(conn));
+                               spawnConnections(lk);
                            } else if (status.code() == ErrorCodes::ExceededTimeLimit) {
                                // If we've exceeded the time limit, restart the connect, rather than
                                // failing all operations.  We do this because the various callers
