@@ -66,7 +66,7 @@ private:
  * another.
  */
 TEST_F(ConnectionPoolTest, SameConn) {
-    ConnectionPool pool(stdx::make_unique<PoolImpl>());
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool");
 
     // Grab and stash an id for the first request
     size_t conn1Id = 0;
@@ -98,7 +98,7 @@ TEST_F(ConnectionPoolTest, SameConn) {
  * Verify that a failed connection isn't returned to the pool
  */
 TEST_F(ConnectionPoolTest, FailedConnDifferentConn) {
-    ConnectionPool pool(stdx::make_unique<PoolImpl>());
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool");
 
     // Grab the first connection and indicate that it failed
     size_t conn1Id = 0;
@@ -131,7 +131,7 @@ TEST_F(ConnectionPoolTest, FailedConnDifferentConn) {
  * connections.
  */
 TEST_F(ConnectionPoolTest, DifferentHostDifferentConn) {
-    ConnectionPool pool(stdx::make_unique<PoolImpl>());
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool");
 
     // Conn 1 from port 30000
     size_t conn1Id = 0;
@@ -163,7 +163,7 @@ TEST_F(ConnectionPoolTest, DifferentHostDifferentConn) {
  * Verify that not returning handle's to the pool spins up new connections.
  */
 TEST_F(ConnectionPoolTest, DifferentConnWithoutReturn) {
-    ConnectionPool pool(stdx::make_unique<PoolImpl>());
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool");
 
     // Get the first connection, move it out rather than letting it return
     ConnectionPool::ConnectionHandle conn1;
@@ -199,7 +199,7 @@ TEST_F(ConnectionPoolTest, DifferentConnWithoutReturn) {
  * Note that the lack of pushSetup() calls delays the get.
  */
 TEST_F(ConnectionPoolTest, TimeoutOnSetup) {
-    ConnectionPool pool(stdx::make_unique<PoolImpl>());
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool");
 
     bool notOk = false;
 
@@ -234,7 +234,7 @@ TEST_F(ConnectionPoolTest, refreshHappens) {
 
     ConnectionPool::Options options;
     options.refreshRequirement = Milliseconds(1000);
-    ConnectionPool pool(stdx::make_unique<PoolImpl>(), options);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
 
     auto now = Date_t::now();
 
@@ -270,7 +270,7 @@ TEST_F(ConnectionPoolTest, refreshTimeoutHappens) {
     ConnectionPool::Options options;
     options.refreshRequirement = Milliseconds(1000);
     options.refreshTimeout = Milliseconds(2000);
-    ConnectionPool pool(stdx::make_unique<PoolImpl>(), options);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
 
     auto now = Date_t::now();
 
@@ -339,7 +339,7 @@ TEST_F(ConnectionPoolTest, refreshTimeoutHappens) {
  * Verify that requests are served in expiration order, not insertion order
  */
 TEST_F(ConnectionPoolTest, requestsServedByUrgency) {
-    ConnectionPool pool(stdx::make_unique<PoolImpl>());
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool");
 
     bool reachedA = false;
     bool reachedB = false;
@@ -386,7 +386,7 @@ TEST_F(ConnectionPoolTest, maxPoolRespected) {
     ConnectionPool::Options options;
     options.minConnections = 1;
     options.maxConnections = 2;
-    ConnectionPool pool(stdx::make_unique<PoolImpl>(), options);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
 
     ConnectionPool::ConnectionHandle conn1;
     ConnectionPool::ConnectionHandle conn2;
@@ -437,6 +437,202 @@ TEST_F(ConnectionPoolTest, maxPoolRespected) {
     doneWith(conn3);
 }
 
+/**
+ * Verify that we respect maxConnecting
+ */
+TEST_F(ConnectionPoolTest, maxConnectingRespected) {
+    ConnectionPool::Options options;
+    options.minConnections = 1;
+    options.maxConnecting = 2;
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
+
+    ConnectionPool::ConnectionHandle conn1;
+    ConnectionPool::ConnectionHandle conn2;
+    ConnectionPool::ConnectionHandle conn3;
+
+    // Make 3 requests, each which keep their connection (don't return it to
+    // the pool)
+    pool.get(HostAndPort(),
+             Milliseconds(3000),
+             [&](StatusWith<ConnectionPool::ConnectionHandle> swConn) {
+                 ASSERT(swConn.isOK());
+
+                 conn3 = std::move(swConn.getValue());
+             });
+    pool.get(HostAndPort(),
+             Milliseconds(2000),
+             [&](StatusWith<ConnectionPool::ConnectionHandle> swConn) {
+                 ASSERT(swConn.isOK());
+
+                 conn2 = std::move(swConn.getValue());
+             });
+    pool.get(HostAndPort(),
+             Milliseconds(1000),
+             [&](StatusWith<ConnectionPool::ConnectionHandle> swConn) {
+                 ASSERT(swConn.isOK());
+
+                 conn1 = std::move(swConn.getValue());
+             });
+
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 2u);
+    ConnectionImpl::pushSetup(Status::OK());
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 2u);
+    ConnectionImpl::pushSetup(Status::OK());
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 1u);
+    ConnectionImpl::pushSetup(Status::OK());
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 0u);
+
+    ASSERT(conn1);
+    ASSERT(conn2);
+    ASSERT(conn3);
+
+    ASSERT_NE(conn1.get(), conn2.get());
+    ASSERT_NE(conn2.get(), conn3.get());
+    ASSERT_NE(conn1.get(), conn3.get());
+
+    doneWith(conn1);
+    doneWith(conn2);
+    doneWith(conn3);
+}
+
+/**
+ * Verify that refresh callbacks block new connections, then trigger new connection spawns after
+ * they return
+ */
+TEST_F(ConnectionPoolTest, maxConnectingWithRefresh) {
+    ConnectionPool::Options options;
+    options.maxConnecting = 1;
+    options.refreshRequirement = Milliseconds(1000);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
+
+    auto now = Date_t::now();
+
+    PoolImpl::setNow(now);
+
+    // Get a connection
+    ConnectionImpl::pushSetup(Status::OK());
+    pool.get(HostAndPort(),
+             Milliseconds(5000),
+             [&](StatusWith<ConnectionPool::ConnectionHandle> swConn) {
+                 ASSERT(swConn.isOK());
+                 doneWith(swConn.getValue());
+             });
+
+    ASSERT_EQ(ConnectionImpl::refreshQueueDepth(), 0u);
+
+    // After 1 second, one refresh has queued
+    PoolImpl::setNow(now + Milliseconds(1000));
+    ASSERT_EQ(ConnectionImpl::refreshQueueDepth(), 1u);
+
+    bool reachedA = false;
+
+    // Try to get another connection
+    pool.get(HostAndPort(),
+             Milliseconds(5000),
+             [&](StatusWith<ConnectionPool::ConnectionHandle> swConn) {
+                 ASSERT(swConn.isOK());
+                 doneWith(swConn.getValue());
+                 reachedA = true;
+             });
+
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 0u);
+    ASSERT(!reachedA);
+    ConnectionImpl::pushRefresh(Status::OK());
+    ASSERT_EQ(ConnectionImpl::refreshQueueDepth(), 0u);
+    ASSERT(reachedA);
+}
+
+/**
+ * Verify that refreshes block new connects, but don't themselves respect maxConnecting
+ */
+TEST_F(ConnectionPoolTest, maxConnectingWithMultipleRefresh) {
+    ConnectionPool::Options options;
+    options.maxConnecting = 2;
+    options.minConnections = 3;
+    options.refreshRequirement = Milliseconds(1000);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
+
+    auto now = Date_t::now();
+
+    PoolImpl::setNow(now);
+
+    // Get us spun up to 3 connections in the pool
+    pool.get(HostAndPort(),
+             Milliseconds(5000),
+             [&](StatusWith<ConnectionPool::ConnectionHandle> swConn) {
+                 ASSERT(swConn.isOK());
+                 doneWith(swConn.getValue());
+             });
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 2u);
+    ConnectionImpl::pushSetup(Status::OK());
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 2u);
+    ConnectionImpl::pushSetup(Status::OK());
+    ConnectionImpl::pushSetup(Status::OK());
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 0u);
+
+    // Force more than two connections into refresh
+    PoolImpl::setNow(now + Milliseconds(1500));
+    ASSERT_EQ(ConnectionImpl::refreshQueueDepth(), 3u);
+
+    std::array<ConnectionPool::ConnectionHandle, 5> conns;
+
+    // Start 5 new requests
+    for (size_t i = 0; i < conns.size(); ++i) {
+        pool.get(HostAndPort(),
+                 Milliseconds(static_cast<int>(1000 + i)),
+                 [&conns, i](StatusWith<ConnectionPool::ConnectionHandle> swConn) {
+                     ASSERT(swConn.isOK());
+                     conns[i] = std::move(swConn.getValue());
+                 });
+    }
+
+    auto firstNBound = [&](size_t n) {
+        for (size_t i = 0; i < n; ++i) {
+            ASSERT(conns[i]);
+        }
+        for (size_t i = n; i < conns.size(); ++i) {
+            ASSERT_FALSE(conns[i]);
+        }
+    };
+
+    // None have started connecting
+    ASSERT_EQ(ConnectionImpl::refreshQueueDepth(), 3u);
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 0u);
+    firstNBound(0);
+
+    // After one refresh, one refreshed connection gets handed out
+    ConnectionImpl::pushRefresh(Status::OK());
+    ASSERT_EQ(ConnectionImpl::refreshQueueDepth(), 2u);
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 0u);
+    firstNBound(1);
+
+    // After two refresh, one enters the setup queue, one refreshed connection gets handed out
+    ConnectionImpl::pushRefresh(Status::OK());
+    ASSERT_EQ(ConnectionImpl::refreshQueueDepth(), 1u);
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 1u);
+    firstNBound(2);
+
+    // After three refresh, we're done refreshing. Two queued in setup
+    ConnectionImpl::pushRefresh(Status::OK());
+    ASSERT_EQ(ConnectionImpl::refreshQueueDepth(), 0u);
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 2u);
+    firstNBound(3);
+
+    // now pushing setup gets us a new connection
+    ConnectionImpl::pushSetup(Status::OK());
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 1u);
+    firstNBound(4);
+
+    // and we're done
+    ConnectionImpl::pushSetup(Status::OK());
+    ASSERT_EQ(ConnectionImpl::setupQueueDepth(), 0u);
+    firstNBound(5);
+
+    for (auto& conn : conns) {
+        doneWith(conn);
+    }
+}
+
 /**
  * Verify that minConnections is respected
  */
@@ -446,7 +642,7 @@ TEST_F(ConnectionPoolTest, minPoolRespected) {
     options.maxConnections = 3;
     options.refreshRequirement = Milliseconds(1000);
     options.refreshTimeout = Milliseconds(2000);
-    ConnectionPool pool(stdx::make_unique<PoolImpl>(), options);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
 
     auto now = Date_t::now();
 
@@ -555,7 +751,7 @@ TEST_F(ConnectionPoolTest, hostTimeoutHappens) {
     options.refreshRequirement = Milliseconds(5000);
     options.refreshTimeout = Milliseconds(5000);
     options.hostTimeout = Milliseconds(1000);
-    ConnectionPool pool(stdx::make_unique<PoolImpl>(), options);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
 
     auto now = Date_t::now();
 
@@ -604,7 +800,7 @@ TEST_F(ConnectionPoolTest, hostTimeoutHappensMoreGetsDelay) {
     options.refreshRequirement = Milliseconds(5000);
     options.refreshTimeout = Milliseconds(5000);
     options.hostTimeout = Milliseconds(1000);
-    ConnectionPool pool(stdx::make_unique<PoolImpl>(), options);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
 
     auto now = Date_t::now();
 
@@ -666,7 +862,7 @@ TEST_F(ConnectionPoolTest, hostTimeoutHappensCheckoutDelays) {
     options.refreshRequirement = Milliseconds(5000);
     options.refreshTimeout = Milliseconds(5000);
     options.hostTimeout = Milliseconds(1000);
-    ConnectionPool pool(stdx::make_unique<PoolImpl>(), options);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
 
     auto now = Date_t::now();
 
@@ -746,7 +942,7 @@ TEST_F(ConnectionPoolTest, dropConnections) {
     options.maxConnections = 1;
     options.refreshRequirement = Seconds(1);
     options.refreshTimeout = Seconds(2);
-    ConnectionPool pool(stdx::make_unique<PoolImpl>(), options);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
 
     auto now = Date_t::now();
     PoolImpl::setNow(now);
@@ -839,7 +1035,7 @@ TEST_F(ConnectionPoolTest, SetupTimeoutsDontTimeoutUnrelatedRequests) {
 
     options.maxConnections = 1;
     options.refreshTimeout = Seconds(2);
-    ConnectionPool pool(stdx::make_unique<PoolImpl>(), options);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
 
     auto now = Date_t::now();
     PoolImpl::setNow(now);
@@ -883,7 +1079,7 @@ TEST_F(ConnectionPoolTest, RefreshTimeoutsDontTimeoutRequests) {
     options.maxConnections = 1;
     options.refreshTimeout = Seconds(2);
     options.refreshRequirement = Seconds(3);
-    ConnectionPool pool(stdx::make_unique<PoolImpl>(), options);
+    ConnectionPool pool(stdx::make_unique<PoolImpl>(), "test pool", options);
 
     auto now = Date_t::now();
     PoolImpl::setNow(now);
