@@ -277,7 +277,7 @@ TEST_F(NetworkInterfaceASIOTest, TimeoutWithNetworkError) {
     auto cbh = makeCallbackHandle();
     auto deferred = startCommand(
         cbh,
-        RemoteCommandRequest(testHost, "testDB", BSON("a" << 1), BSONObj(), Milliseconds(100)));
+        RemoteCommandRequest(testHost, "testDB", BSON("a" << 1), BSONObj(), Milliseconds(1000)));
 
     // Create and initialize a stream so operation can begin
     auto stream = streamFactory().blockUntilStreamExists(testHost);
@@ -292,7 +292,7 @@ TEST_F(NetworkInterfaceASIOTest, TimeoutWithNetworkError) {
 
         // Trigger both a timeout and a network error
         stream->setError(make_error_code(ErrorCodes::HostUnreachable));
-        timerFactory().fastForward(Milliseconds(500));
+        timerFactory().fastForward(Milliseconds(2000));
     }
 
     // Wait for op to complete, assert that timeout had precedence.
@@ -304,7 +304,7 @@ TEST_F(NetworkInterfaceASIOTest, CancelWithTimeoutAndNetworkError) {
     auto cbh = makeCallbackHandle();
     auto deferred = startCommand(
         cbh,
-        RemoteCommandRequest(testHost, "testDB", BSON("a" << 1), BSONObj(), Milliseconds(100)));
+        RemoteCommandRequest(testHost, "testDB", BSON("a" << 1), BSONObj(), Milliseconds(1000)));
 
     // Create and initialize a stream so operation can begin
     auto stream = streamFactory().blockUntilStreamExists(testHost);
@@ -319,7 +319,7 @@ TEST_F(NetworkInterfaceASIOTest, CancelWithTimeoutAndNetworkError) {
 
         // Trigger a timeout, a cancellation, and a network error
         stream->setError(make_error_code(ErrorCodes::HostUnreachable));
-        timerFactory().fastForward(Milliseconds(500));
+        timerFactory().fastForward(Milliseconds(2000));
         net().cancelCommand(cbh);
     }
 
@@ -533,6 +533,46 @@ public:
     }
 };
 
+TEST_F(NetworkInterfaceASIOConnectionHookTest, InvalidIsMaster) {
+    auto validationFailedStatus =
+        Status(ErrorCodes::InterruptedDueToReplStateChange, "operation was interrupted");
+
+    start(makeTestHook(
+        [&](const HostAndPort& remoteHost, const RemoteCommandResponse& isMasterReply) {
+            return Status(ErrorCodes::UnknownError, "unused");
+        },
+        [&](const HostAndPort& remoteHost)
+            -> StatusWith<boost::optional<RemoteCommandRequest>> { return {boost::none}; },
+        [&](const HostAndPort& remoteHost, RemoteCommandResponse&& response) {
+            return Status::OK();
+        }));
+
+    auto deferred = startCommand(makeCallbackHandle(),
+                                 {testHost,
+                                  "blah",
+                                  BSON("foo"
+                                       << "bar")});
+
+    auto stream = streamFactory().blockUntilStreamExists(testHost);
+
+    ConnectEvent{stream}.skip();
+
+    // simulate isMaster reply.
+    stream->simulateServer(rpc::Protocol::kOpQuery,
+                           [](RemoteCommandRequest request) -> RemoteCommandResponse {
+                               RemoteCommandResponse response;
+                               response.data = BSON("ok" << 0.0 << "errmsg"
+                                                         << "operation was interrupted"
+                                                         << "code" << 11602);
+                               return response;
+                           });
+
+    // we should stop here.
+    auto& res = deferred.get();
+
+    ASSERT(res == validationFailedStatus);
+}
+
 TEST_F(NetworkInterfaceASIOConnectionHookTest, ValidateHostInvalid) {
     bool validateCalled = false;
     bool hostCorrect = false;
