@@ -177,6 +177,11 @@ ShardRegistry::ShardRegistry(std::unique_ptr<RemoteCommandTargeterFactory> targe
 
 ShardRegistry::~ShardRegistry() = default;
 
+ConnectionString ShardRegistry::getConfigServerConnectionString() const {
+    stdx::lock_guard<stdx::mutex> lk(_mutex);
+    return _configServerCS;
+}
+
 void ShardRegistry::updateConfigServerConnectionString(ConnectionString configServerCS) {
     stdx::lock_guard<stdx::mutex> lk(_mutex);
     _updateConfigServerConnectionString_inlock(std::move(configServerCS));
@@ -551,7 +556,7 @@ StatusWith<ShardRegistry::QueryResponse> ShardRegistry::_exhaustiveFindOnConfig(
                 return;
             }
 
-            response.opTime = replParseStatus.getValue().getLastOpVisible();
+            response.opTime = replParseStatus.getValue().getLastOpCommitted();
             advanceConfigOpTime(response.opTime);
         }
 
@@ -640,11 +645,12 @@ StatusWith<ShardRegistry::QueryResponse> ShardRegistry::exhaustiveFindOnConfig(
     MONGO_UNREACHABLE;
 }
 
-StatusWith<BSONObj> ShardRegistry::runCommandOnShard(OperationContext* txn,
-                                                     const std::shared_ptr<Shard>& shard,
-                                                     const ReadPreferenceSetting& readPref,
-                                                     const std::string& dbName,
-                                                     const BSONObj& cmdObj) {
+StatusWith<BSONObj> ShardRegistry::runIdempotentCommandOnShard(
+    OperationContext* txn,
+    const std::shared_ptr<Shard>& shard,
+    const ReadPreferenceSetting& readPref,
+    const std::string& dbName,
+    const BSONObj& cmdObj) {
     auto response = _runCommandWithRetries(txn,
                                            _executorPool->getFixedExecutor(),
                                            shard,
@@ -654,7 +660,7 @@ StatusWith<BSONObj> ShardRegistry::runCommandOnShard(OperationContext* txn,
                                            readPref.pref == ReadPreference::PrimaryOnly
                                                ? rpc::makeEmptyMetadata()
                                                : kSecondaryOkMetadata,
-                                           kNotMasterErrors);
+                                           kAllRetriableErrors);
     if (!response.isOK()) {
         return response.getStatus();
     }
@@ -662,24 +668,26 @@ StatusWith<BSONObj> ShardRegistry::runCommandOnShard(OperationContext* txn,
     return response.getValue().response;
 }
 
-StatusWith<BSONObj> ShardRegistry::runCommandOnShard(OperationContext* txn,
-                                                     ShardId shardId,
-                                                     const ReadPreferenceSetting& readPref,
-                                                     const std::string& dbName,
-                                                     const BSONObj& cmdObj) {
+StatusWith<BSONObj> ShardRegistry::runIdempotentCommandOnShard(
+    OperationContext* txn,
+    ShardId shardId,
+    const ReadPreferenceSetting& readPref,
+    const std::string& dbName,
+    const BSONObj& cmdObj) {
     auto shard = getShard(txn, shardId);
     if (!shard) {
         return {ErrorCodes::ShardNotFound, str::stream() << "shard " << shardId << " not found"};
     }
-    return runCommandOnShard(txn, shard, readPref, dbName, cmdObj);
+    return runIdempotentCommandOnShard(txn, shard, readPref, dbName, cmdObj);
 }
 
 
-StatusWith<BSONObj> ShardRegistry::runCommandForAddShard(OperationContext* txn,
-                                                         const std::shared_ptr<Shard>& shard,
-                                                         const ReadPreferenceSetting& readPref,
-                                                         const std::string& dbName,
-                                                         const BSONObj& cmdObj) {
+StatusWith<BSONObj> ShardRegistry::runIdempotentCommandForAddShard(
+    OperationContext* txn,
+    const std::shared_ptr<Shard>& shard,
+    const ReadPreferenceSetting& readPref,
+    const std::string& dbName,
+    const BSONObj& cmdObj) {
     auto status = _runCommandWithRetries(txn,
                                          _executorForAddShard.get(),
                                          shard,
@@ -689,7 +697,7 @@ StatusWith<BSONObj> ShardRegistry::runCommandForAddShard(OperationContext* txn,
                                          readPref.pref == ReadPreference::PrimaryOnly
                                              ? rpc::makeEmptyMetadata()
                                              : kSecondaryOkMetadata,
-                                         kNotMasterErrors);
+                                         kAllRetriableErrors);
     if (!status.isOK()) {
         return status.getStatus();
     }
@@ -697,10 +705,11 @@ StatusWith<BSONObj> ShardRegistry::runCommandForAddShard(OperationContext* txn,
     return status.getValue().response;
 }
 
-StatusWith<BSONObj> ShardRegistry::runCommandOnConfig(OperationContext* txn,
-                                                      const ReadPreferenceSetting& readPref,
-                                                      const std::string& dbName,
-                                                      const BSONObj& cmdObj) {
+StatusWith<BSONObj> ShardRegistry::runIdempotentCommandOnConfig(
+    OperationContext* txn,
+    const ReadPreferenceSetting& readPref,
+    const std::string& dbName,
+    const BSONObj& cmdObj) {
     auto response = _runCommandWithRetries(
         txn,
         _executorPool->getFixedExecutor(),
@@ -709,7 +718,7 @@ StatusWith<BSONObj> ShardRegistry::runCommandOnConfig(OperationContext* txn,
         dbName,
         cmdObj,
         readPref.pref == ReadPreference::PrimaryOnly ? kReplMetadata : kReplSecondaryOkMetadata,
-        kNotMasterErrors);
+        kAllRetriableErrors);
 
     if (!response.isOK()) {
         return response.getStatus();
@@ -718,28 +727,6 @@ StatusWith<BSONObj> ShardRegistry::runCommandOnConfig(OperationContext* txn,
     return response.getValue().response;
 }
 
-StatusWith<BSONObj> ShardRegistry::runCommandWithNotMasterRetries(OperationContext* txn,
-                                                                  const ShardId& shardId,
-                                                                  const std::string& dbname,
-                                                                  const BSONObj& cmdObj) {
-    auto shard = getShard(txn, shardId);
-    invariant(!shard->isConfig());
-
-    auto response = _runCommandWithRetries(txn,
-                                           _executorPool->getFixedExecutor(),
-                                           shard,
-                                           ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                           dbname,
-                                           cmdObj,
-                                           rpc::makeEmptyMetadata(),
-                                           kNotMasterErrors);
-    if (!response.isOK()) {
-        return response.getStatus();
-    }
-
-    return response.getValue().response;
-}
-
 StatusWith<BSONObj> ShardRegistry::runCommandOnConfigWithRetries(
     OperationContext* txn,
     const std::string& dbname,
@@ -809,7 +796,11 @@ StatusWith<ShardRegistry::CommandResponse> ShardRegistry::_runCommandWithMetadat
     }
 
     executor::RemoteCommandRequest request(
-        host.getValue(), dbName, cmdObj, metadata, kConfigCommandTimeout);
+        host.getValue(),
+        dbName,
+        cmdObj,
+        metadata,
+        shard->isConfig() ? kConfigCommandTimeout : executor::RemoteCommandRequest::kNoTimeout);
     StatusWith<executor::RemoteCommandResponse> responseStatus =
         Status(ErrorCodes::InternalError, "Internal error running command");
 
@@ -846,11 +837,17 @@ StatusWith<ShardRegistry::CommandResponse> ShardRegistry::_runCommandWithMetadat
             return replParseStatus.getStatus();
         }
 
+        // Use the last committed optime to advance config optime.
+        // For successful majority writes, we could use the optime of the last op
+        // from us and lastOpCommitted is always greater than or equal to it.
+        // On majority write failures, the last visible optime would be incorrect
+        // due to rollback as explained in SERVER-24630 and the last committed optime
+        // is safe to use.
         const auto& replMetadata = replParseStatus.getValue();
-        cmdResponse.visibleOpTime = replMetadata.getLastOpVisible();
+        const OpTime lastCommittedOpTime = replMetadata.getLastOpCommitted();
 
         if (shard->isConfig()) {
-            advanceConfigOpTime(cmdResponse.visibleOpTime);
+            advanceConfigOpTime(lastCommittedOpTime);
         }
     }
 
@@ -874,13 +871,13 @@ void ShardRegistry::updateReplSetMonitor(const std::shared_ptr<RemoteCommandTarg
 
     if (ErrorCodes::isNotMasterError(remoteCommandStatus.code()) ||
         (remoteCommandStatus == ErrorCodes::InterruptedDueToReplStateChange)) {
-        targeter->markHostNotMaster(remoteHost);
+        targeter->markHostNotMaster(remoteHost, remoteCommandStatus);
     } else if (ErrorCodes::isNetworkError(remoteCommandStatus.code())) {
-        targeter->markHostUnreachable(remoteHost);
+        targeter->markHostUnreachable(remoteHost, remoteCommandStatus);
     } else if (remoteCommandStatus == ErrorCodes::NotMasterOrSecondary) {
-        targeter->markHostUnreachable(remoteHost);
+        targeter->markHostUnreachable(remoteHost, remoteCommandStatus);
     } else if (remoteCommandStatus == ErrorCodes::ExceededTimeLimit) {
-        targeter->markHostUnreachable(remoteHost);
+        targeter->markHostUnreachable(remoteHost, remoteCommandStatus);
     }
 }
 
