@@ -51,6 +51,7 @@
 #include "mongo/s/commands/cluster_commands_common.h"
 #include "mongo/s/config.h"
 #include "mongo/s/grid.h"
+#include "mongo/s/query/cluster_query_knobs.h"
 #include "mongo/s/query/store_possible_cursor.h"
 #include "mongo/s/stale_exception.h"
 #include "mongo/util/log.h"
@@ -237,7 +238,8 @@ public:
         // Run merging command on random shard, unless a stage needs the primary shard. Need to use
         // ShardConnection so that the merging mongod is sent the config servers on connection init.
         auto& prng = txn->getClient()->getPrng();
-        const auto& mergingShardId = needPrimaryShardMerger
+        const auto& mergingShardId =
+            (needPrimaryShardMerger || internalQueryAlwaysMergeOnPrimaryShard)
             ? conf->getPrimaryId()
             : shardResults[prng.nextInt32(shardResults.size())].shardTargetId;
         const auto mergingShard = grid.shardRegistry()->getShard(txn, mergingShardId);
