@@ -44,6 +44,7 @@
 #include "mongo/db/commands.h"
 #include "mongo/db/db_raii.h"
 #include "mongo/db/dbhelpers.h"
+#include "mongo/db/exec/working_set_common.h"
 #include "mongo/db/index_legacy.h"
 #include "mongo/db/index/index_descriptor.h"
 #include "mongo/db/instance.h"
@@ -173,7 +174,8 @@ public:
 
         RecordId loc;
         BSONObj currKey;
-        while (PlanExecutor::ADVANCED == exec->getNext(&currKey, &loc)) {
+        PlanExecutor::ExecState state;
+        while (PlanExecutor::ADVANCED == (state = exec->getNext(&currKey, &loc))) {
             // check that current key contains non missing elements for all fields in keyPattern
             BSONObjIterator i(currKey);
             for (int k = 0; k < keyPatternLength; k++) {
@@ -210,6 +212,14 @@ public:
             }
         }
 
+        if (PlanExecutor::DEAD == state || PlanExecutor::FAILURE == state) {
+            return appendCommandStatus(
+                result,
+                Status(ErrorCodes::OperationFailed,
+                       str::stream() << "Executor error while checking sharding index: "
+                                     << WorkingSetCommon::toStatusString(currKey)));
+        }
+
         return true;
     }
 } cmdCheckShardingIndex;
@@ -455,6 +465,14 @@ public:
                     state = exec->getNext(&currKey, NULL);
                 }
 
+                if (PlanExecutor::DEAD == state || PlanExecutor::FAILURE == state) {
+                    return appendCommandStatus(
+                        result,
+                        Status(ErrorCodes::OperationFailed,
+                               str::stream() << "Executor error during splitVector command: "
+                                             << WorkingSetCommon::toStatusString(currKey)));
+                }
+
                 if (!forceMedianSplit)
                     break;
 
@@ -808,6 +826,21 @@ public:
             preCond.append(b.obj());
         }
 
+        // NOTE: The newShardVersion resulting from this split is higher than any
+        // other chunk version, so it's also implicitly the newCollVersion
+        ChunkVersion newShardVersion = collVersion;
+
+        // Increment the minor version once, splitChunk increments once per split point
+        // (resulting in the correct final shard/collection version)
+        //
+        // TODO: Revisit this interface, it's a bit clunky
+        newShardVersion.incMinor();
+
+        string errMsg;
+        unique_ptr<CollectionMetadata> cloned(
+            collMetadata->cloneSplit(origChunk, splitKeys, newShardVersion, &errMsg));
+        uassert(ErrorCodes::IllegalOperation, errMsg, cloned.get());
+
         //
         // 4. apply the batch of updates to remote and local metadata
         //
@@ -827,17 +860,7 @@ public:
             Lock::DBLock writeLk(txn->lockState(), nss.db(), MODE_IX);
             Lock::CollectionLock collLock(txn->lockState(), nss.ns(), MODE_X);
 
-            // NOTE: The newShardVersion resulting from this split is higher than any
-            // other chunk version, so it's also implicitly the newCollVersion
-            ChunkVersion newShardVersion = collVersion;
-
-            // Increment the minor version once, splitChunk increments once per split point
-            // (resulting in the correct final shard/collection version)
-            //
-            // TODO: Revisit this interface, it's a bit clunky
-            newShardVersion.incMinor();
-
-            shardingState->splitChunk(txn, nss.ns(), min, max, splitKeys, newShardVersion);
+            shardingState->exchangeCollectionMetadata(txn, nss, std::move(cloned));
         }
 
         //
@@ -939,12 +962,17 @@ private:
                                                                  PlanExecutor::YIELD_MANUAL));
 
         // check if exactly one document found
-        if (PlanExecutor::ADVANCED == exec->getNext(NULL, NULL)) {
-            if (PlanExecutor::IS_EOF == exec->getNext(NULL, NULL)) {
+        PlanExecutor::ExecState state;
+        BSONObj obj;
+        if (PlanExecutor::ADVANCED == (state = exec->getNext(&obj, NULL))) {
+            if (PlanExecutor::IS_EOF == (state = exec->getNext(&obj, NULL))) {
                 return true;
             }
         }
 
+        // Non-yielding collection scans from InternalPlanner will never error.
+        invariant(PlanExecutor::ADVANCED == state || PlanExecutor::IS_EOF == state);
+
         return false;
     }
 
