@@ -95,10 +95,18 @@ bool gFirstRuntimeCreated = false;
 MONGO_TRIVIALLY_CONSTRUCTIBLE_THREAD_LOCAL MozJSImplScope* kCurrentScope;
 
 struct MozJSImplScope::MozJSEntry {
-    MozJSEntry(MozJSImplScope* scope) : ar(scope->_context), ac(scope->_context, scope->_global) {}
+    MozJSEntry(MozJSImplScope* scope)
+        : ar(scope->_context), ac(scope->_context, scope->_global), _scope(scope) {
+        ++_scope->_inOp;
+    }
+
+    ~MozJSEntry() {
+        --_scope->_inOp;
+    }
 
     JSAutoRequest ar;
     JSAutoCompartment ac;
+    MozJSImplScope* _scope;
 };
 
 void MozJSImplScope::_reportError(JSContext* cx, const char* message, JSErrorReport* report) {
@@ -136,23 +144,23 @@ std::string MozJSImplScope::getError() {
 }
 
 void MozJSImplScope::registerOperation(OperationContext* txn) {
-    invariant(_opId == 0);
+    invariant(_opCtx == nullptr);
 
     // getPooledScope may call registerOperation with a nullptr, so we have to
     // check for that here.
     if (!txn)
         return;
 
+    _opCtx = txn;
     _opId = txn->getOpID();
 
     _engine->registerOperation(txn, this);
 }
 
 void MozJSImplScope::unregisterOperation() {
-    if (_opId != 0) {
+    if (_opCtx) {
         _engine->unregisterOperation(_opId);
-
-        _opId = 0;
+        _opCtx = nullptr;
     }
 }
 
@@ -161,6 +169,10 @@ void MozJSImplScope::kill() {
     JS_RequestInterruptCallback(_runtime);
 }
 
+void MozJSImplScope::interrupt() {
+    JS_RequestInterruptCallback(_runtime);
+}
+
 bool MozJSImplScope::isKillPending() const {
     return _pendingKill.load();
 }
@@ -191,6 +203,14 @@ bool MozJSImplScope::_interruptCallback(JSContext* cx) {
     } else if (scope->isKillPending()) {
         scope->_status = Status(ErrorCodes::Interrupted, "Interrupted by the host");
     }
+    // If we are on the right thread, in the middle of an operation, and we have a registered opCtx,
+    // then we should check the opCtx for interrupts.
+    if ((scope->_mr._thread == PR_GetCurrentThread()) && (scope->_inOp > 0) && scope->_opCtx) {
+        auto status = scope->_opCtx->checkForInterruptNoAssert();
+        if (!status.isOK()) {
+            scope->_status = status;
+        }
+    }
 
     if (!scope->_status.isOK()) {
         scope->_engine->getDeadlineMonitor().stopDeadline(scope);
@@ -296,6 +316,7 @@ MozJSImplScope::MozJSImplScope(MozJSScriptEngine* engine)
       _pendingKill(false),
       _opId(0),
       _opCtx(nullptr),
+      _inOp(0),
       _pendingGC(false),
       _connectState(ConnectState::Not),
       _status(Status::OK()),
@@ -466,11 +487,20 @@ BSONObj MozJSImplScope::getObject(const char* field) {
 void MozJSImplScope::newFunction(StringData raw, JS::MutableHandleValue out) {
     MozJSEntry entry(this);
 
-    std::string code = str::stream() << "____MongoToSM_newFunction_temp = " << raw;
+    _MozJSCreateFunction(raw, std::move(out));
+}
+
+void MozJSImplScope::_MozJSCreateFunction(StringData raw, JS::MutableHandleValue fun) {
+    std::string code = str::stream()
+        << "(" << parseJSFunctionOrExpression(_context, StringData(raw)) << ")";
 
     JS::CompileOptions co(_context);
     setCompileOptions(&co);
-    _checkErrorState(JS::Evaluate(_context, _global, co, code.c_str(), code.length(), out));
+
+    _checkErrorState(JS::Evaluate(_context, _global, co, code.c_str(), code.length(), fun));
+    uassert(10232,
+            "not a function",
+            fun.isObject() && JS_ObjectIsFunction(_context, fun.toObjectOrNull()));
 }
 
 BSONObj MozJSImplScope::callThreadArgs(const BSONObj& args) {
@@ -511,39 +541,20 @@ bool hasFunctionIdentifier(StringData code) {
     return code[8] == ' ' || code[8] == '(';
 }
 
-void MozJSImplScope::_MozJSCreateFunction(const char* raw,
-                                          ScriptingFunction functionNumber,
-                                          JS::MutableHandleValue fun) {
-    std::string code = str::stream() << "_funcs" << functionNumber << " = "
-                                     << parseJSFunctionOrExpression(_context, StringData(raw));
-
-    JS::CompileOptions co(_context);
-    setCompileOptions(&co);
-
-    _checkErrorState(JS::Evaluate(_context, _global, co, code.c_str(), code.length(), fun));
-    uassert(10232,
-            "not a function",
-            fun.isObject() && JS_ObjectIsFunction(_context, fun.toObjectOrNull()));
-}
-
-ScriptingFunction MozJSImplScope::_createFunction(const char* raw,
-                                                  ScriptingFunction functionNumber) {
+ScriptingFunction MozJSImplScope::_createFunction(const char* raw) {
     MozJSEntry entry(this);
 
     JS::RootedValue fun(_context);
-    _MozJSCreateFunction(raw, functionNumber, &fun);
+    _MozJSCreateFunction(raw, &fun);
     _funcs.emplace_back(_context, fun.get());
-
-    return functionNumber;
+    return _funcs.size();
 }
 
 void MozJSImplScope::setFunction(const char* field, const char* code) {
     MozJSEntry entry(this);
 
     JS::RootedValue fun(_context);
-
-    _MozJSCreateFunction(code, getFunctionCache().size() + 1, &fun);
-
+    _MozJSCreateFunction(code, &fun);
     ObjectWrapper(_context, _global).setValue(field, fun);
 }
 
@@ -589,14 +600,16 @@ int MozJSImplScope::invoke(ScriptingFunction func,
 
     if (timeoutMs)
         _engine->getDeadlineMonitor().startDeadline(this, timeoutMs);
+    else {
+        _engine->getDeadlineMonitor().startDeadline(this, -1);
+    }
 
     JS::RootedValue out(_context);
     JS::RootedObject obj(_context, smrecv.toObjectOrNull());
 
     bool success = JS::Call(_context, obj, funcValue, args, &out);
 
-    if (timeoutMs)
-        _engine->getDeadlineMonitor().stopDeadline(this);
+    _engine->getDeadlineMonitor().stopDeadline(this);
 
     _checkErrorState(success);
 
@@ -634,15 +647,17 @@ bool MozJSImplScope::exec(StringData code,
     if (_checkErrorState(success, reportError, assertOnError))
         return false;
 
-    if (timeoutMs)
+    if (timeoutMs) {
         _engine->getDeadlineMonitor().startDeadline(this, timeoutMs);
+    } else {
+        _engine->getDeadlineMonitor().startDeadline(this, -1);
+    }
 
     JS::RootedValue out(_context);
 
     success = JS_ExecuteScript(_context, _global, script, &out);
 
-    if (timeoutMs)
-        _engine->getDeadlineMonitor().stopDeadline(this);
+    _engine->getDeadlineMonitor().stopDeadline(this);
 
     if (_checkErrorState(success, reportError, assertOnError))
         return false;
@@ -677,9 +692,6 @@ void MozJSImplScope::gc() {
 void MozJSImplScope::localConnectForDbEval(OperationContext* txn, const char* dbName) {
     MozJSEntry entry(this);
 
-    invariant(_opCtx == NULL);
-    _opCtx = txn;
-
     if (_connectState == ConnectState::External)
         uasserted(12510, "externalSetup already called, can't call localConnect");
     if (_connectState == ConnectState::Local) {
@@ -692,6 +704,11 @@ void MozJSImplScope::localConnectForDbEval(OperationContext* txn, const char* db
     // NOTE: order is important here.  the following methods must be called after
     //       the above conditional statements.
 
+    _connectState = ConnectState::Local;
+    _localDBName = dbName;
+
+    loadStored(txn);
+
     // install db access functions in the global object
     installDBAccess();
 
@@ -699,16 +716,11 @@ void MozJSImplScope::localConnectForDbEval(OperationContext* txn, const char* db
     _mongoLocalProto.install(_global);
     execCoreFiles();
 
-    const char* const makeMongo = "_mongo = new Mongo()";
+    const char* const makeMongo = "const _mongo = new Mongo()";
     exec(makeMongo, "local connect 2", false, true, true, 0);
 
-    std::string makeDB = str::stream() << "db = _mongo.getDB(\"" << dbName << "\");";
+    std::string makeDB = str::stream() << "const db = _mongo.getDB(\"" << dbName << "\");";
     exec(makeDB, "local connect 3", false, true, true, 0);
-
-    _connectState = ConnectState::Local;
-    _localDBName = dbName;
-
-    loadStored(txn);
 }
 
 void MozJSImplScope::externalSetup() {
