@@ -280,7 +280,6 @@ Mongo.prototype.writeMode = function() {
     if (this.hasWriteCommands()) {
         // good with whatever is already set
     } else if (this._writeMode == "commands") {
-        print("Cannot use commands write mode, degrading to compatibility mode");
         this._writeMode = "compatibility";
     }
 
@@ -334,7 +333,6 @@ Mongo.prototype.readMode = function() {
             if (hasReadCommands && !this.isReplicaSetConnection()) {
                 this._readMode = "commands";
             } else {
-                print("Cannot use 'commands' readMode, degrading to 'legacy' mode");
                 this._readMode = "legacy";
             }
         } catch (e) {
