@@ -89,6 +89,8 @@ var ReplSetTest = function(opts) {
     var _unbridgedPorts;
     var _unbridgedNodes;
 
+    this.kDefaultTimeoutMS = 5 * 60 * 1000;
+
     // Publicly exposed variables
 
     /**
@@ -161,7 +163,7 @@ var ReplSetTest = function(opts) {
             return;
         }
 
-        timeout = timeout || 30000;
+        timeout = timeout || self.kDefaultTimeoutMS;
 
         if (!node.getDB) {
             node = self.nodes[node];
@@ -179,7 +181,7 @@ var ReplSetTest = function(opts) {
         var currTime = new Date().getTime();
         var status;
 
-        assert.soon(function() {
+        assert.soonNoExcept(function() {
             try {
                 var conn = _callIsMaster();
                 if (!conn) {
@@ -401,9 +403,9 @@ var ReplSetTest = function(opts) {
      * Blocks until the secondary nodes have completed recovery and their roles are known.
      */
     this.awaitSecondaryNodes = function(timeout) {
-        timeout = timeout || 60000;
+        timeout = timeout || self.kDefaultTimeoutMS;
 
-        assert.soon(function() {
+        assert.soonNoExcept(function() {
             // Reload who the current slaves are
             self.getPrimary(timeout);
 
@@ -443,45 +445,44 @@ var ReplSetTest = function(opts) {
 
     /**
      * Blocks until all nodes agree on who the primary is.
+     * If 'expectedPrimaryNodeId' is provided, ensure that every node is seeing this node as the
+     * primary. Otherwise, ensure that all the nodes in the set agree with the first node on the
+     * identity of the primary.
      */
-    this.awaitNodesAgreeOnPrimary = function(timeout) {
-        timeout = timeout || 60000;
+    this.awaitNodesAgreeOnPrimary = function(timeout, nodes, expectedPrimaryNodeId) {
+        timeout = timeout || self.kDefaultTimeoutMS;
+        nodes = nodes || self.nodes;
+        expectedPrimaryNodeId = expectedPrimaryNodeId || -1;
 
-        assert.soon(function() {
-            try {
-                var primary = -1;
+        assert.soonNoExcept(function() {
+            var primary = expectedPrimaryNodeId;
 
-                for (var i = 0; i < self.nodes.length; i++) {
-                    var replSetGetStatus =
-                        self.nodes[i].getDB("admin").runCommand({replSetGetStatus: 1});
-                    var nodesPrimary = -1;
-                    for (var j = 0; j < replSetGetStatus.members.length; j++) {
-                        if (replSetGetStatus.members[j].state === ReplSetTest.State.PRIMARY) {
-                            // Node sees two primaries.
-                            if (nodesPrimary !== -1) {
-                                return false;
-                            }
-                            nodesPrimary = j;
+            for (var i = 0; i < nodes.length; i++) {
+                var replSetGetStatus = nodes[i].getDB("admin").runCommand({replSetGetStatus: 1});
+                var nodesPrimary = -1;
+                for (var j = 0; j < replSetGetStatus.members.length; j++) {
+                    if (replSetGetStatus.members[j].state === ReplSetTest.State.PRIMARY) {
+                        // Node sees two primaries.
+                        if (nodesPrimary !== -1) {
+                            return false;
                         }
-                    }
-                    // Node doesn't see a primary.
-                    if (nodesPrimary < 0) {
-                        return false;
-                    }
-
-                    if (primary < 0) {
-                        // If we haven't seen a primary yet, set it to this.
-                        primary = nodesPrimary;
-                    } else if (primary !== nodesPrimary) {
-                        return false;
+                        nodesPrimary = j;
                     }
                 }
+                // Node doesn't see a primary.
+                if (nodesPrimary < 0) {
+                    return false;
+                }
 
-                return true;
-            } catch (e) {
-                print("caught exception " + e);
-                return false;
+                if (primary < 0) {
+                    // If we haven't seen a primary yet, set it to this.
+                    primary = nodesPrimary;
+                } else if (primary !== nodesPrimary) {
+                    return false;
+                }
             }
+
+            return true;
         }, "Awaiting nodes to agree on primary", timeout);
     };
 
@@ -490,10 +491,10 @@ var ReplSetTest = function(opts) {
      * if primary is available will return a connection to it. Otherwise throws an exception.
      */
     this.getPrimary = function(timeout) {
-        timeout = timeout || 60000;
+        timeout = timeout || self.kDefaultTimeoutMS;
         var primary = null;
 
-        assert.soon(function() {
+        assert.soonNoExcept(function() {
             primary = _callIsMaster();
             return primary;
         }, "Finding primary", timeout);
@@ -503,9 +504,9 @@ var ReplSetTest = function(opts) {
 
     this.awaitNoPrimary = function(msg, timeout) {
         msg = msg || "Timed out waiting for there to be no primary in replset: " + this.name;
-        timeout = timeout || 30000;
+        timeout = timeout || self.kDefaultTimeoutMS;
 
-        assert.soon(function() {
+        assert.soonNoExcept(function() {
             return _callIsMaster() == false;
         }, msg, timeout);
     };
@@ -572,7 +573,7 @@ var ReplSetTest = function(opts) {
         var config = cfg || this.getReplSetConfig();
         var cmd = {};
         var cmdKey = initCmd || 'replSetInitiate';
-        timeout = timeout || 120000;
+        timeout = timeout || self.kDefaultTimeoutMS;
         if (jsTestOptions().useLegacyReplicationProtocol &&
             !config.hasOwnProperty("protocolVersion")) {
             config.protocolVersion = 0;
@@ -590,6 +591,49 @@ var ReplSetTest = function(opts) {
         }
     };
 
+    /**
+     * Steps up 'node' as primary.
+     * Waits for all nodes to reach the same optime before each election.
+     * Calls awaitReplication() which requires all connections in 'nodes' to be authenticated.
+     */
+    this.stepUp = function(node) {
+        this.awaitReplication();
+        this.awaitNodesAgreeOnPrimary();
+        if (this.getPrimary() === node) {
+            print("Node " + node.host + " is already primary, no need to step it up.");
+            return;
+        }
+        print("Stepping up node " + node.host);
+
+        // Ensure the specified node is primary.
+        for (var i = 0; i < this.nodes.length; i++) {
+            var primary = this.getPrimary();
+            if (primary === node) {
+                break;
+            }
+            try {
+                // Make sure the nodes do not step back up for 10 minutes.
+                assert.commandWorked(primary.adminCommand({replSetStepDown: 10 * 60, force: true}));
+            } catch (ex) {
+                print("Caught exception while stepping down node '" + tojson(node.host) + "': " +
+                      tojson(ex));
+            }
+            this.awaitReplication();
+            this.awaitNodesAgreeOnPrimary();
+        }
+
+        // Reset the rest of the nodes so they can run for election during the test.
+        for (var i = 0; i < this.nodes.length; i++) {
+            // Cannot call replSetFreeze on the primary.
+            if (this.nodes[i] === node) {
+                continue;
+            }
+            assert.commandWorked(this.nodes[i].adminCommand({replSetFreeze: 0}));
+        }
+
+        assert.eq(this.getPrimary(), node, node.host + " was not primary after stepUp");
+    };
+
     /**
      * Gets the current replica set config from the specified node index. If no nodeId is specified,
      * uses the primary node.
@@ -678,7 +722,7 @@ var ReplSetTest = function(opts) {
         print("Waiting for op with OpTime " + tojson(opTime) +
               " to be committed on all secondaries");
 
-        assert.soon(function() {
+        assert.soonNoExcept(function() {
             for (var i = 0; i < rst.nodes.length; i++) {
                 var node = rst.nodes[i];
 
@@ -712,14 +756,14 @@ var ReplSetTest = function(opts) {
     };
 
     this.awaitReplication = function(timeout) {
-        timeout = timeout || 30000;
+        timeout = timeout || self.kDefaultTimeoutMS;
 
         var masterLatestOpTime;
 
         // Blocking call, which will wait for the last optime written on the master to be available
         var awaitLastOpTimeWrittenFn = function() {
             var master = self.getPrimary();
-            assert.soon(function() {
+            assert.soonNoExcept(function() {
                 try {
                     masterLatestOpTime = _getLastOpTime(master);
                 } catch (e) {
@@ -728,7 +772,7 @@ var ReplSetTest = function(opts) {
                 }
 
                 return true;
-            }, "awaiting oplog query", 30000);
+            }, "awaiting oplog query", timeout);
         };
 
         awaitLastOpTimeWrittenFn();
@@ -756,7 +800,7 @@ var ReplSetTest = function(opts) {
               ", is " + tojson(masterLatestOpTime) + ", last oplog entry is " +
               tojsononeline(masterOpTime));
 
-        assert.soon(function() {
+        assert.soonNoExcept(function() {
             try {
                 print("ReplSetTest awaitReplication: checking secondaries against timestamp " +
                       tojson(masterLatestOpTime));
@@ -1191,7 +1235,7 @@ var ReplSetTest = function(opts) {
      */
     this.waitForMaster = function(timeout) {
         var master;
-        assert.soon(function() {
+        assert.soonNoExcept(function() {
             return (master = self.getPrimary());
         }, "waiting for master", timeout);
 
@@ -1310,7 +1354,7 @@ ReplSetTest.awaitRSClientHosts = function(conn, host, hostOk, rs, timeout) {
         return;
     }
 
-    timeout = timeout || 60000;
+    timeout = timeout || 5 * 60 * 1000;
 
     if (hostOk == undefined)
         hostOk = {
@@ -1325,7 +1369,7 @@ ReplSetTest.awaitRSClientHosts = function(conn, host, hostOk, rs, timeout) {
 
     var tests = 0;
 
-    assert.soon(function() {
+    assert.soonNoExcept(function() {
         var rsClientHosts = conn.adminCommand('connPoolStats').replicaSets;
         if (tests++ % 10 == 0) {
             printjson(rsClientHosts);
