@@ -1,5 +1,5 @@
 // Date and time types
-if (typeof(Timestamp) != "undefined"){
+if (typeof(Timestamp) != "undefined") {
     Timestamp.prototype.tojson = function() {
         return this.toString();
     };
@@ -15,32 +15,31 @@ if (typeof(Timestamp) != "undefined"){
     Timestamp.prototype.toString = function() {
         return "Timestamp(" + this.t + ", " + this.i + ")";
     };
-}
-else {
+} else {
     print("warning: no Timestamp class");
 }
 
-Date.timeFunc = function(theFunc, numTimes){
+Date.timeFunc = function(theFunc, numTimes) {
     var start = new Date();
     numTimes = numTimes || 1;
-    for (var i=0; i<numTimes; i++){
+    for (var i = 0; i < numTimes; i++) {
         theFunc.apply(null, argumentsToArray(arguments).slice(2));
     }
 
     return (new Date()).getTime() - start.getTime();
 };
 
-Date.prototype.tojson = function(){
+Date.prototype.tojson = function() {
     var UTC = 'UTC';
-    var year = this['get'+UTC+'FullYear']().zeroPad(4);
-    var month = (this['get'+UTC+'Month']() + 1).zeroPad(2);
-    var date = this['get'+UTC+'Date']().zeroPad(2);
-    var hour = this['get'+UTC+'Hours']().zeroPad(2);
-    var minute = this['get'+UTC+'Minutes']().zeroPad(2);
-    var sec = this['get'+UTC+'Seconds']().zeroPad(2);
+    var year = this['get' + UTC + 'FullYear']().zeroPad(4);
+    var month = (this['get' + UTC + 'Month']() + 1).zeroPad(2);
+    var date = this['get' + UTC + 'Date']().zeroPad(2);
+    var hour = this['get' + UTC + 'Hours']().zeroPad(2);
+    var minute = this['get' + UTC + 'Minutes']().zeroPad(2);
+    var sec = this['get' + UTC + 'Seconds']().zeroPad(2);
 
-    if (this['get'+UTC+'Milliseconds']())
-        sec += '.' + this['get'+UTC+'Milliseconds']().zeroPad(3);
+    if (this['get' + UTC + 'Milliseconds']())
+        sec += '.' + this['get' + UTC + 'Milliseconds']().zeroPad(3);
 
     var ofs = 'Z';
     // // print a non-UTC time
@@ -50,25 +49,27 @@ Date.prototype.tojson = function(){
     //     ofs += (ofsmin/60).zeroPad(2)
     //     ofs += (ofsmin%60).zeroPad(2)
     // }
-    return 'ISODate("'+year+'-'+month+'-'+date+'T'+hour+':'+minute+':'+sec+ofs+'")';
+    return 'ISODate("' + year + '-' + month + '-' + date + 'T' + hour + ':' + minute + ':' + sec +
+        ofs + '")';
 };
 
-ISODate = function(isoDateStr){
+ISODate = function(isoDateStr) {
     if (!isoDateStr)
         return new Date();
 
-    var isoDateRegex = /(\d{4})-?(\d{2})-?(\d{2})([T ](\d{2})(:?(\d{2})(:?(\d{2}(\.\d+)?))?)?(Z|([+-])(\d{2}):?(\d{2})?)?)?/;
+    var isoDateRegex =
+        /(\d{4})-?(\d{2})-?(\d{2})([T ](\d{2})(:?(\d{2})(:?(\d{2}(\.\d+)?))?)?(Z|([+-])(\d{2}):?(\d{2})?)?)?/;
     var res = isoDateRegex.exec(isoDateStr);
 
     if (!res)
         throw Error("invalid ISO date");
 
-    var year = parseInt(res[1],10) || 1970; // this should always be present
-    var month = (parseInt(res[2],10) || 1) - 1;
-    var date = parseInt(res[3],10) || 0;
-    var hour = parseInt(res[5],10) || 0;
-    var min = parseInt(res[7],10) || 0;
-    var sec = parseInt((res[9] && res[9].substr(0,2)),10) || 0;
+    var year = parseInt(res[1], 10) || 1970;  // this should always be present
+    var month = (parseInt(res[2], 10) || 1) - 1;
+    var date = parseInt(res[3], 10) || 0;
+    var hour = parseInt(res[5], 10) || 0;
+    var min = parseInt(res[7], 10) || 0;
+    var sec = parseInt((res[9] && res[9].substr(0, 2)), 10) || 0;
     var ms = Math.round((parseFloat(res[10]) || 0) * 1000);
     if (ms == 1000) {
         ms = 0;
@@ -83,9 +84,9 @@ ISODate = function(isoDateStr){
         ++hour;
     }
     if (hour == 24) {
-        hour = 0;   // the day wrapped, let JavaScript figure out the rest
+        hour = 0;  // the day wrapped, let JavaScript figure out the rest
         var tempTime = Date.UTC(year, month, date, hour, min, sec, ms);
-        tempTime += 24 * 60 * 60 * 1000;    // milliseconds in a day
+        tempTime += 24 * 60 * 60 * 1000;  // milliseconds in a day
         var tempDate = new Date(tempTime);
         year = tempDate.getUTCFullYear();
         month = tempDate.getUTCMonth();
@@ -94,11 +95,11 @@ ISODate = function(isoDateStr){
 
     var time = Date.UTC(year, month, date, hour, min, sec, ms);
 
-    if (res[11] && res[11] != 'Z'){
+    if (res[11] && res[11] != 'Z') {
         var ofs = 0;
-        ofs += (parseInt(res[13],10) || 0) * 60*60*1000; // hours
-        ofs += (parseInt(res[14],10) || 0) *    60*1000; // mins
-        if (res[12] == '+') // if ahead subtract
+        ofs += (parseInt(res[13], 10) || 0) * 60 * 60 * 1000;  // hours
+        ofs += (parseInt(res[14], 10) || 0) * 60 * 1000;       // mins
+        if (res[12] == '+')                                    // if ahead subtract
             ofs *= -1;
 
         time += ofs;
@@ -108,47 +109,47 @@ ISODate = function(isoDateStr){
 };
 
 // Regular Expression
-RegExp.escape = function(text){
+RegExp.escape = function(text) {
     return text.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
 };
 
 RegExp.prototype.tojson = RegExp.prototype.toString;
 
 // Array
-Array.contains = function(a, x){
+Array.contains = function(a, x) {
     if (!Array.isArray(a)) {
         throw new Error("The first argument to Array.contains must be an array");
     }
 
-    for (var i=0; i<a.length; i++){
+    for (var i = 0; i < a.length; i++) {
         if (a[i] == x)
             return true;
     }
     return false;
 };
 
-Array.unique = function(a){
+Array.unique = function(a) {
     if (!Array.isArray(a)) {
         throw new Error("The first argument to Array.unique must be an array");
     }
 
     var u = [];
-    for (var i=0; i<a.length; i++){
+    for (var i = 0; i < a.length; i++) {
         var o = a[i];
-        if (! Array.contains(u, o)){
+        if (!Array.contains(u, o)) {
             u.push(o);
         }
     }
     return u;
 };
 
-Array.shuffle = function(arr){
+Array.shuffle = function(arr) {
     if (!Array.isArray(arr)) {
         throw new Error("The first argument to Array.shuffle must be an array");
     }
 
-    for (var i=0; i<arr.length-1; i++){
-        var pos = i+Random.randInt(arr.length-i);
+    for (var i = 0; i < arr.length - 1; i++) {
+        var pos = i + Random.randInt(arr.length - i);
         var save = arr[i];
         arr[i] = arr[pos];
         arr[pos] = save;
@@ -156,7 +157,7 @@ Array.shuffle = function(arr){
     return arr;
 };
 
-Array.tojson = function(a, indent, nolint){
+Array.tojson = function(a, indent, nolint) {
     if (!Array.isArray(a)) {
         throw new Error("The first argument to Array.tojson must be an array");
     }
@@ -176,30 +177,30 @@ Array.tojson = function(a, indent, nolint){
 
     // add to indent if we are pretty
     if (!nolint)
-      indent += "\t";
+        indent += "\t";
 
-    for (var i=0; i<a.length; i++){
+    for (var i = 0; i < a.length; i++) {
         s += indent + tojson(a[i], indent, nolint);
-        if (i < a.length - 1){
+        if (i < a.length - 1) {
             s += "," + elementSeparator;
         }
     }
 
     // remove from indent if we are pretty
     if (!nolint)
-      indent = indent.substring(1);
+        indent = indent.substring(1);
 
     s += elementSeparator + indent + "]";
     return s;
 };
 
-Array.fetchRefs = function(arr, coll){
+Array.fetchRefs = function(arr, coll) {
     if (!Array.isArray(arr)) {
         throw new Error("The first argument to Array.fetchRefs must be an array");
     }
 
     var n = [];
-    for (var i=0; i<arr.length; i ++){
+    for (var i = 0; i < arr.length; i++) {
         var z = arr[i];
         if (coll && coll != z.getCollection())
             continue;
@@ -208,7 +209,7 @@ Array.fetchRefs = function(arr, coll){
     return n;
 };
 
-Array.sum = function(arr){
+Array.sum = function(arr) {
     if (!Array.isArray(arr)) {
         throw new Error("The first argument to Array.sum must be an array");
     }
@@ -216,12 +217,12 @@ Array.sum = function(arr){
     if (arr.length == 0)
         return null;
     var s = arr[0];
-    for (var i=1; i<arr.length; i++)
+    for (var i = 1; i < arr.length; i++)
         s += arr[i];
     return s;
 };
 
-Array.avg = function(arr){
+Array.avg = function(arr) {
     if (!Array.isArray(arr)) {
         throw new Error("The first argument to Array.avg must be an array");
     }
@@ -231,7 +232,7 @@ Array.avg = function(arr){
     return Array.sum(arr) / arr.length;
 };
 
-Array.stdDev = function(arr){
+Array.stdDev = function(arr) {
     if (!Array.isArray(arr)) {
         throw new Error("The first argument to Array.stdDev must be an array");
     }
@@ -239,7 +240,7 @@ Array.stdDev = function(arr){
     var avg = Array.avg(arr);
     var sum = 0;
 
-    for (var i=0; i<arr.length; i++){
+    for (var i = 0; i < arr.length; i++) {
         sum += Math.pow(arr[i] - avg, 2);
     }
 
@@ -247,16 +248,16 @@ Array.stdDev = function(arr){
 };
 
 // Object
-Object.extend = function(dst, src, deep){
-    for (var k in src){
+Object.extend = function(dst, src, deep) {
+    for (var k in src) {
         var v = src[k];
-        if (deep && typeof(v) == "object"){
-            if (v.constructor === ObjectId) { // convert ObjectId properly
+        if (deep && typeof(v) == "object" && v !== null) {
+            if (v.constructor === ObjectId) {  // convert ObjectId properly
                 eval("v = " + tojson(v));
-            } else if ("floatApprox" in v) { // convert NumberLong properly
+            } else if ("floatApprox" in v) {  // convert NumberLong properly
                 eval("v = " + tojson(v));
             } else {
-                v = Object.extend(typeof (v.length) == "number" ? [] : {}, v, true);
+                v = Object.extend(typeof(v.length) == "number" ? [] : {}, v, true);
             }
         }
         dst[k] = v;
@@ -264,15 +265,15 @@ Object.extend = function(dst, src, deep){
     return dst;
 };
 
-Object.merge = function(dst, src, deep){
+Object.merge = function(dst, src, deep) {
     var clone = Object.extend({}, dst, deep);
     return Object.extend(clone, src, deep);
 };
 
 Object.keySet = function(o) {
     var ret = new Array();
-    for(var i in o) {
-        if (!(i in o.__proto__ && o[ i ] === o.__proto__[ i ])) {
+    for (var i in o) {
+        if (!(i in o.__proto__ && o[i] === o.__proto__[i])) {
             ret.push(i);
         }
     }
@@ -282,17 +283,17 @@ Object.keySet = function(o) {
 // String
 if (String.prototype.trim === undefined) {
     String.prototype.trim = function() {
-        return this.replace(/^\s+|\s+$/g,"");
+        return this.replace(/^\s+|\s+$/g, "");
     };
 }
 if (String.prototype.trimLeft === undefined) {
     String.prototype.trimLeft = function() {
-        return this.replace(/^\s+/,"");
+        return this.replace(/^\s+/, "");
     };
 }
 if (String.prototype.trimRight === undefined) {
     String.prototype.trimRight = function() {
-        return this.replace(/\s+$/,"");
+        return this.replace(/\s+$/, "");
     };
 }
 
@@ -300,18 +301,19 @@ if (String.prototype.trimRight === undefined) {
 String.prototype.ltrim = String.prototype.trimLeft;
 String.prototype.rtrim = String.prototype.trimRight;
 
-String.prototype.startsWith = function(str){
+String.prototype.startsWith = function(str) {
     return this.indexOf(str) == 0;
 };
 
-String.prototype.endsWith = function(str){
+String.prototype.endsWith = function(str) {
     return this.indexOf(str, this.length - str.length) !== -1;
 };
 
 // Polyfill taken from
 // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/includes
 if (!String.prototype.includes) {
-    String.prototype.includes = function() {'use strict';
+    String.prototype.includes = function() {
+        'use strict';
         return String.prototype.indexOf.apply(this, arguments) !== -1;
     };
 }
@@ -324,7 +326,8 @@ if (!String.prototype.includes) {
 // @param chr character to be used for padding, defaults to whitespace
 // @return the padded string
 String.prototype.pad = function(length, right, chr) {
-    if (typeof chr == 'undefined') chr = ' ';
+    if (typeof chr == 'undefined')
+        chr = ' ';
     var str = this;
     for (var i = length - str.length; i > 0; i--) {
         if (right) {
@@ -346,7 +349,7 @@ Number.prototype.zeroPad = function(width) {
 };
 
 // NumberLong
-if (! NumberLong.prototype) {
+if (!NumberLong.prototype) {
     NumberLong.prototype = {};
 }
 
@@ -355,7 +358,7 @@ NumberLong.prototype.tojson = function() {
 };
 
 // NumberInt
-if (! NumberInt.prototype) {
+if (!NumberInt.prototype) {
     NumberInt.prototype = {};
 }
 
@@ -365,7 +368,7 @@ NumberInt.prototype.tojson = function() {
 
 // NumberDecimal
 if (typeof NumberDecimal !== 'undefined') {
-    if (! NumberDecimal.prototype) {
+    if (!NumberDecimal.prototype) {
         NumberDecimal.prototype = {};
     }
 
@@ -375,28 +378,28 @@ if (typeof NumberDecimal !== 'undefined') {
 }
 
 // ObjectId
-if (! ObjectId.prototype)
+if (!ObjectId.prototype)
     ObjectId.prototype = {};
 
-ObjectId.prototype.toString = function(){
+ObjectId.prototype.toString = function() {
     return "ObjectId(" + tojson(this.str) + ")";
 };
 
-ObjectId.prototype.tojson = function(){
+ObjectId.prototype.tojson = function() {
     return this.toString();
 };
 
-ObjectId.prototype.valueOf = function(){
+ObjectId.prototype.valueOf = function() {
     return this.str;
 };
 
 ObjectId.prototype.isObjectId = true;
 
-ObjectId.prototype.getTimestamp = function(){
-    return new Date(parseInt(this.valueOf().slice(0,8), 16)*1000);
+ObjectId.prototype.getTimestamp = function() {
+    return new Date(parseInt(this.valueOf().slice(0, 8), 16) * 1000);
 };
 
-ObjectId.prototype.equals = function(other){
+ObjectId.prototype.equals = function(other) {
     return this.str == other.str;
 };
 
@@ -420,10 +423,10 @@ ObjectId.fromDate = function(source) {
     }
 
     // Convert date object to seconds since Unix epoch.
-    var seconds = Math.floor(sourceDate.getTime()/1000);
+    var seconds = Math.floor(sourceDate.getTime() / 1000);
 
     // Generate hex timestamp with padding.
-    var hexTimestamp = seconds.toString(16).pad(8,false,'0') + "0000000000000000";
+    var hexTimestamp = seconds.toString(16).pad(8, false, '0') + "0000000000000000";
 
     // Create an ObjectId with hex timestamp.
     var objectId = ObjectId(hexTimestamp);
@@ -432,72 +435,71 @@ ObjectId.fromDate = function(source) {
 };
 
 // DBPointer
-if (typeof(DBPointer) != "undefined"){
-    DBPointer.prototype.fetch = function(){
+if (typeof(DBPointer) != "undefined") {
+    DBPointer.prototype.fetch = function() {
         assert(this.ns, "need a ns");
         assert(this.id, "need an id");
-        return db[ this.ns ].findOne({ _id : this.id });
+        return db[this.ns].findOne({_id: this.id});
     };
 
-    DBPointer.prototype.tojson = function(indent){
+    DBPointer.prototype.tojson = function(indent) {
         return this.toString();
     };
 
-    DBPointer.prototype.getCollection = function(){
+    DBPointer.prototype.getCollection = function() {
         return this.ns;
     };
 
-    DBPointer.prototype.getId = function(){
+    DBPointer.prototype.getId = function() {
         return this.id;
     };
 
-    DBPointer.prototype.toString = function(){
+    DBPointer.prototype.toString = function() {
         return "DBPointer(" + tojson(this.ns) + ", " + tojson(this.id) + ")";
     };
-}
-else {
+} else {
     print("warning: no DBPointer");
 }
 
 // DBRef
-if (typeof(DBRef) != "undefined"){
-    DBRef.prototype.fetch = function(){
+if (typeof(DBRef) != "undefined") {
+    DBRef.prototype.fetch = function() {
         assert(this.$ref, "need a ns");
         assert(this.$id, "need an id");
         var coll = this.$db ? db.getSiblingDB(this.$db).getCollection(this.$ref) : db[this.$ref];
-        return coll.findOne({ _id : this.$id });
+        return coll.findOne({_id: this.$id});
     };
 
-    DBRef.prototype.tojson = function(indent){
+    DBRef.prototype.tojson = function(indent) {
         return this.toString();
     };
 
-    DBRef.prototype.getDb = function(){
+    DBRef.prototype.getDb = function() {
         return this.$db || undefined;
     };
 
-    DBRef.prototype.getCollection = function(){
+    DBRef.prototype.getCollection = function() {
         return this.$ref;
     };
 
-    DBRef.prototype.getRef = function(){
+    DBRef.prototype.getRef = function() {
         return this.$ref;
     };
 
-    DBRef.prototype.getId = function(){
+    DBRef.prototype.getId = function() {
         return this.$id;
     };
 
-    DBRef.prototype.toString = function(){
-        return "DBRef(" + tojson(this.$ref) + ", " + tojson(this.$id) + (this.$db ? ", " + tojson(this.$db) : "") + ")";
+    DBRef.prototype.toString = function() {
+        return "DBRef(" + tojson(this.$ref) + ", " + tojson(this.$id) +
+            (this.$db ? ", " + tojson(this.$db) : "") + ")";
     };
-}
-else {
+} else {
     print("warning: no DBRef");
 }
 
 // BinData
-if (typeof(BinData) != "undefined"){
+if (typeof(BinData) != "undefined") {
     BinData.prototype.tojson = function() {
         return this.toString();
     };
@@ -508,87 +510,91 @@ if (typeof(BinData) != "undefined"){
     BinData.prototype.length = function() {
         return this.len;
     };
-}
-else {
+} else {
     print("warning: no BinData class");
 }
 
 // Map
-if (typeof(Map) == "undefined"){
-    Map = function(){
+if (typeof(Map) == "undefined") {
+    Map = function() {
         this._data = {};
     };
 }
 
-Map.hash = function(val){
-    if (! val)
+Map.hash = function(val) {
+    if (!val)
         return val;
 
-    switch (typeof(val)){
-    case 'string':
-    case 'number':
-    case 'date':
-        return val.toString();
-    case 'object':
-    case 'array':
-        var s = "";
-        for (var k in val){
-            s += k + val[k];
-        }
-        return s;
+    switch (typeof(val)) {
+        case 'string':
+        case 'number':
+        case 'date':
+            return val.toString();
+        case 'object':
+        case 'array':
+            var s = "";
+            for (var k in val) {
+                s += k + val[k];
+            }
+            return s;
     }
 
-    throw Error( "can't hash : " + typeof(val) );
+    throw Error("can't hash : " + typeof(val));
 };
 
-Map.prototype.put = function(key, value){
+Map.prototype.put = function(key, value) {
     var o = this._get(key);
     var old = o.value;
     o.value = value;
     return old;
 };
 
-Map.prototype.get = function(key){
+Map.prototype.get = function(key) {
     return this._get(key).value;
 };
 
-Map.prototype._get = function(key){
+Map.prototype._get = function(key) {
     var h = Map.hash(key);
     var a = this._data[h];
-    if (! a){
+    if (!a) {
         a = [];
         this._data[h] = a;
     }
-    for (var i=0; i<a.length; i++){
-        if (friendlyEqual(key, a[i].key)){
+    for (var i = 0; i < a.length; i++) {
+        if (friendlyEqual(key, a[i].key)) {
             return a[i];
         }
     }
-    var o = { key : key, value : null };
+    var o = {
+        key: key,
+        value: null
+    };
     a.push(o);
     return o;
 };
 
-Map.prototype.values = function(){
+Map.prototype.values = function() {
     var all = [];
-    for (var k in this._data){
-        this._data[k].forEach(function(z){ all.push(z.value); });
+    for (var k in this._data) {
+        this._data[k].forEach(function(z) {
+            all.push(z.value);
+        });
     }
     return all;
 };
 
-if (typeof(gc) == "undefined"){
-    gc = function(){
+if (typeof(gc) == "undefined") {
+    gc = function() {
         print("warning: using noop gc()");
     };
 }
 
 // Free Functions
-tojsononeline = function(x){
+tojsononeline = function(x) {
     return tojson(x, " ", true);
 };
 
-tojson = function(x, indent, nolint){
+tojson = function(x, indent, nolint) {
     if (x === null)
         return "null";
 
@@ -599,68 +605,69 @@ tojson = function(x, indent, nolint){
         indent = "";
 
     switch (typeof x) {
-    case "string": {
-        var out = new Array(x.length+1);
-        out[0] = '"';
-        for (var i=0; i<x.length; i++){
-            switch (x[i]) {
-                case '"':
-                  out[out.length] = '\\"';
-                  break;
-                case '\\':
-                  out[out.length] = '\\\\';
-                  break;
-                case '\b':
-                  out[out.length] = '\\b';
-                  break;
-                case '\f':
-                  out[out.length] = '\\f';
-                  break;
-                case '\n':
-                  out[out.length] = '\\n';
-                  break;
-                case '\r':
-                  out[out.length] = '\\r';
-                  break;
-                case '\t':
-                  out[out.length] = '\\t';
-                  break;
+        case "string": {
+            var out = new Array(x.length + 1);
+            out[0] = '"';
+            for (var i = 0; i < x.length; i++) {
+                switch (x[i]) {
+                    case '"':
+                        out[out.length] = '\\"';
+                        break;
+                    case '\\':
+                        out[out.length] = '\\\\';
+                        break;
+                    case '\b':
+                        out[out.length] = '\\b';
+                        break;
+                    case '\f':
+                        out[out.length] = '\\f';
+                        break;
+                    case '\n':
+                        out[out.length] = '\\n';
+                        break;
+                    case '\r':
+                        out[out.length] = '\\r';
+                        break;
+                    case '\t':
+                        out[out.length] = '\\t';
+                        break;
 
-                default: {
-                    var code = x.charCodeAt(i);
-                    if (code < 0x20){
-                        out[out.length] =
-                          (code < 0x10 ? '\\u000' : '\\u00') + code.toString(16);
-                    } else {
-                        out[out.length] = x[i];
+                    default: {
+                        var code = x.charCodeAt(i);
+                        if (code < 0x20) {
+                            out[out.length] =
+                                (code < 0x10 ? '\\u000' : '\\u00') + code.toString(16);
+                        } else {
+                            out[out.length] = x[i];
+                        }
                     }
                 }
             }
-        }
 
-        return out.join('') + "\"";
-    }
-    case "number":
-    case "boolean":
-        return "" + x;
-    case "object":{
-        var s = tojsonObject(x, indent, nolint);
-        if ((nolint == null || nolint == true) && s.length < 80 && (indent == null || indent.length == 0)){
-            s = s.replace(/[\t\r\n]+/gm, " ");
+            return out.join('') + "\"";
         }
-        return s;
-    }
-    case "function":
-        if (x === MinKey || x === MaxKey)
-            return x.tojson();
-        return x.toString();
-    default:
-        throw Error( "tojson can't handle type " + (typeof x) );
+        case "number":
+        case "boolean":
+            return "" + x;
+        case "object": {
+            var s = tojsonObject(x, indent, nolint);
+            if ((nolint == null || nolint == true) && s.length < 80 &&
+                (indent == null || indent.length == 0)) {
+                s = s.replace(/[\t\r\n]+/gm, " ");
+            }
+            return s;
+        }
+        case "function":
+            if (x === MinKey || x === MaxKey)
+                return x.tojson();
+            return x.toString();
+        default:
+            throw Error("tojson can't handle type " + (typeof x));
     }
 
 };
 
-tojsonObject = function(x, indent, nolint){
+tojsonObject = function(x, indent, nolint) {
     var lineEnding = nolint ? " " : "\n";
     var tabSpace = nolint ? "" : "\t";
     assert.eq((typeof x), "object", "tojsonObject needs object, not [" + (typeof x) + "]");
@@ -669,10 +676,11 @@ tojsonObject = function(x, indent, nolint){
         indent = "";
 
     if (typeof(x.tojson) == "function" && x.tojson != tojson) {
-        return x.tojson(indent,nolint);
+        return x.tojson(indent, nolint);
     }
 
-    if (x.constructor && typeof(x.constructor.tojson) == "function" && x.constructor.tojson != tojson) {
+    if (x.constructor && typeof(x.constructor.tojson) == "function" &&
+        x.constructor.tojson != tojson) {
         return x.constructor.tojson(x, indent, nolint);
     }
 
@@ -682,8 +690,7 @@ tojsonObject = function(x, indent, nolint){
 
     try {
         x.toString();
-    }
-    catch(e) {
+    } catch (e) {
         // toString not callable
         return "[object]";
     }
@@ -697,7 +704,7 @@ tojsonObject = function(x, indent, nolint){
     if (typeof(x._simpleKeys) == "function")
         keys = x._simpleKeys();
     var fieldStrings = [];
-    for (var k in keys){
+    for (var k in keys) {
         var val = x[k];
 
         // skip internal DB types to avoid issues with interceptors
@@ -711,8 +718,7 @@ tojsonObject = function(x, indent, nolint){
 
     if (fieldStrings.length > 0) {
         s += fieldStrings.join("," + lineEnding);
-    }
-    else {
+    } else {
         s += indent;
     }
     s += lineEnding;
@@ -722,23 +728,23 @@ tojsonObject = function(x, indent, nolint){
     return s + indent + "}";
 };
 
-printjson = function(x){
-    print( tojson( x ) );
+printjson = function(x) {
+    print(tojson(x));
 };
 
-printjsononeline = function(x){
-    print( tojsononeline( x ) );
+printjsononeline = function(x) {
+    print(tojsononeline(x));
 };
 
-isString = function(x){
+isString = function(x) {
     return typeof(x) == "string";
 };
 
-isNumber = function(x){
+isNumber = function(x) {
     return typeof(x) == "number";
 };
 
 // This function returns true even if the argument is an array.  See SERVER-14220.
-isObject = function(x){
+isObject = function(x) {
     return typeof(x) == "object";
 };
