@@ -214,6 +214,13 @@ void Test::stopCapturingLogMessages() {
     checked_cast<StringVectorAppender*>(_captureAppender.get())->disable();
     _isCapturingLogMessages = false;
 }
+void Test::printCapturedLogLines() const {
+    log() << "****************************** Captured Lines (start) *****************************";
+    std::for_each(getCapturedLogMessages().begin(),
+                  getCapturedLogMessages().end(),
+                  [](std::string line) { log() << line; });
+    log() << "****************************** Captured Lines (end) ******************************";
+}
 
 int64_t Test::countLogLinesContaining(const std::string& needle) {
     return std::count_if(getCapturedLogMessages().begin(),
