@@ -75,19 +75,18 @@ class MessagingPortWithHandler : public MessagingPort {
 
 public:
     MessagingPortWithHandler(const std::shared_ptr<Socket>& socket,
-                             MessageHandler* handler,
+                             const std::shared_ptr<MessageHandler> handler,
                              long long connectionId)
         : MessagingPort(socket), _handler(handler) {
         setConnectionId(connectionId);
     }
 
-    MessageHandler* getHandler() const {
+    const std::shared_ptr<MessageHandler> getHandler() const {
         return _handler;
     }
 
 private:
-    // Not owned.
-    MessageHandler* const _handler;
+    const std::shared_ptr<MessageHandler> _handler;
 };
 
 }  // namespace
@@ -98,11 +97,10 @@ public:
      * Creates a new message server.
      *
      * @param opts
-     * @param handler the handler to use. Caller is responsible for managing this object
-     *     and should make sure that it lives longer than this server.
+     * @param handler the handler to use.
      */
-    PortMessageServer(const MessageServer::Options& opts, MessageHandler* handler)
-        : Listener("", opts.ipList, opts.port), _handler(handler) {}
+    PortMessageServer(const MessageServer::Options& opts, std::shared_ptr<MessageHandler> handler)
+        : Listener("", opts.ipList, opts.port), _handler(std::move(handler)) {}
 
     virtual void accepted(std::shared_ptr<Socket> psocket, long long connectionId) {
         ScopeGuard sleepAfterClosingPort = MakeGuard(sleepmillis, 2);
@@ -181,7 +179,7 @@ public:
     }
 
 private:
-    MessageHandler* _handler;
+    const std::shared_ptr<MessageHandler> _handler;
 
     /**
      * Handles incoming messages from a given socket.
@@ -201,7 +199,7 @@ private:
         invariant(arg);
         unique_ptr<MessagingPortWithHandler> portWithHandler(
             static_cast<MessagingPortWithHandler*>(arg));
-        MessageHandler* const handler = portWithHandler->getHandler();
+        const std::shared_ptr<MessageHandler> handler = portWithHandler->getHandler();
 
         setThreadName(std::string(str::stream() << "conn" << portWithHandler->connectionId()));
         portWithHandler->psock->setLogLevel(logger::LogSeverity::Debug(1));
@@ -261,8 +259,9 @@ private:
 };
 
 
-MessageServer* createServer(const MessageServer::Options& opts, MessageHandler* handler) {
-    return new PortMessageServer(opts, handler);
+MessageServer* createServer(const MessageServer::Options& opts,
+                            std::shared_ptr<MessageHandler> handler) {
+    return new PortMessageServer(opts, std::move(handler));
 }
 
 }  // namespace mongo
