@@ -691,9 +691,7 @@ int Socket::_send(const char* data, int len, const char* context) {
     }
 #endif
     int ret = ::send(_fd, data, len, portSendFlags);
-    if (ret < 0) {
-        handleSendError(ret, context);
-    }
+
     return ret;
 }
 
@@ -707,11 +705,15 @@ void Socket::send(const char* data, int len, const char* context) {
 #else
             errno = ENETUNREACH;
 #endif
-            handleSendError(ret, context);
         } else {
             ret = _send(data, len, context);
         }
 
+        if (ret < 0) {
+            handleSendError(ret, context);
+            continue;
+        }
+
         _bytesOut += ret;
 
         fassert(16507, ret <= len);
@@ -771,15 +773,7 @@ void Socket::send(const vector<pair<char*, int>>& data, const char* context) {
         }
 
         if (ret == -1) {
-            if (errno != EAGAIN || _timeout == 0) {
-                LOG(_logLevel) << "Socket " << context << " send() " << errnoWithDescription()
-                               << ' ' << remoteString() << endl;
-                throw SocketException(SocketException::SEND_ERROR, remoteString());
-            } else {
-                LOG(_logLevel) << "Socket " << context << " send() remote timeout "
-                               << remoteString() << endl;
-                throw SocketException(SocketException::SEND_TIMEOUT, remoteString());
-            }
+            handleSendError(ret, context);
         } else {
             struct iovec*& i = meta.msg_iov;
             while (ret > 0) {
@@ -852,7 +846,7 @@ void Socket::handleSendError(int ret, const char* context) {
 #endif
         LOG(_logLevel) << "Socket " << context << " send() timed out " << remoteString() << endl;
         throw SocketException(SocketException::SEND_TIMEOUT, remoteString());
-    } else {
+    } else if (mongo_errno != EINTR) {
         LOG(_logLevel) << "Socket " << context << " send() " << errnoWithDescription(mongo_errno)
                        << ' ' << remoteString() << endl;
         throw SocketException(SocketException::SEND_ERROR, remoteString());
@@ -872,7 +866,6 @@ void Socket::handleRecvError(int ret, int len) {
     int e = errno;
 #if defined(EINTR)
     if (e == EINTR) {
-        LOG(_logLevel) << "EINTR returned from recv(), retrying";
         return;
     }
 #endif
