@@ -312,9 +312,6 @@ Status storeSSLServerOptions(const moe::Environment& params) {
         if (sslGlobalParams.sslPEMKeyFile.size() == 0) {
             return Status(ErrorCodes::BadValue, "need sslPEMKeyFile when SSL is enabled");
         }
-        if (sslGlobalParams.sslWeakCertificateValidation && sslGlobalParams.sslCAFile.empty()) {
-            return Status(ErrorCodes::BadValue, "need sslCAFile with sslWeakCertificateValidation");
-        }
         if (!sslGlobalParams.sslCRLFile.empty() && sslGlobalParams.sslCAFile.empty()) {
             return Status(ErrorCodes::BadValue, "need sslCAFile with sslCRLFile");
         }
@@ -385,14 +382,4 @@ Status storeSSLClientOptions(const moe::Environment& params) {
     return Status::OK();
 }
 
-Status validateSSLMongoShellOptions(const moe::Environment& params) {
-    // Users must specify either a CAFile or allowInvalidCertificates if ssl=true.
-    if (params.count("ssl") && params["ssl"].as<bool>() == true && !params.count("ssl.CAFile") &&
-        !params.count("ssl.allowInvalidCertificates")) {
-        return Status(ErrorCodes::BadValue,
-                      "need to either provide sslCAFile or specify sslAllowInvalidCertificates");
-    }
-    return Status::OK();
-}
-
 }  // namespace mongo
